/* CDApplet.c generated by valac 0.10.0, the Vala compiler
 * generated from CDApplet.vala, do not modify */

/* This is a part of the external applet for Cairo-Dock

Copyright : (C) 2010-2011 by Fabounet
E-mail : fabounet@glx-dock.org

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU General Public License for more details.
http://www.gnu.org/licenses/licenses.html#GPL */
/*/ To compile it manually:*/
/*/ valac -q -C --disable-warnings --disable-dbus-transformation --pkg gio-2.0 --vapi=CDApplet-simple.vapi --internal-vapi=CDApplet.vapi --header=CDApplet-simple.h --internal-header=CDApplet.h CDApplet.vala*/
/*/ gcc --shared -fPIC -o CDApplet.so $(pkg-config --cflags --libs gobject-2.0 gio-2.0) CDApplet.c*/
/*///////////////////////*/
/*/// dependancies //////*/
/*///////////////////////*/

#include <glib.h>
#include <glib-object.h>
#include <stdlib.h>
#include <string.h>
#include <gio/gio.h>
#include <float.h>
#include <math.h>


#define CAIRO_DOCK_APPLET_TYPE_IAPPLET (cairo_dock_applet_iapplet_get_type ())
#define CAIRO_DOCK_APPLET_IAPPLET(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), CAIRO_DOCK_APPLET_TYPE_IAPPLET, CairoDockAppletIApplet))
#define CAIRO_DOCK_APPLET_IS_IAPPLET(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), CAIRO_DOCK_APPLET_TYPE_IAPPLET))
#define CAIRO_DOCK_APPLET_IAPPLET_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), CAIRO_DOCK_APPLET_TYPE_IAPPLET, CairoDockAppletIAppletIface))

typedef struct _CairoDockAppletIApplet CairoDockAppletIApplet;
typedef struct _CairoDockAppletIAppletIface CairoDockAppletIAppletIface;

#define CAIRO_DOCK_APPLET_TYPE_IAPPLET_PROXY (cairo_dock_applet_iapplet_proxy_get_type ())
typedef GDBusProxy CairoDockAppletIAppletProxy;
typedef GDBusProxyClass CairoDockAppletIAppletProxyClass;
#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_variant_unref0(var) ((var == NULL) ? NULL : (var = (g_variant_unref (var), NULL)))
#define _g_hash_table_unref0(var) ((var == NULL) ? NULL : (var = (g_hash_table_unref (var), NULL)))

#define CAIRO_DOCK_APPLET_TYPE_ISUB_APPLET (cairo_dock_applet_isub_applet_get_type ())
#define CAIRO_DOCK_APPLET_ISUB_APPLET(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), CAIRO_DOCK_APPLET_TYPE_ISUB_APPLET, CairoDockAppletISubApplet))
#define CAIRO_DOCK_APPLET_IS_ISUB_APPLET(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), CAIRO_DOCK_APPLET_TYPE_ISUB_APPLET))
#define CAIRO_DOCK_APPLET_ISUB_APPLET_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), CAIRO_DOCK_APPLET_TYPE_ISUB_APPLET, CairoDockAppletISubAppletIface))

typedef struct _CairoDockAppletISubApplet CairoDockAppletISubApplet;
typedef struct _CairoDockAppletISubAppletIface CairoDockAppletISubAppletIface;

#define CAIRO_DOCK_APPLET_TYPE_ISUB_APPLET_PROXY (cairo_dock_applet_isub_applet_proxy_get_type ())
typedef GDBusProxy CairoDockAppletISubAppletProxy;
typedef GDBusProxyClass CairoDockAppletISubAppletProxyClass;

#define CAIRO_DOCK_APPLET_TYPE_CD_APPLET (cairo_dock_applet_cd_applet_get_type ())
#define CAIRO_DOCK_APPLET_CD_APPLET(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), CAIRO_DOCK_APPLET_TYPE_CD_APPLET, CairoDockAppletCDApplet))
#define CAIRO_DOCK_APPLET_CD_APPLET_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), CAIRO_DOCK_APPLET_TYPE_CD_APPLET, CairoDockAppletCDAppletClass))
#define CAIRO_DOCK_APPLET_IS_CD_APPLET(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), CAIRO_DOCK_APPLET_TYPE_CD_APPLET))
#define CAIRO_DOCK_APPLET_IS_CD_APPLET_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), CAIRO_DOCK_APPLET_TYPE_CD_APPLET))
#define CAIRO_DOCK_APPLET_CD_APPLET_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), CAIRO_DOCK_APPLET_TYPE_CD_APPLET, CairoDockAppletCDAppletClass))

typedef struct _CairoDockAppletCDApplet CairoDockAppletCDApplet;
typedef struct _CairoDockAppletCDAppletClass CairoDockAppletCDAppletClass;
typedef struct _CairoDockAppletCDAppletPrivate CairoDockAppletCDAppletPrivate;

#define CAIRO_DOCK_APPLET_CD_APPLET_TYPE_SCREEN_POSITION (cairo_dock_applet_cd_applet_screen_position_get_type ())

#define CAIRO_DOCK_APPLET_CD_APPLET_TYPE_CONTAINER_TYPE (cairo_dock_applet_cd_applet_container_type_get_type ())

#define CAIRO_DOCK_APPLET_CD_APPLET_TYPE_EMBLEM_POSITION (cairo_dock_applet_cd_applet_emblem_position_get_type ())

#define CAIRO_DOCK_APPLET_CD_APPLET_TYPE_MENU_ITEM_TYPE (cairo_dock_applet_cd_applet_menu_item_type_get_type ())
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_main_loop_unref0(var) ((var == NULL) ? NULL : (var = (g_main_loop_unref (var), NULL)))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
#define _g_key_file_free0(var) ((var == NULL) ? NULL : (var = (g_key_file_free (var), NULL)))

struct _CairoDockAppletIAppletIface {
	GTypeInterface parent_iface;
	GVariant* (*Get) (CairoDockAppletIApplet* self, const char* cProperty, GError** error);
	GHashTable* (*GetAll) (CairoDockAppletIApplet* self, GError** error);
	void (*SetQuickInfo) (CairoDockAppletIApplet* self, const char* cQuickInfo, GError** error);
	void (*SetLabel) (CairoDockAppletIApplet* self, const char* cLabel, GError** error);
	void (*SetIcon) (CairoDockAppletIApplet* self, const char* cImage, GError** error);
	void (*SetEmblem) (CairoDockAppletIApplet* self, const char* cImage, gint iPosition, GError** error);
	void (*Animate) (CairoDockAppletIApplet* self, const char* cAnimation, gint iRounds, GError** error);
	void (*DemandsAttention) (CairoDockAppletIApplet* self, gboolean bStart, const char* cAnimation, GError** error);
	void (*ShowDialog) (CairoDockAppletIApplet* self, const char* cMessage, gint iDuration, GError** error);
	void (*PopupDialog) (CairoDockAppletIApplet* self, GHashTable* hDialogAttributes, GHashTable* hWidgetAttributes, GError** error);
	void (*AddDataRenderer) (CairoDockAppletIApplet* self, const char* cType, gint iNbValues, const char* cTheme, GError** error);
	void (*RenderValues) (CairoDockAppletIApplet* self, double* pValues, int pValues_length1, GError** error);
	void (*ControlAppli) (CairoDockAppletIApplet* self, const char* cApplicationClass, GError** error);
	void (*ShowAppli) (CairoDockAppletIApplet* self, gboolean bShow, GError** error);
	void (*AddMenuItems) (CairoDockAppletIApplet* self, GHashTable** pItems, int pItems_length1, GError** error);
	void (*BindShortkey) (CairoDockAppletIApplet* self, char** cShortkeys, int cShortkeys_length1, GError** error);
};

struct _CairoDockAppletISubAppletIface {
	GTypeInterface parent_iface;
	void (*SetQuickInfo) (CairoDockAppletISubApplet* self, const char* cQuickInfo, const char* cIconID, GError** error);
	void (*SetLabel) (CairoDockAppletISubApplet* self, const char* cLabel, const char* cIconID, GError** error);
	void (*SetIcon) (CairoDockAppletISubApplet* self, const char* cImage, const char* cIconID, GError** error);
	void (*SetEmblem) (CairoDockAppletISubApplet* self, const char* cImage, gint iPosition, const char* cIconID, GError** error);
	void (*Animate) (CairoDockAppletISubApplet* self, const char* cAnimation, gint iNbRounds, const char* cIconID, GError** error);
	void (*ShowDialog) (CairoDockAppletISubApplet* self, const char* message, gint iDuration, const char* cIconID, GError** error);
	void (*AddSubIcons) (CairoDockAppletISubApplet* self, char** pIconFields, int pIconFields_length1, GError** error);
	void (*RemoveSubIcon) (CairoDockAppletISubApplet* self, const char* cIconID, GError** error);
};

struct _CairoDockAppletCDApplet {
	GObject parent_instance;
	CairoDockAppletCDAppletPrivate * priv;
	CairoDockAppletIApplet* icon;
	CairoDockAppletISubApplet* sub_icons;
	char* cAppletName;
	char* cConfFile;
	char* cParentAppName;
	char* cBusPath;
};

struct _CairoDockAppletCDAppletClass {
	GObjectClass parent_class;
	void (*on_click) (CairoDockAppletCDApplet* self, gint iState);
	void (*on_middle_click) (CairoDockAppletCDApplet* self);
	void (*on_build_menu) (CairoDockAppletCDApplet* self);
	void (*on_menu_select) (CairoDockAppletCDApplet* self, gint iNumEntry);
	void (*on_scroll) (CairoDockAppletCDApplet* self, gboolean bScrollUp);
	void (*on_drop_data) (CairoDockAppletCDApplet* self, const char* cReceivedData);
	void (*on_answer) (CairoDockAppletCDApplet* self, GVariant* answer);
	void (*on_answer_dialog) (CairoDockAppletCDApplet* self, gint iButton, GVariant* answer);
	void (*on_shortkey) (CairoDockAppletCDApplet* self, const char* cKey);
	void (*on_change_focus) (CairoDockAppletCDApplet* self, gboolean bIsActive);
	void (*on_click_sub_icon) (CairoDockAppletCDApplet* self, gint iState, const char* cIconID);
	void (*on_middle_click_sub_icon) (CairoDockAppletCDApplet* self, const char* cIconID);
	void (*on_scroll_sub_icon) (CairoDockAppletCDApplet* self, gboolean bScrollUp, const char* cIconID);
	void (*on_drop_data_sub_icon) (CairoDockAppletCDApplet* self, const char* cReceivedData, const char* cIconID);
	void (*on_build_menu_sub_icon) (CairoDockAppletCDApplet* self, const char* cIconID);
	void (*on_menu_select_sub_icon) (CairoDockAppletCDApplet* self, gint iNumEntry, const char* cIconID);
	void (*begin) (CairoDockAppletCDApplet* self);
	void (*end) (CairoDockAppletCDApplet* self);
	void (*reload) (CairoDockAppletCDApplet* self);
	void (*get_config) (CairoDockAppletCDApplet* self, GKeyFile* keyfile);
};

struct _CairoDockAppletCDAppletPrivate {
	GMainLoop* loop;
	char* _cMenuIconId;
};

typedef enum  {
	CAIRO_DOCK_APPLET_CD_APPLET_SCREEN_POSITION_BOTTOM = 0,
	CAIRO_DOCK_APPLET_CD_APPLET_SCREEN_POSITION_TOP,
	CAIRO_DOCK_APPLET_CD_APPLET_SCREEN_POSITION_RIGHT,
	CAIRO_DOCK_APPLET_CD_APPLET_SCREEN_POSITION_LEFT
} CairoDockAppletCDAppletScreenPosition;

typedef enum  {
	CAIRO_DOCK_APPLET_CD_APPLET_CONTAINER_TYPE_DOCK = 0,
	CAIRO_DOCK_APPLET_CD_APPLET_CONTAINER_TYPE_DESKLET
} CairoDockAppletCDAppletContainerType;

typedef enum  {
	CAIRO_DOCK_APPLET_CD_APPLET_EMBLEM_POSITION_UPPER_LEFT = 0,
	CAIRO_DOCK_APPLET_CD_APPLET_EMBLEM_POSITION_LOWER_RIGHT,
	CAIRO_DOCK_APPLET_CD_APPLET_EMBLEM_POSITION_LOWER_LEFT,
	CAIRO_DOCK_APPLET_CD_APPLET_EMBLEM_POSITION_UPPER_RIGHT,
	CAIRO_DOCK_APPLET_CD_APPLET_EMBLEM_POSITION_MIDDLE
} CairoDockAppletCDAppletEmblemPosition;

typedef enum  {
	CAIRO_DOCK_APPLET_CD_APPLET_MENU_ITEM_TYPE_MENU_ENTRY = 0,
	CAIRO_DOCK_APPLET_CD_APPLET_MENU_ITEM_TYPE_MENU_SUB_MENU,
	CAIRO_DOCK_APPLET_CD_APPLET_MENU_ITEM_TYPE_MENU_SEPARATOR,
	CAIRO_DOCK_APPLET_CD_APPLET_MENU_ITEM_TYPE_MENU_CHECKBOX,
	CAIRO_DOCK_APPLET_CD_APPLET_MENU_ITEM_TYPE_MENU_RADIO_BUTTON
} CairoDockAppletCDAppletMenuItemType;


static gpointer cairo_dock_applet_cd_applet_parent_class = NULL;

GType cairo_dock_applet_iapplet_proxy_get_type (void) G_GNUC_CONST;
guint cairo_dock_applet_iapplet_register_object (void* object, GDBusConnection* connection, const gchar* path, GError** error);
GType cairo_dock_applet_iapplet_get_type (void) G_GNUC_CONST;
GVariant* cairo_dock_applet_iapplet_Get (CairoDockAppletIApplet* self, const char* cProperty, GError** error);
GHashTable* cairo_dock_applet_iapplet_GetAll (CairoDockAppletIApplet* self, GError** error);
void cairo_dock_applet_iapplet_SetQuickInfo (CairoDockAppletIApplet* self, const char* cQuickInfo, GError** error);
void cairo_dock_applet_iapplet_SetLabel (CairoDockAppletIApplet* self, const char* cLabel, GError** error);
void cairo_dock_applet_iapplet_SetIcon (CairoDockAppletIApplet* self, const char* cImage, GError** error);
void cairo_dock_applet_iapplet_SetEmblem (CairoDockAppletIApplet* self, const char* cImage, gint iPosition, GError** error);
void cairo_dock_applet_iapplet_Animate (CairoDockAppletIApplet* self, const char* cAnimation, gint iRounds, GError** error);
void cairo_dock_applet_iapplet_DemandsAttention (CairoDockAppletIApplet* self, gboolean bStart, const char* cAnimation, GError** error);
void cairo_dock_applet_iapplet_ShowDialog (CairoDockAppletIApplet* self, const char* cMessage, gint iDuration, GError** error);
void cairo_dock_applet_iapplet_PopupDialog (CairoDockAppletIApplet* self, GHashTable* hDialogAttributes, GHashTable* hWidgetAttributes, GError** error);
void cairo_dock_applet_iapplet_AddDataRenderer (CairoDockAppletIApplet* self, const char* cType, gint iNbValues, const char* cTheme, GError** error);
void cairo_dock_applet_iapplet_RenderValues (CairoDockAppletIApplet* self, double* pValues, int pValues_length1, GError** error);
void cairo_dock_applet_iapplet_ControlAppli (CairoDockAppletIApplet* self, const char* cApplicationClass, GError** error);
void cairo_dock_applet_iapplet_ShowAppli (CairoDockAppletIApplet* self, gboolean bShow, GError** error);
void cairo_dock_applet_iapplet_AddMenuItems (CairoDockAppletIApplet* self, GHashTable** pItems, int pItems_length1, GError** error);
void cairo_dock_applet_iapplet_BindShortkey (CairoDockAppletIApplet* self, char** cShortkeys, int cShortkeys_length1, GError** error);
static void cairo_dock_applet_iapplet_proxy_g_signal (GDBusProxy* proxy, const gchar* sender_name, const gchar* signal_name, GVariant* parameters);
static void _dbus_handle_cairo_dock_applet_iapplet_on_click (CairoDockAppletIApplet* self, GVariant* parameters);
static void _dbus_handle_cairo_dock_applet_iapplet_on_middle_click (CairoDockAppletIApplet* self, GVariant* parameters);
static void _dbus_handle_cairo_dock_applet_iapplet_on_build_menu (CairoDockAppletIApplet* self, GVariant* parameters);
static void _dbus_handle_cairo_dock_applet_iapplet_on_menu_select (CairoDockAppletIApplet* self, GVariant* parameters);
static void _dbus_handle_cairo_dock_applet_iapplet_on_scroll (CairoDockAppletIApplet* self, GVariant* parameters);
static void _dbus_handle_cairo_dock_applet_iapplet_on_drop_data (CairoDockAppletIApplet* self, GVariant* parameters);
static void _dbus_handle_cairo_dock_applet_iapplet_on_answer (CairoDockAppletIApplet* self, GVariant* parameters);
static void _dbus_handle_cairo_dock_applet_iapplet_on_answer_dialog (CairoDockAppletIApplet* self, GVariant* parameters);
static void _dbus_handle_cairo_dock_applet_iapplet_on_shortkey (CairoDockAppletIApplet* self, GVariant* parameters);
static void _dbus_handle_cairo_dock_applet_iapplet_on_change_focus (CairoDockAppletIApplet* self, GVariant* parameters);
static void _dbus_handle_cairo_dock_applet_iapplet_on_stop_module (CairoDockAppletIApplet* self, GVariant* parameters);
static void _dbus_handle_cairo_dock_applet_iapplet_on_reload_module (CairoDockAppletIApplet* self, GVariant* parameters);
static GVariant* cairo_dock_applet_iapplet_proxy_Get (CairoDockAppletIApplet* self, const char* cProperty, GError** error);
static GHashTable* cairo_dock_applet_iapplet_proxy_GetAll (CairoDockAppletIApplet* self, GError** error);
static void cairo_dock_applet_iapplet_proxy_SetQuickInfo (CairoDockAppletIApplet* self, const char* cQuickInfo, GError** error);
static void cairo_dock_applet_iapplet_proxy_SetLabel (CairoDockAppletIApplet* self, const char* cLabel, GError** error);
static void cairo_dock_applet_iapplet_proxy_SetIcon (CairoDockAppletIApplet* self, const char* cImage, GError** error);
static void cairo_dock_applet_iapplet_proxy_SetEmblem (CairoDockAppletIApplet* self, const char* cImage, gint iPosition, GError** error);
static void cairo_dock_applet_iapplet_proxy_Animate (CairoDockAppletIApplet* self, const char* cAnimation, gint iRounds, GError** error);
static void cairo_dock_applet_iapplet_proxy_DemandsAttention (CairoDockAppletIApplet* self, gboolean bStart, const char* cAnimation, GError** error);
static void cairo_dock_applet_iapplet_proxy_ShowDialog (CairoDockAppletIApplet* self, const char* cMessage, gint iDuration, GError** error);
static void cairo_dock_applet_iapplet_proxy_PopupDialog (CairoDockAppletIApplet* self, GHashTable* hDialogAttributes, GHashTable* hWidgetAttributes, GError** error);
static void cairo_dock_applet_iapplet_proxy_AddDataRenderer (CairoDockAppletIApplet* self, const char* cType, gint iNbValues, const char* cTheme, GError** error);
static void cairo_dock_applet_iapplet_proxy_RenderValues (CairoDockAppletIApplet* self, double* pValues, int pValues_length1, GError** error);
static void cairo_dock_applet_iapplet_proxy_ControlAppli (CairoDockAppletIApplet* self, const char* cApplicationClass, GError** error);
static void cairo_dock_applet_iapplet_proxy_ShowAppli (CairoDockAppletIApplet* self, gboolean bShow, GError** error);
static void cairo_dock_applet_iapplet_proxy_AddMenuItems (CairoDockAppletIApplet* self, GHashTable** pItems, int pItems_length1, GError** error);
static void cairo_dock_applet_iapplet_proxy_BindShortkey (CairoDockAppletIApplet* self, char** cShortkeys, int cShortkeys_length1, GError** error);
static void cairo_dock_applet_iapplet_proxy_cairo_dock_applet_iapplet_interface_init (CairoDockAppletIAppletIface* iface);
static void cairo_dock_applet_iapplet_dbus_interface_method_call (GDBusConnection* connection, const gchar* sender, const gchar* object_path, const gchar* interface_name, const gchar* method_name, GVariant* parameters, GDBusMethodInvocation* invocation, gpointer user_data);
static void _dbus_cairo_dock_applet_iapplet_Get (CairoDockAppletIApplet* self, GVariant* parameters, GDBusMethodInvocation* invocation);
static void _dbus_cairo_dock_applet_iapplet_GetAll (CairoDockAppletIApplet* self, GVariant* parameters, GDBusMethodInvocation* invocation);
static void _dbus_cairo_dock_applet_iapplet_SetQuickInfo (CairoDockAppletIApplet* self, GVariant* parameters, GDBusMethodInvocation* invocation);
static void _dbus_cairo_dock_applet_iapplet_SetLabel (CairoDockAppletIApplet* self, GVariant* parameters, GDBusMethodInvocation* invocation);
static void _dbus_cairo_dock_applet_iapplet_SetIcon (CairoDockAppletIApplet* self, GVariant* parameters, GDBusMethodInvocation* invocation);
static void _dbus_cairo_dock_applet_iapplet_SetEmblem (CairoDockAppletIApplet* self, GVariant* parameters, GDBusMethodInvocation* invocation);
static void _dbus_cairo_dock_applet_iapplet_Animate (CairoDockAppletIApplet* self, GVariant* parameters, GDBusMethodInvocation* invocation);
static void _dbus_cairo_dock_applet_iapplet_DemandsAttention (CairoDockAppletIApplet* self, GVariant* parameters, GDBusMethodInvocation* invocation);
static void _dbus_cairo_dock_applet_iapplet_ShowDialog (CairoDockAppletIApplet* self, GVariant* parameters, GDBusMethodInvocation* invocation);
static void _dbus_cairo_dock_applet_iapplet_PopupDialog (CairoDockAppletIApplet* self, GVariant* parameters, GDBusMethodInvocation* invocation);
static void _dbus_cairo_dock_applet_iapplet_AddDataRenderer (CairoDockAppletIApplet* self, GVariant* parameters, GDBusMethodInvocation* invocation);
static void _dbus_cairo_dock_applet_iapplet_RenderValues (CairoDockAppletIApplet* self, GVariant* parameters, GDBusMethodInvocation* invocation);
static void _dbus_cairo_dock_applet_iapplet_ControlAppli (CairoDockAppletIApplet* self, GVariant* parameters, GDBusMethodInvocation* invocation);
static void _dbus_cairo_dock_applet_iapplet_ShowAppli (CairoDockAppletIApplet* self, GVariant* parameters, GDBusMethodInvocation* invocation);
static void _dbus_cairo_dock_applet_iapplet_AddMenuItems (CairoDockAppletIApplet* self, GVariant* parameters, GDBusMethodInvocation* invocation);
static void _dbus_cairo_dock_applet_iapplet_BindShortkey (CairoDockAppletIApplet* self, GVariant* parameters, GDBusMethodInvocation* invocation);
static GVariant* cairo_dock_applet_iapplet_dbus_interface_get_property (GDBusConnection* connection, const gchar* sender, const gchar* object_path, const gchar* interface_name, const gchar* property_name, GError** error, gpointer user_data);
static gboolean cairo_dock_applet_iapplet_dbus_interface_set_property (GDBusConnection* connection, const gchar* sender, const gchar* object_path, const gchar* interface_name, const gchar* property_name, GVariant* value, GError** error, gpointer user_data);
static void _dbus_cairo_dock_applet_iapplet_on_click (GObject* _sender, gint iState, gpointer* _data);
static void _dbus_cairo_dock_applet_iapplet_on_middle_click (GObject* _sender, gpointer* _data);
static void _dbus_cairo_dock_applet_iapplet_on_build_menu (GObject* _sender, gpointer* _data);
static void _dbus_cairo_dock_applet_iapplet_on_menu_select (GObject* _sender, gint iNumEntry, gpointer* _data);
static void _dbus_cairo_dock_applet_iapplet_on_scroll (GObject* _sender, gboolean bScrollUp, gpointer* _data);
static void _dbus_cairo_dock_applet_iapplet_on_drop_data (GObject* _sender, const char* cReceivedData, gpointer* _data);
static void _dbus_cairo_dock_applet_iapplet_on_answer (GObject* _sender, GVariant* answer, gpointer* _data);
static void _dbus_cairo_dock_applet_iapplet_on_answer_dialog (GObject* _sender, gint iButton, GVariant* answer, gpointer* _data);
static void _dbus_cairo_dock_applet_iapplet_on_shortkey (GObject* _sender, const char* cKey, gpointer* _data);
static void _dbus_cairo_dock_applet_iapplet_on_change_focus (GObject* _sender, gboolean bIsActive, gpointer* _data);
static void _dbus_cairo_dock_applet_iapplet_on_stop_module (GObject* _sender, gpointer* _data);
static void _dbus_cairo_dock_applet_iapplet_on_reload_module (GObject* _sender, gboolean bConfigHasChanged, gpointer* _data);
static void _cairo_dock_applet_iapplet_unregister_object (gpointer user_data);
GType cairo_dock_applet_isub_applet_proxy_get_type (void) G_GNUC_CONST;
guint cairo_dock_applet_isub_applet_register_object (void* object, GDBusConnection* connection, const gchar* path, GError** error);
GType cairo_dock_applet_isub_applet_get_type (void) G_GNUC_CONST;
void cairo_dock_applet_isub_applet_SetQuickInfo (CairoDockAppletISubApplet* self, const char* cQuickInfo, const char* cIconID, GError** error);
void cairo_dock_applet_isub_applet_SetLabel (CairoDockAppletISubApplet* self, const char* cLabel, const char* cIconID, GError** error);
void cairo_dock_applet_isub_applet_SetIcon (CairoDockAppletISubApplet* self, const char* cImage, const char* cIconID, GError** error);
void cairo_dock_applet_isub_applet_SetEmblem (CairoDockAppletISubApplet* self, const char* cImage, gint iPosition, const char* cIconID, GError** error);
void cairo_dock_applet_isub_applet_Animate (CairoDockAppletISubApplet* self, const char* cAnimation, gint iNbRounds, const char* cIconID, GError** error);
void cairo_dock_applet_isub_applet_ShowDialog (CairoDockAppletISubApplet* self, const char* message, gint iDuration, const char* cIconID, GError** error);
void cairo_dock_applet_isub_applet_AddSubIcons (CairoDockAppletISubApplet* self, char** pIconFields, int pIconFields_length1, GError** error);
void cairo_dock_applet_isub_applet_RemoveSubIcon (CairoDockAppletISubApplet* self, const char* cIconID, GError** error);
static void cairo_dock_applet_isub_applet_proxy_g_signal (GDBusProxy* proxy, const gchar* sender_name, const gchar* signal_name, GVariant* parameters);
static void _dbus_handle_cairo_dock_applet_isub_applet_on_click_sub_icon (CairoDockAppletISubApplet* self, GVariant* parameters);
static void _dbus_handle_cairo_dock_applet_isub_applet_on_middle_click_sub_icon (CairoDockAppletISubApplet* self, GVariant* parameters);
static void _dbus_handle_cairo_dock_applet_isub_applet_on_scroll_sub_icon (CairoDockAppletISubApplet* self, GVariant* parameters);
static void _dbus_handle_cairo_dock_applet_isub_applet_on_drop_data_sub_icon (CairoDockAppletISubApplet* self, GVariant* parameters);
static void _dbus_handle_cairo_dock_applet_isub_applet_on_build_menu_sub_icon (CairoDockAppletISubApplet* self, GVariant* parameters);
static void cairo_dock_applet_isub_applet_proxy_SetQuickInfo (CairoDockAppletISubApplet* self, const char* cQuickInfo, const char* cIconID, GError** error);
static void cairo_dock_applet_isub_applet_proxy_SetLabel (CairoDockAppletISubApplet* self, const char* cLabel, const char* cIconID, GError** error);
static void cairo_dock_applet_isub_applet_proxy_SetIcon (CairoDockAppletISubApplet* self, const char* cImage, const char* cIconID, GError** error);
static void cairo_dock_applet_isub_applet_proxy_SetEmblem (CairoDockAppletISubApplet* self, const char* cImage, gint iPosition, const char* cIconID, GError** error);
static void cairo_dock_applet_isub_applet_proxy_Animate (CairoDockAppletISubApplet* self, const char* cAnimation, gint iNbRounds, const char* cIconID, GError** error);
static void cairo_dock_applet_isub_applet_proxy_ShowDialog (CairoDockAppletISubApplet* self, const char* message, gint iDuration, const char* cIconID, GError** error);
static void cairo_dock_applet_isub_applet_proxy_AddSubIcons (CairoDockAppletISubApplet* self, char** pIconFields, int pIconFields_length1, GError** error);
static void cairo_dock_applet_isub_applet_proxy_RemoveSubIcon (CairoDockAppletISubApplet* self, const char* cIconID, GError** error);
static void cairo_dock_applet_isub_applet_proxy_cairo_dock_applet_isub_applet_interface_init (CairoDockAppletISubAppletIface* iface);
static void cairo_dock_applet_isub_applet_dbus_interface_method_call (GDBusConnection* connection, const gchar* sender, const gchar* object_path, const gchar* interface_name, const gchar* method_name, GVariant* parameters, GDBusMethodInvocation* invocation, gpointer user_data);
static void _dbus_cairo_dock_applet_isub_applet_SetQuickInfo (CairoDockAppletISubApplet* self, GVariant* parameters, GDBusMethodInvocation* invocation);
static void _dbus_cairo_dock_applet_isub_applet_SetLabel (CairoDockAppletISubApplet* self, GVariant* parameters, GDBusMethodInvocation* invocation);
static void _dbus_cairo_dock_applet_isub_applet_SetIcon (CairoDockAppletISubApplet* self, GVariant* parameters, GDBusMethodInvocation* invocation);
static void _dbus_cairo_dock_applet_isub_applet_SetEmblem (CairoDockAppletISubApplet* self, GVariant* parameters, GDBusMethodInvocation* invocation);
static void _dbus_cairo_dock_applet_isub_applet_Animate (CairoDockAppletISubApplet* self, GVariant* parameters, GDBusMethodInvocation* invocation);
static void _dbus_cairo_dock_applet_isub_applet_ShowDialog (CairoDockAppletISubApplet* self, GVariant* parameters, GDBusMethodInvocation* invocation);
static void _dbus_cairo_dock_applet_isub_applet_AddSubIcons (CairoDockAppletISubApplet* self, GVariant* parameters, GDBusMethodInvocation* invocation);
static void _dbus_cairo_dock_applet_isub_applet_RemoveSubIcon (CairoDockAppletISubApplet* self, GVariant* parameters, GDBusMethodInvocation* invocation);
static GVariant* cairo_dock_applet_isub_applet_dbus_interface_get_property (GDBusConnection* connection, const gchar* sender, const gchar* object_path, const gchar* interface_name, const gchar* property_name, GError** error, gpointer user_data);
static gboolean cairo_dock_applet_isub_applet_dbus_interface_set_property (GDBusConnection* connection, const gchar* sender, const gchar* object_path, const gchar* interface_name, const gchar* property_name, GVariant* value, GError** error, gpointer user_data);
static void _dbus_cairo_dock_applet_isub_applet_on_click_sub_icon (GObject* _sender, gint iState, const char* cIconID, gpointer* _data);
static void _dbus_cairo_dock_applet_isub_applet_on_middle_click_sub_icon (GObject* _sender, const char* cIconID, gpointer* _data);
static void _dbus_cairo_dock_applet_isub_applet_on_scroll_sub_icon (GObject* _sender, gboolean bScrollUp, const char* cIconID, gpointer* _data);
static void _dbus_cairo_dock_applet_isub_applet_on_drop_data_sub_icon (GObject* _sender, const char* cReceivedData, const char* cIconID, gpointer* _data);
static void _dbus_cairo_dock_applet_isub_applet_on_build_menu_sub_icon (GObject* _sender, const char* cIconID, gpointer* _data);
static void _cairo_dock_applet_isub_applet_unregister_object (gpointer user_data);
GType cairo_dock_applet_cd_applet_get_type (void) G_GNUC_CONST;
#define CAIRO_DOCK_APPLET_CD_APPLET_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), CAIRO_DOCK_APPLET_TYPE_CD_APPLET, CairoDockAppletCDAppletPrivate))
enum  {
	CAIRO_DOCK_APPLET_CD_APPLET_DUMMY_PROPERTY
};
GType cairo_dock_applet_cd_applet_screen_position_get_type (void) G_GNUC_CONST;
GType cairo_dock_applet_cd_applet_container_type_get_type (void) G_GNUC_CONST;
GType cairo_dock_applet_cd_applet_emblem_position_get_type (void) G_GNUC_CONST;
GType cairo_dock_applet_cd_applet_menu_item_type_get_type (void) G_GNUC_CONST;
CairoDockAppletCDApplet* cairo_dock_applet_cd_applet_new (char** argv, int argv_length1);
CairoDockAppletCDApplet* cairo_dock_applet_cd_applet_construct (GType object_type, char** argv, int argv_length1);
static void _cairo_dock_applet_cd_applet_get_config (CairoDockAppletCDApplet* self);
static void _cairo_dock_applet_cd_applet_connect_to_bus (CairoDockAppletCDApplet* self);
void cairo_dock_applet_cd_applet_run (CairoDockAppletCDApplet* self);
void cairo_dock_applet_cd_applet_begin (CairoDockAppletCDApplet* self);
void cairo_dock_applet_cd_applet_on_click (CairoDockAppletCDApplet* self, gint iState);
static void cairo_dock_applet_cd_applet_real_on_click (CairoDockAppletCDApplet* self, gint iState);
void cairo_dock_applet_cd_applet_on_middle_click (CairoDockAppletCDApplet* self);
static void cairo_dock_applet_cd_applet_real_on_middle_click (CairoDockAppletCDApplet* self);
static void _cairo_dock_applet_cd_applet_on_build_menu (CairoDockAppletCDApplet* self);
void cairo_dock_applet_cd_applet_on_build_menu (CairoDockAppletCDApplet* self);
static void cairo_dock_applet_cd_applet_real_on_build_menu (CairoDockAppletCDApplet* self);
static void _cairo_dock_applet_cd_applet_on_menu_select (CairoDockAppletCDApplet* self, gint iNumEntry);
void cairo_dock_applet_cd_applet_on_menu_select (CairoDockAppletCDApplet* self, gint iNumEntry);
void cairo_dock_applet_cd_applet_on_menu_select_sub_icon (CairoDockAppletCDApplet* self, gint iNumEntry, const char* cIconID);
static void cairo_dock_applet_cd_applet_real_on_menu_select (CairoDockAppletCDApplet* self, gint iNumEntry);
void cairo_dock_applet_cd_applet_on_scroll (CairoDockAppletCDApplet* self, gboolean bScrollUp);
static void cairo_dock_applet_cd_applet_real_on_scroll (CairoDockAppletCDApplet* self, gboolean bScrollUp);
void cairo_dock_applet_cd_applet_on_drop_data (CairoDockAppletCDApplet* self, const char* cReceivedData);
static void cairo_dock_applet_cd_applet_real_on_drop_data (CairoDockAppletCDApplet* self, const char* cReceivedData);
void cairo_dock_applet_cd_applet_on_answer (CairoDockAppletCDApplet* self, GVariant* answer);
static void cairo_dock_applet_cd_applet_real_on_answer (CairoDockAppletCDApplet* self, GVariant* answer);
void cairo_dock_applet_cd_applet_on_answer_dialog (CairoDockAppletCDApplet* self, gint iButton, GVariant* answer);
static void cairo_dock_applet_cd_applet_real_on_answer_dialog (CairoDockAppletCDApplet* self, gint iButton, GVariant* answer);
void cairo_dock_applet_cd_applet_on_shortkey (CairoDockAppletCDApplet* self, const char* cKey);
static void cairo_dock_applet_cd_applet_real_on_shortkey (CairoDockAppletCDApplet* self, const char* cKey);
void cairo_dock_applet_cd_applet_on_change_focus (CairoDockAppletCDApplet* self, gboolean bIsActive);
static void cairo_dock_applet_cd_applet_real_on_change_focus (CairoDockAppletCDApplet* self, gboolean bIsActive);
void cairo_dock_applet_cd_applet_on_click_sub_icon (CairoDockAppletCDApplet* self, gint iState, const char* cIconID);
static void cairo_dock_applet_cd_applet_real_on_click_sub_icon (CairoDockAppletCDApplet* self, gint iState, const char* cIconID);
void cairo_dock_applet_cd_applet_on_middle_click_sub_icon (CairoDockAppletCDApplet* self, const char* cIconID);
static void cairo_dock_applet_cd_applet_real_on_middle_click_sub_icon (CairoDockAppletCDApplet* self, const char* cIconID);
void cairo_dock_applet_cd_applet_on_scroll_sub_icon (CairoDockAppletCDApplet* self, gboolean bScrollUp, const char* cIconID);
static void cairo_dock_applet_cd_applet_real_on_scroll_sub_icon (CairoDockAppletCDApplet* self, gboolean bScrollUp, const char* cIconID);
void cairo_dock_applet_cd_applet_on_drop_data_sub_icon (CairoDockAppletCDApplet* self, const char* cReceivedData, const char* cIconID);
static void cairo_dock_applet_cd_applet_real_on_drop_data_sub_icon (CairoDockAppletCDApplet* self, const char* cReceivedData, const char* cIconID);
static void _cairo_dock_applet_cd_applet_on_build_menu_sub_icon (CairoDockAppletCDApplet* self, const char* cIconID);
void cairo_dock_applet_cd_applet_on_build_menu_sub_icon (CairoDockAppletCDApplet* self, const char* cIconID);
static void cairo_dock_applet_cd_applet_real_on_build_menu_sub_icon (CairoDockAppletCDApplet* self, const char* cIconID);
static void cairo_dock_applet_cd_applet_real_on_menu_select_sub_icon (CairoDockAppletCDApplet* self, gint iNumEntry, const char* cIconID);
static void cairo_dock_applet_cd_applet_real_begin (CairoDockAppletCDApplet* self);
void cairo_dock_applet_cd_applet_end (CairoDockAppletCDApplet* self);
static void cairo_dock_applet_cd_applet_real_end (CairoDockAppletCDApplet* self);
static void _cairo_dock_applet_cd_applet_on_stop (CairoDockAppletCDApplet* self);
void cairo_dock_applet_cd_applet_reload (CairoDockAppletCDApplet* self);
static void cairo_dock_applet_cd_applet_real_reload (CairoDockAppletCDApplet* self);
static void _cairo_dock_applet_cd_applet_on_reload (CairoDockAppletCDApplet* self, gboolean bConfigHasChanged);
void cairo_dock_applet_cd_applet_get_config (CairoDockAppletCDApplet* self, GKeyFile* keyfile);
static void cairo_dock_applet_cd_applet_real_get_config (CairoDockAppletCDApplet* self, GKeyFile* keyfile);
static void _cairo_dock_applet_cd_applet_on_click_cairo_dock_applet_iapplet_on_click (CairoDockAppletIApplet* _sender, gint iState, gpointer self);
static void _cairo_dock_applet_cd_applet_on_middle_click_cairo_dock_applet_iapplet_on_middle_click (CairoDockAppletIApplet* _sender, gpointer self);
static void __cairo_dock_applet_cd_applet_on_build_menu_cairo_dock_applet_iapplet_on_build_menu (CairoDockAppletIApplet* _sender, gpointer self);
static void __cairo_dock_applet_cd_applet_on_menu_select_cairo_dock_applet_iapplet_on_menu_select (CairoDockAppletIApplet* _sender, gint iNumEntry, gpointer self);
static void _cairo_dock_applet_cd_applet_on_scroll_cairo_dock_applet_iapplet_on_scroll (CairoDockAppletIApplet* _sender, gboolean bScrollUp, gpointer self);
static void _cairo_dock_applet_cd_applet_on_drop_data_cairo_dock_applet_iapplet_on_drop_data (CairoDockAppletIApplet* _sender, const char* cReceivedData, gpointer self);
static void _cairo_dock_applet_cd_applet_on_answer_cairo_dock_applet_iapplet_on_answer (CairoDockAppletIApplet* _sender, GVariant* answer, gpointer self);
static void _cairo_dock_applet_cd_applet_on_answer_dialog_cairo_dock_applet_iapplet_on_answer_dialog (CairoDockAppletIApplet* _sender, gint iButton, GVariant* answer, gpointer self);
static void _cairo_dock_applet_cd_applet_on_shortkey_cairo_dock_applet_iapplet_on_shortkey (CairoDockAppletIApplet* _sender, const char* cKey, gpointer self);
static void _cairo_dock_applet_cd_applet_on_change_focus_cairo_dock_applet_iapplet_on_change_focus (CairoDockAppletIApplet* _sender, gboolean bIsActive, gpointer self);
static void __cairo_dock_applet_cd_applet_on_stop_cairo_dock_applet_iapplet_on_stop_module (CairoDockAppletIApplet* _sender, gpointer self);
static void __cairo_dock_applet_cd_applet_on_reload_cairo_dock_applet_iapplet_on_reload_module (CairoDockAppletIApplet* _sender, gboolean bConfigHasChanged, gpointer self);
static void _cairo_dock_applet_cd_applet_on_click_sub_icon_cairo_dock_applet_isub_applet_on_click_sub_icon (CairoDockAppletISubApplet* _sender, gint iState, const char* cIconID, gpointer self);
static void _cairo_dock_applet_cd_applet_on_middle_click_sub_icon_cairo_dock_applet_isub_applet_on_middle_click_sub_icon (CairoDockAppletISubApplet* _sender, const char* cIconID, gpointer self);
static void _cairo_dock_applet_cd_applet_on_scroll_sub_icon_cairo_dock_applet_isub_applet_on_scroll_sub_icon (CairoDockAppletISubApplet* _sender, gboolean bScrollUp, const char* cIconID, gpointer self);
static void _cairo_dock_applet_cd_applet_on_drop_data_sub_icon_cairo_dock_applet_isub_applet_on_drop_data_sub_icon (CairoDockAppletISubApplet* _sender, const char* cReceivedData, const char* cIconID, gpointer self);
static void __cairo_dock_applet_cd_applet_on_build_menu_sub_icon_cairo_dock_applet_isub_applet_on_build_menu_sub_icon (CairoDockAppletISubApplet* _sender, const char* cIconID, gpointer self);
static void cairo_dock_applet_cd_applet_finalize (GObject* obj);
static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func);
static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);

static const GDBusArgInfo _cairo_dock_applet_iapplet_dbus_arg_info_Get_cProperty = {-1, "cProperty", "s"};
static const GDBusArgInfo _cairo_dock_applet_iapplet_dbus_arg_info_Get_result = {-1, "result", "v"};
static const GDBusArgInfo * const _cairo_dock_applet_iapplet_dbus_arg_info_Get_in[] = {&_cairo_dock_applet_iapplet_dbus_arg_info_Get_cProperty, NULL};
static const GDBusArgInfo * const _cairo_dock_applet_iapplet_dbus_arg_info_Get_out[] = {&_cairo_dock_applet_iapplet_dbus_arg_info_Get_result, NULL};
static const GDBusMethodInfo _cairo_dock_applet_iapplet_dbus_method_info_Get = {-1, "Get", (GDBusArgInfo **) (&_cairo_dock_applet_iapplet_dbus_arg_info_Get_in), (GDBusArgInfo **) (&_cairo_dock_applet_iapplet_dbus_arg_info_Get_out)};
static const GDBusArgInfo _cairo_dock_applet_iapplet_dbus_arg_info_GetAll_result = {-1, "result", "a{sv}"};
static const GDBusArgInfo * const _cairo_dock_applet_iapplet_dbus_arg_info_GetAll_in[] = {NULL};
static const GDBusArgInfo * const _cairo_dock_applet_iapplet_dbus_arg_info_GetAll_out[] = {&_cairo_dock_applet_iapplet_dbus_arg_info_GetAll_result, NULL};
static const GDBusMethodInfo _cairo_dock_applet_iapplet_dbus_method_info_GetAll = {-1, "GetAll", (GDBusArgInfo **) (&_cairo_dock_applet_iapplet_dbus_arg_info_GetAll_in), (GDBusArgInfo **) (&_cairo_dock_applet_iapplet_dbus_arg_info_GetAll_out)};
static const GDBusArgInfo _cairo_dock_applet_iapplet_dbus_arg_info_SetQuickInfo_cQuickInfo = {-1, "cQuickInfo", "s"};
static const GDBusArgInfo * const _cairo_dock_applet_iapplet_dbus_arg_info_SetQuickInfo_in[] = {&_cairo_dock_applet_iapplet_dbus_arg_info_SetQuickInfo_cQuickInfo, NULL};
static const GDBusArgInfo * const _cairo_dock_applet_iapplet_dbus_arg_info_SetQuickInfo_out[] = {NULL};
static const GDBusMethodInfo _cairo_dock_applet_iapplet_dbus_method_info_SetQuickInfo = {-1, "SetQuickInfo", (GDBusArgInfo **) (&_cairo_dock_applet_iapplet_dbus_arg_info_SetQuickInfo_in), (GDBusArgInfo **) (&_cairo_dock_applet_iapplet_dbus_arg_info_SetQuickInfo_out)};
static const GDBusArgInfo _cairo_dock_applet_iapplet_dbus_arg_info_SetLabel_cLabel = {-1, "cLabel", "s"};
static const GDBusArgInfo * const _cairo_dock_applet_iapplet_dbus_arg_info_SetLabel_in[] = {&_cairo_dock_applet_iapplet_dbus_arg_info_SetLabel_cLabel, NULL};
static const GDBusArgInfo * const _cairo_dock_applet_iapplet_dbus_arg_info_SetLabel_out[] = {NULL};
static const GDBusMethodInfo _cairo_dock_applet_iapplet_dbus_method_info_SetLabel = {-1, "SetLabel", (GDBusArgInfo **) (&_cairo_dock_applet_iapplet_dbus_arg_info_SetLabel_in), (GDBusArgInfo **) (&_cairo_dock_applet_iapplet_dbus_arg_info_SetLabel_out)};
static const GDBusArgInfo _cairo_dock_applet_iapplet_dbus_arg_info_SetIcon_cImage = {-1, "cImage", "s"};
static const GDBusArgInfo * const _cairo_dock_applet_iapplet_dbus_arg_info_SetIcon_in[] = {&_cairo_dock_applet_iapplet_dbus_arg_info_SetIcon_cImage, NULL};
static const GDBusArgInfo * const _cairo_dock_applet_iapplet_dbus_arg_info_SetIcon_out[] = {NULL};
static const GDBusMethodInfo _cairo_dock_applet_iapplet_dbus_method_info_SetIcon = {-1, "SetIcon", (GDBusArgInfo **) (&_cairo_dock_applet_iapplet_dbus_arg_info_SetIcon_in), (GDBusArgInfo **) (&_cairo_dock_applet_iapplet_dbus_arg_info_SetIcon_out)};
static const GDBusArgInfo _cairo_dock_applet_iapplet_dbus_arg_info_SetEmblem_cImage = {-1, "cImage", "s"};
static const GDBusArgInfo _cairo_dock_applet_iapplet_dbus_arg_info_SetEmblem_iPosition = {-1, "iPosition", "i"};
static const GDBusArgInfo * const _cairo_dock_applet_iapplet_dbus_arg_info_SetEmblem_in[] = {&_cairo_dock_applet_iapplet_dbus_arg_info_SetEmblem_cImage, &_cairo_dock_applet_iapplet_dbus_arg_info_SetEmblem_iPosition, NULL};
static const GDBusArgInfo * const _cairo_dock_applet_iapplet_dbus_arg_info_SetEmblem_out[] = {NULL};
static const GDBusMethodInfo _cairo_dock_applet_iapplet_dbus_method_info_SetEmblem = {-1, "SetEmblem", (GDBusArgInfo **) (&_cairo_dock_applet_iapplet_dbus_arg_info_SetEmblem_in), (GDBusArgInfo **) (&_cairo_dock_applet_iapplet_dbus_arg_info_SetEmblem_out)};
static const GDBusArgInfo _cairo_dock_applet_iapplet_dbus_arg_info_Animate_cAnimation = {-1, "cAnimation", "s"};
static const GDBusArgInfo _cairo_dock_applet_iapplet_dbus_arg_info_Animate_iRounds = {-1, "iRounds", "i"};
static const GDBusArgInfo * const _cairo_dock_applet_iapplet_dbus_arg_info_Animate_in[] = {&_cairo_dock_applet_iapplet_dbus_arg_info_Animate_cAnimation, &_cairo_dock_applet_iapplet_dbus_arg_info_Animate_iRounds, NULL};
static const GDBusArgInfo * const _cairo_dock_applet_iapplet_dbus_arg_info_Animate_out[] = {NULL};
static const GDBusMethodInfo _cairo_dock_applet_iapplet_dbus_method_info_Animate = {-1, "Animate", (GDBusArgInfo **) (&_cairo_dock_applet_iapplet_dbus_arg_info_Animate_in), (GDBusArgInfo **) (&_cairo_dock_applet_iapplet_dbus_arg_info_Animate_out)};
static const GDBusArgInfo _cairo_dock_applet_iapplet_dbus_arg_info_DemandsAttention_bStart = {-1, "bStart", "b"};
static const GDBusArgInfo _cairo_dock_applet_iapplet_dbus_arg_info_DemandsAttention_cAnimation = {-1, "cAnimation", "s"};
static const GDBusArgInfo * const _cairo_dock_applet_iapplet_dbus_arg_info_DemandsAttention_in[] = {&_cairo_dock_applet_iapplet_dbus_arg_info_DemandsAttention_bStart, &_cairo_dock_applet_iapplet_dbus_arg_info_DemandsAttention_cAnimation, NULL};
static const GDBusArgInfo * const _cairo_dock_applet_iapplet_dbus_arg_info_DemandsAttention_out[] = {NULL};
static const GDBusMethodInfo _cairo_dock_applet_iapplet_dbus_method_info_DemandsAttention = {-1, "DemandsAttention", (GDBusArgInfo **) (&_cairo_dock_applet_iapplet_dbus_arg_info_DemandsAttention_in), (GDBusArgInfo **) (&_cairo_dock_applet_iapplet_dbus_arg_info_DemandsAttention_out)};
static const GDBusArgInfo _cairo_dock_applet_iapplet_dbus_arg_info_ShowDialog_cMessage = {-1, "cMessage", "s"};
static const GDBusArgInfo _cairo_dock_applet_iapplet_dbus_arg_info_ShowDialog_iDuration = {-1, "iDuration", "i"};
static const GDBusArgInfo * const _cairo_dock_applet_iapplet_dbus_arg_info_ShowDialog_in[] = {&_cairo_dock_applet_iapplet_dbus_arg_info_ShowDialog_cMessage, &_cairo_dock_applet_iapplet_dbus_arg_info_ShowDialog_iDuration, NULL};
static const GDBusArgInfo * const _cairo_dock_applet_iapplet_dbus_arg_info_ShowDialog_out[] = {NULL};
static const GDBusMethodInfo _cairo_dock_applet_iapplet_dbus_method_info_ShowDialog = {-1, "ShowDialog", (GDBusArgInfo **) (&_cairo_dock_applet_iapplet_dbus_arg_info_ShowDialog_in), (GDBusArgInfo **) (&_cairo_dock_applet_iapplet_dbus_arg_info_ShowDialog_out)};
static const GDBusArgInfo _cairo_dock_applet_iapplet_dbus_arg_info_PopupDialog_hDialogAttributes = {-1, "hDialogAttributes", "a{sv}"};
static const GDBusArgInfo _cairo_dock_applet_iapplet_dbus_arg_info_PopupDialog_hWidgetAttributes = {-1, "hWidgetAttributes", "a{sv}"};
static const GDBusArgInfo * const _cairo_dock_applet_iapplet_dbus_arg_info_PopupDialog_in[] = {&_cairo_dock_applet_iapplet_dbus_arg_info_PopupDialog_hDialogAttributes, &_cairo_dock_applet_iapplet_dbus_arg_info_PopupDialog_hWidgetAttributes, NULL};
static const GDBusArgInfo * const _cairo_dock_applet_iapplet_dbus_arg_info_PopupDialog_out[] = {NULL};
static const GDBusMethodInfo _cairo_dock_applet_iapplet_dbus_method_info_PopupDialog = {-1, "PopupDialog", (GDBusArgInfo **) (&_cairo_dock_applet_iapplet_dbus_arg_info_PopupDialog_in), (GDBusArgInfo **) (&_cairo_dock_applet_iapplet_dbus_arg_info_PopupDialog_out)};
static const GDBusArgInfo _cairo_dock_applet_iapplet_dbus_arg_info_AddDataRenderer_cType = {-1, "cType", "s"};
static const GDBusArgInfo _cairo_dock_applet_iapplet_dbus_arg_info_AddDataRenderer_iNbValues = {-1, "iNbValues", "i"};
static const GDBusArgInfo _cairo_dock_applet_iapplet_dbus_arg_info_AddDataRenderer_cTheme = {-1, "cTheme", "s"};
static const GDBusArgInfo * const _cairo_dock_applet_iapplet_dbus_arg_info_AddDataRenderer_in[] = {&_cairo_dock_applet_iapplet_dbus_arg_info_AddDataRenderer_cType, &_cairo_dock_applet_iapplet_dbus_arg_info_AddDataRenderer_iNbValues, &_cairo_dock_applet_iapplet_dbus_arg_info_AddDataRenderer_cTheme, NULL};
static const GDBusArgInfo * const _cairo_dock_applet_iapplet_dbus_arg_info_AddDataRenderer_out[] = {NULL};
static const GDBusMethodInfo _cairo_dock_applet_iapplet_dbus_method_info_AddDataRenderer = {-1, "AddDataRenderer", (GDBusArgInfo **) (&_cairo_dock_applet_iapplet_dbus_arg_info_AddDataRenderer_in), (GDBusArgInfo **) (&_cairo_dock_applet_iapplet_dbus_arg_info_AddDataRenderer_out)};
static const GDBusArgInfo _cairo_dock_applet_iapplet_dbus_arg_info_RenderValues_pValues = {-1, "pValues", "ad"};
static const GDBusArgInfo * const _cairo_dock_applet_iapplet_dbus_arg_info_RenderValues_in[] = {&_cairo_dock_applet_iapplet_dbus_arg_info_RenderValues_pValues, NULL};
static const GDBusArgInfo * const _cairo_dock_applet_iapplet_dbus_arg_info_RenderValues_out[] = {NULL};
static const GDBusMethodInfo _cairo_dock_applet_iapplet_dbus_method_info_RenderValues = {-1, "RenderValues", (GDBusArgInfo **) (&_cairo_dock_applet_iapplet_dbus_arg_info_RenderValues_in), (GDBusArgInfo **) (&_cairo_dock_applet_iapplet_dbus_arg_info_RenderValues_out)};
static const GDBusArgInfo _cairo_dock_applet_iapplet_dbus_arg_info_ControlAppli_cApplicationClass = {-1, "cApplicationClass", "s"};
static const GDBusArgInfo * const _cairo_dock_applet_iapplet_dbus_arg_info_ControlAppli_in[] = {&_cairo_dock_applet_iapplet_dbus_arg_info_ControlAppli_cApplicationClass, NULL};
static const GDBusArgInfo * const _cairo_dock_applet_iapplet_dbus_arg_info_ControlAppli_out[] = {NULL};
static const GDBusMethodInfo _cairo_dock_applet_iapplet_dbus_method_info_ControlAppli = {-1, "ControlAppli", (GDBusArgInfo **) (&_cairo_dock_applet_iapplet_dbus_arg_info_ControlAppli_in), (GDBusArgInfo **) (&_cairo_dock_applet_iapplet_dbus_arg_info_ControlAppli_out)};
static const GDBusArgInfo _cairo_dock_applet_iapplet_dbus_arg_info_ShowAppli_bShow = {-1, "bShow", "b"};
static const GDBusArgInfo * const _cairo_dock_applet_iapplet_dbus_arg_info_ShowAppli_in[] = {&_cairo_dock_applet_iapplet_dbus_arg_info_ShowAppli_bShow, NULL};
static const GDBusArgInfo * const _cairo_dock_applet_iapplet_dbus_arg_info_ShowAppli_out[] = {NULL};
static const GDBusMethodInfo _cairo_dock_applet_iapplet_dbus_method_info_ShowAppli = {-1, "ShowAppli", (GDBusArgInfo **) (&_cairo_dock_applet_iapplet_dbus_arg_info_ShowAppli_in), (GDBusArgInfo **) (&_cairo_dock_applet_iapplet_dbus_arg_info_ShowAppli_out)};
static const GDBusArgInfo _cairo_dock_applet_iapplet_dbus_arg_info_AddMenuItems_pItems = {-1, "pItems", "aa{sv}"};
static const GDBusArgInfo * const _cairo_dock_applet_iapplet_dbus_arg_info_AddMenuItems_in[] = {&_cairo_dock_applet_iapplet_dbus_arg_info_AddMenuItems_pItems, NULL};
static const GDBusArgInfo * const _cairo_dock_applet_iapplet_dbus_arg_info_AddMenuItems_out[] = {NULL};
static const GDBusMethodInfo _cairo_dock_applet_iapplet_dbus_method_info_AddMenuItems = {-1, "AddMenuItems", (GDBusArgInfo **) (&_cairo_dock_applet_iapplet_dbus_arg_info_AddMenuItems_in), (GDBusArgInfo **) (&_cairo_dock_applet_iapplet_dbus_arg_info_AddMenuItems_out)};
static const GDBusArgInfo _cairo_dock_applet_iapplet_dbus_arg_info_BindShortkey_cShortkeys = {-1, "cShortkeys", "as"};
static const GDBusArgInfo * const _cairo_dock_applet_iapplet_dbus_arg_info_BindShortkey_in[] = {&_cairo_dock_applet_iapplet_dbus_arg_info_BindShortkey_cShortkeys, NULL};
static const GDBusArgInfo * const _cairo_dock_applet_iapplet_dbus_arg_info_BindShortkey_out[] = {NULL};
static const GDBusMethodInfo _cairo_dock_applet_iapplet_dbus_method_info_BindShortkey = {-1, "BindShortkey", (GDBusArgInfo **) (&_cairo_dock_applet_iapplet_dbus_arg_info_BindShortkey_in), (GDBusArgInfo **) (&_cairo_dock_applet_iapplet_dbus_arg_info_BindShortkey_out)};
static const GDBusMethodInfo * const _cairo_dock_applet_iapplet_dbus_method_info[] = {&_cairo_dock_applet_iapplet_dbus_method_info_Get, &_cairo_dock_applet_iapplet_dbus_method_info_GetAll, &_cairo_dock_applet_iapplet_dbus_method_info_SetQuickInfo, &_cairo_dock_applet_iapplet_dbus_method_info_SetLabel, &_cairo_dock_applet_iapplet_dbus_method_info_SetIcon, &_cairo_dock_applet_iapplet_dbus_method_info_SetEmblem, &_cairo_dock_applet_iapplet_dbus_method_info_Animate, &_cairo_dock_applet_iapplet_dbus_method_info_DemandsAttention, &_cairo_dock_applet_iapplet_dbus_method_info_ShowDialog, &_cairo_dock_applet_iapplet_dbus_method_info_PopupDialog, &_cairo_dock_applet_iapplet_dbus_method_info_AddDataRenderer, &_cairo_dock_applet_iapplet_dbus_method_info_RenderValues, &_cairo_dock_applet_iapplet_dbus_method_info_ControlAppli, &_cairo_dock_applet_iapplet_dbus_method_info_ShowAppli, &_cairo_dock_applet_iapplet_dbus_method_info_AddMenuItems, &_cairo_dock_applet_iapplet_dbus_method_info_BindShortkey, NULL};
static const GDBusArgInfo _cairo_dock_applet_iapplet_dbus_arg_info_on_click_iState = {-1, "iState", "i"};
static const GDBusArgInfo * const _cairo_dock_applet_iapplet_dbus_arg_info_on_click[] = {&_cairo_dock_applet_iapplet_dbus_arg_info_on_click_iState, NULL};
static const GDBusSignalInfo _cairo_dock_applet_iapplet_dbus_signal_info_on_click = {-1, "on_click", (GDBusArgInfo **) (&_cairo_dock_applet_iapplet_dbus_arg_info_on_click)};
static const GDBusArgInfo * const _cairo_dock_applet_iapplet_dbus_arg_info_on_middle_click[] = {NULL};
static const GDBusSignalInfo _cairo_dock_applet_iapplet_dbus_signal_info_on_middle_click = {-1, "on_middle_click", (GDBusArgInfo **) (&_cairo_dock_applet_iapplet_dbus_arg_info_on_middle_click)};
static const GDBusArgInfo * const _cairo_dock_applet_iapplet_dbus_arg_info_on_build_menu[] = {NULL};
static const GDBusSignalInfo _cairo_dock_applet_iapplet_dbus_signal_info_on_build_menu = {-1, "on_build_menu", (GDBusArgInfo **) (&_cairo_dock_applet_iapplet_dbus_arg_info_on_build_menu)};
static const GDBusArgInfo _cairo_dock_applet_iapplet_dbus_arg_info_on_menu_select_iNumEntry = {-1, "iNumEntry", "i"};
static const GDBusArgInfo * const _cairo_dock_applet_iapplet_dbus_arg_info_on_menu_select[] = {&_cairo_dock_applet_iapplet_dbus_arg_info_on_menu_select_iNumEntry, NULL};
static const GDBusSignalInfo _cairo_dock_applet_iapplet_dbus_signal_info_on_menu_select = {-1, "on_menu_select", (GDBusArgInfo **) (&_cairo_dock_applet_iapplet_dbus_arg_info_on_menu_select)};
static const GDBusArgInfo _cairo_dock_applet_iapplet_dbus_arg_info_on_scroll_bScrollUp = {-1, "bScrollUp", "b"};
static const GDBusArgInfo * const _cairo_dock_applet_iapplet_dbus_arg_info_on_scroll[] = {&_cairo_dock_applet_iapplet_dbus_arg_info_on_scroll_bScrollUp, NULL};
static const GDBusSignalInfo _cairo_dock_applet_iapplet_dbus_signal_info_on_scroll = {-1, "on_scroll", (GDBusArgInfo **) (&_cairo_dock_applet_iapplet_dbus_arg_info_on_scroll)};
static const GDBusArgInfo _cairo_dock_applet_iapplet_dbus_arg_info_on_drop_data_cReceivedData = {-1, "cReceivedData", "s"};
static const GDBusArgInfo * const _cairo_dock_applet_iapplet_dbus_arg_info_on_drop_data[] = {&_cairo_dock_applet_iapplet_dbus_arg_info_on_drop_data_cReceivedData, NULL};
static const GDBusSignalInfo _cairo_dock_applet_iapplet_dbus_signal_info_on_drop_data = {-1, "on_drop_data", (GDBusArgInfo **) (&_cairo_dock_applet_iapplet_dbus_arg_info_on_drop_data)};
static const GDBusArgInfo _cairo_dock_applet_iapplet_dbus_arg_info_on_answer_answer = {-1, "answer", "v"};
static const GDBusArgInfo * const _cairo_dock_applet_iapplet_dbus_arg_info_on_answer[] = {&_cairo_dock_applet_iapplet_dbus_arg_info_on_answer_answer, NULL};
static const GDBusSignalInfo _cairo_dock_applet_iapplet_dbus_signal_info_on_answer = {-1, "on_answer", (GDBusArgInfo **) (&_cairo_dock_applet_iapplet_dbus_arg_info_on_answer)};
static const GDBusArgInfo _cairo_dock_applet_iapplet_dbus_arg_info_on_answer_dialog_iButton = {-1, "iButton", "i"};
static const GDBusArgInfo _cairo_dock_applet_iapplet_dbus_arg_info_on_answer_dialog_answer = {-1, "answer", "v"};
static const GDBusArgInfo * const _cairo_dock_applet_iapplet_dbus_arg_info_on_answer_dialog[] = {&_cairo_dock_applet_iapplet_dbus_arg_info_on_answer_dialog_iButton, &_cairo_dock_applet_iapplet_dbus_arg_info_on_answer_dialog_answer, NULL};
static const GDBusSignalInfo _cairo_dock_applet_iapplet_dbus_signal_info_on_answer_dialog = {-1, "on_answer_dialog", (GDBusArgInfo **) (&_cairo_dock_applet_iapplet_dbus_arg_info_on_answer_dialog)};
static const GDBusArgInfo _cairo_dock_applet_iapplet_dbus_arg_info_on_shortkey_cKey = {-1, "cKey", "s"};
static const GDBusArgInfo * const _cairo_dock_applet_iapplet_dbus_arg_info_on_shortkey[] = {&_cairo_dock_applet_iapplet_dbus_arg_info_on_shortkey_cKey, NULL};
static const GDBusSignalInfo _cairo_dock_applet_iapplet_dbus_signal_info_on_shortkey = {-1, "on_shortkey", (GDBusArgInfo **) (&_cairo_dock_applet_iapplet_dbus_arg_info_on_shortkey)};
static const GDBusArgInfo _cairo_dock_applet_iapplet_dbus_arg_info_on_change_focus_bIsActive = {-1, "bIsActive", "b"};
static const GDBusArgInfo * const _cairo_dock_applet_iapplet_dbus_arg_info_on_change_focus[] = {&_cairo_dock_applet_iapplet_dbus_arg_info_on_change_focus_bIsActive, NULL};
static const GDBusSignalInfo _cairo_dock_applet_iapplet_dbus_signal_info_on_change_focus = {-1, "on_change_focus", (GDBusArgInfo **) (&_cairo_dock_applet_iapplet_dbus_arg_info_on_change_focus)};
static const GDBusArgInfo * const _cairo_dock_applet_iapplet_dbus_arg_info_on_stop_module[] = {NULL};
static const GDBusSignalInfo _cairo_dock_applet_iapplet_dbus_signal_info_on_stop_module = {-1, "on_stop_module", (GDBusArgInfo **) (&_cairo_dock_applet_iapplet_dbus_arg_info_on_stop_module)};
static const GDBusArgInfo _cairo_dock_applet_iapplet_dbus_arg_info_on_reload_module_bConfigHasChanged = {-1, "bConfigHasChanged", "b"};
static const GDBusArgInfo * const _cairo_dock_applet_iapplet_dbus_arg_info_on_reload_module[] = {&_cairo_dock_applet_iapplet_dbus_arg_info_on_reload_module_bConfigHasChanged, NULL};
static const GDBusSignalInfo _cairo_dock_applet_iapplet_dbus_signal_info_on_reload_module = {-1, "on_reload_module", (GDBusArgInfo **) (&_cairo_dock_applet_iapplet_dbus_arg_info_on_reload_module)};
static const GDBusSignalInfo * const _cairo_dock_applet_iapplet_dbus_signal_info[] = {&_cairo_dock_applet_iapplet_dbus_signal_info_on_click, &_cairo_dock_applet_iapplet_dbus_signal_info_on_middle_click, &_cairo_dock_applet_iapplet_dbus_signal_info_on_build_menu, &_cairo_dock_applet_iapplet_dbus_signal_info_on_menu_select, &_cairo_dock_applet_iapplet_dbus_signal_info_on_scroll, &_cairo_dock_applet_iapplet_dbus_signal_info_on_drop_data, &_cairo_dock_applet_iapplet_dbus_signal_info_on_answer, &_cairo_dock_applet_iapplet_dbus_signal_info_on_answer_dialog, &_cairo_dock_applet_iapplet_dbus_signal_info_on_shortkey, &_cairo_dock_applet_iapplet_dbus_signal_info_on_change_focus, &_cairo_dock_applet_iapplet_dbus_signal_info_on_stop_module, &_cairo_dock_applet_iapplet_dbus_signal_info_on_reload_module, NULL};
static const GDBusPropertyInfo * const _cairo_dock_applet_iapplet_dbus_property_info[] = {NULL};
static const GDBusInterfaceInfo _cairo_dock_applet_iapplet_dbus_interface_info = {-1, "org.cairodock.CairoDock.applet", (GDBusMethodInfo **) (&_cairo_dock_applet_iapplet_dbus_method_info), (GDBusSignalInfo **) (&_cairo_dock_applet_iapplet_dbus_signal_info), (GDBusPropertyInfo **) (&_cairo_dock_applet_iapplet_dbus_property_info)};
static const GDBusInterfaceVTable _cairo_dock_applet_iapplet_dbus_interface_vtable = {cairo_dock_applet_iapplet_dbus_interface_method_call, cairo_dock_applet_iapplet_dbus_interface_get_property, cairo_dock_applet_iapplet_dbus_interface_set_property};
static const GDBusArgInfo _cairo_dock_applet_isub_applet_dbus_arg_info_SetQuickInfo_cQuickInfo = {-1, "cQuickInfo", "s"};
static const GDBusArgInfo _cairo_dock_applet_isub_applet_dbus_arg_info_SetQuickInfo_cIconID = {-1, "cIconID", "s"};
static const GDBusArgInfo * const _cairo_dock_applet_isub_applet_dbus_arg_info_SetQuickInfo_in[] = {&_cairo_dock_applet_isub_applet_dbus_arg_info_SetQuickInfo_cQuickInfo, &_cairo_dock_applet_isub_applet_dbus_arg_info_SetQuickInfo_cIconID, NULL};
static const GDBusArgInfo * const _cairo_dock_applet_isub_applet_dbus_arg_info_SetQuickInfo_out[] = {NULL};
static const GDBusMethodInfo _cairo_dock_applet_isub_applet_dbus_method_info_SetQuickInfo = {-1, "SetQuickInfo", (GDBusArgInfo **) (&_cairo_dock_applet_isub_applet_dbus_arg_info_SetQuickInfo_in), (GDBusArgInfo **) (&_cairo_dock_applet_isub_applet_dbus_arg_info_SetQuickInfo_out)};
static const GDBusArgInfo _cairo_dock_applet_isub_applet_dbus_arg_info_SetLabel_cLabel = {-1, "cLabel", "s"};
static const GDBusArgInfo _cairo_dock_applet_isub_applet_dbus_arg_info_SetLabel_cIconID = {-1, "cIconID", "s"};
static const GDBusArgInfo * const _cairo_dock_applet_isub_applet_dbus_arg_info_SetLabel_in[] = {&_cairo_dock_applet_isub_applet_dbus_arg_info_SetLabel_cLabel, &_cairo_dock_applet_isub_applet_dbus_arg_info_SetLabel_cIconID, NULL};
static const GDBusArgInfo * const _cairo_dock_applet_isub_applet_dbus_arg_info_SetLabel_out[] = {NULL};
static const GDBusMethodInfo _cairo_dock_applet_isub_applet_dbus_method_info_SetLabel = {-1, "SetLabel", (GDBusArgInfo **) (&_cairo_dock_applet_isub_applet_dbus_arg_info_SetLabel_in), (GDBusArgInfo **) (&_cairo_dock_applet_isub_applet_dbus_arg_info_SetLabel_out)};
static const GDBusArgInfo _cairo_dock_applet_isub_applet_dbus_arg_info_SetIcon_cImage = {-1, "cImage", "s"};
static const GDBusArgInfo _cairo_dock_applet_isub_applet_dbus_arg_info_SetIcon_cIconID = {-1, "cIconID", "s"};
static const GDBusArgInfo * const _cairo_dock_applet_isub_applet_dbus_arg_info_SetIcon_in[] = {&_cairo_dock_applet_isub_applet_dbus_arg_info_SetIcon_cImage, &_cairo_dock_applet_isub_applet_dbus_arg_info_SetIcon_cIconID, NULL};
static const GDBusArgInfo * const _cairo_dock_applet_isub_applet_dbus_arg_info_SetIcon_out[] = {NULL};
static const GDBusMethodInfo _cairo_dock_applet_isub_applet_dbus_method_info_SetIcon = {-1, "SetIcon", (GDBusArgInfo **) (&_cairo_dock_applet_isub_applet_dbus_arg_info_SetIcon_in), (GDBusArgInfo **) (&_cairo_dock_applet_isub_applet_dbus_arg_info_SetIcon_out)};
static const GDBusArgInfo _cairo_dock_applet_isub_applet_dbus_arg_info_SetEmblem_cImage = {-1, "cImage", "s"};
static const GDBusArgInfo _cairo_dock_applet_isub_applet_dbus_arg_info_SetEmblem_iPosition = {-1, "iPosition", "i"};
static const GDBusArgInfo _cairo_dock_applet_isub_applet_dbus_arg_info_SetEmblem_cIconID = {-1, "cIconID", "s"};
static const GDBusArgInfo * const _cairo_dock_applet_isub_applet_dbus_arg_info_SetEmblem_in[] = {&_cairo_dock_applet_isub_applet_dbus_arg_info_SetEmblem_cImage, &_cairo_dock_applet_isub_applet_dbus_arg_info_SetEmblem_iPosition, &_cairo_dock_applet_isub_applet_dbus_arg_info_SetEmblem_cIconID, NULL};
static const GDBusArgInfo * const _cairo_dock_applet_isub_applet_dbus_arg_info_SetEmblem_out[] = {NULL};
static const GDBusMethodInfo _cairo_dock_applet_isub_applet_dbus_method_info_SetEmblem = {-1, "SetEmblem", (GDBusArgInfo **) (&_cairo_dock_applet_isub_applet_dbus_arg_info_SetEmblem_in), (GDBusArgInfo **) (&_cairo_dock_applet_isub_applet_dbus_arg_info_SetEmblem_out)};
static const GDBusArgInfo _cairo_dock_applet_isub_applet_dbus_arg_info_Animate_cAnimation = {-1, "cAnimation", "s"};
static const GDBusArgInfo _cairo_dock_applet_isub_applet_dbus_arg_info_Animate_iNbRounds = {-1, "iNbRounds", "i"};
static const GDBusArgInfo _cairo_dock_applet_isub_applet_dbus_arg_info_Animate_cIconID = {-1, "cIconID", "s"};
static const GDBusArgInfo * const _cairo_dock_applet_isub_applet_dbus_arg_info_Animate_in[] = {&_cairo_dock_applet_isub_applet_dbus_arg_info_Animate_cAnimation, &_cairo_dock_applet_isub_applet_dbus_arg_info_Animate_iNbRounds, &_cairo_dock_applet_isub_applet_dbus_arg_info_Animate_cIconID, NULL};
static const GDBusArgInfo * const _cairo_dock_applet_isub_applet_dbus_arg_info_Animate_out[] = {NULL};
static const GDBusMethodInfo _cairo_dock_applet_isub_applet_dbus_method_info_Animate = {-1, "Animate", (GDBusArgInfo **) (&_cairo_dock_applet_isub_applet_dbus_arg_info_Animate_in), (GDBusArgInfo **) (&_cairo_dock_applet_isub_applet_dbus_arg_info_Animate_out)};
static const GDBusArgInfo _cairo_dock_applet_isub_applet_dbus_arg_info_ShowDialog_message = {-1, "message", "s"};
static const GDBusArgInfo _cairo_dock_applet_isub_applet_dbus_arg_info_ShowDialog_iDuration = {-1, "iDuration", "i"};
static const GDBusArgInfo _cairo_dock_applet_isub_applet_dbus_arg_info_ShowDialog_cIconID = {-1, "cIconID", "s"};
static const GDBusArgInfo * const _cairo_dock_applet_isub_applet_dbus_arg_info_ShowDialog_in[] = {&_cairo_dock_applet_isub_applet_dbus_arg_info_ShowDialog_message, &_cairo_dock_applet_isub_applet_dbus_arg_info_ShowDialog_iDuration, &_cairo_dock_applet_isub_applet_dbus_arg_info_ShowDialog_cIconID, NULL};
static const GDBusArgInfo * const _cairo_dock_applet_isub_applet_dbus_arg_info_ShowDialog_out[] = {NULL};
static const GDBusMethodInfo _cairo_dock_applet_isub_applet_dbus_method_info_ShowDialog = {-1, "ShowDialog", (GDBusArgInfo **) (&_cairo_dock_applet_isub_applet_dbus_arg_info_ShowDialog_in), (GDBusArgInfo **) (&_cairo_dock_applet_isub_applet_dbus_arg_info_ShowDialog_out)};
static const GDBusArgInfo _cairo_dock_applet_isub_applet_dbus_arg_info_AddSubIcons_pIconFields = {-1, "pIconFields", "as"};
static const GDBusArgInfo * const _cairo_dock_applet_isub_applet_dbus_arg_info_AddSubIcons_in[] = {&_cairo_dock_applet_isub_applet_dbus_arg_info_AddSubIcons_pIconFields, NULL};
static const GDBusArgInfo * const _cairo_dock_applet_isub_applet_dbus_arg_info_AddSubIcons_out[] = {NULL};
static const GDBusMethodInfo _cairo_dock_applet_isub_applet_dbus_method_info_AddSubIcons = {-1, "AddSubIcons", (GDBusArgInfo **) (&_cairo_dock_applet_isub_applet_dbus_arg_info_AddSubIcons_in), (GDBusArgInfo **) (&_cairo_dock_applet_isub_applet_dbus_arg_info_AddSubIcons_out)};
static const GDBusArgInfo _cairo_dock_applet_isub_applet_dbus_arg_info_RemoveSubIcon_cIconID = {-1, "cIconID", "s"};
static const GDBusArgInfo * const _cairo_dock_applet_isub_applet_dbus_arg_info_RemoveSubIcon_in[] = {&_cairo_dock_applet_isub_applet_dbus_arg_info_RemoveSubIcon_cIconID, NULL};
static const GDBusArgInfo * const _cairo_dock_applet_isub_applet_dbus_arg_info_RemoveSubIcon_out[] = {NULL};
static const GDBusMethodInfo _cairo_dock_applet_isub_applet_dbus_method_info_RemoveSubIcon = {-1, "RemoveSubIcon", (GDBusArgInfo **) (&_cairo_dock_applet_isub_applet_dbus_arg_info_RemoveSubIcon_in), (GDBusArgInfo **) (&_cairo_dock_applet_isub_applet_dbus_arg_info_RemoveSubIcon_out)};
static const GDBusMethodInfo * const _cairo_dock_applet_isub_applet_dbus_method_info[] = {&_cairo_dock_applet_isub_applet_dbus_method_info_SetQuickInfo, &_cairo_dock_applet_isub_applet_dbus_method_info_SetLabel, &_cairo_dock_applet_isub_applet_dbus_method_info_SetIcon, &_cairo_dock_applet_isub_applet_dbus_method_info_SetEmblem, &_cairo_dock_applet_isub_applet_dbus_method_info_Animate, &_cairo_dock_applet_isub_applet_dbus_method_info_ShowDialog, &_cairo_dock_applet_isub_applet_dbus_method_info_AddSubIcons, &_cairo_dock_applet_isub_applet_dbus_method_info_RemoveSubIcon, NULL};
static const GDBusArgInfo _cairo_dock_applet_isub_applet_dbus_arg_info_on_click_sub_icon_iState = {-1, "iState", "i"};
static const GDBusArgInfo _cairo_dock_applet_isub_applet_dbus_arg_info_on_click_sub_icon_cIconID = {-1, "cIconID", "s"};
static const GDBusArgInfo * const _cairo_dock_applet_isub_applet_dbus_arg_info_on_click_sub_icon[] = {&_cairo_dock_applet_isub_applet_dbus_arg_info_on_click_sub_icon_iState, &_cairo_dock_applet_isub_applet_dbus_arg_info_on_click_sub_icon_cIconID, NULL};
static const GDBusSignalInfo _cairo_dock_applet_isub_applet_dbus_signal_info_on_click_sub_icon = {-1, "on_clickSubIcon", (GDBusArgInfo **) (&_cairo_dock_applet_isub_applet_dbus_arg_info_on_click_sub_icon)};
static const GDBusArgInfo _cairo_dock_applet_isub_applet_dbus_arg_info_on_middle_click_sub_icon_cIconID = {-1, "cIconID", "s"};
static const GDBusArgInfo * const _cairo_dock_applet_isub_applet_dbus_arg_info_on_middle_click_sub_icon[] = {&_cairo_dock_applet_isub_applet_dbus_arg_info_on_middle_click_sub_icon_cIconID, NULL};
static const GDBusSignalInfo _cairo_dock_applet_isub_applet_dbus_signal_info_on_middle_click_sub_icon = {-1, "on_middle_clickSubIcon", (GDBusArgInfo **) (&_cairo_dock_applet_isub_applet_dbus_arg_info_on_middle_click_sub_icon)};
static const GDBusArgInfo _cairo_dock_applet_isub_applet_dbus_arg_info_on_scroll_sub_icon_bScrollUp = {-1, "bScrollUp", "b"};
static const GDBusArgInfo _cairo_dock_applet_isub_applet_dbus_arg_info_on_scroll_sub_icon_cIconID = {-1, "cIconID", "s"};
static const GDBusArgInfo * const _cairo_dock_applet_isub_applet_dbus_arg_info_on_scroll_sub_icon[] = {&_cairo_dock_applet_isub_applet_dbus_arg_info_on_scroll_sub_icon_bScrollUp, &_cairo_dock_applet_isub_applet_dbus_arg_info_on_scroll_sub_icon_cIconID, NULL};
static const GDBusSignalInfo _cairo_dock_applet_isub_applet_dbus_signal_info_on_scroll_sub_icon = {-1, "on_scrollSubIcon", (GDBusArgInfo **) (&_cairo_dock_applet_isub_applet_dbus_arg_info_on_scroll_sub_icon)};
static const GDBusArgInfo _cairo_dock_applet_isub_applet_dbus_arg_info_on_drop_data_sub_icon_cReceivedData = {-1, "cReceivedData", "s"};
static const GDBusArgInfo _cairo_dock_applet_isub_applet_dbus_arg_info_on_drop_data_sub_icon_cIconID = {-1, "cIconID", "s"};
static const GDBusArgInfo * const _cairo_dock_applet_isub_applet_dbus_arg_info_on_drop_data_sub_icon[] = {&_cairo_dock_applet_isub_applet_dbus_arg_info_on_drop_data_sub_icon_cReceivedData, &_cairo_dock_applet_isub_applet_dbus_arg_info_on_drop_data_sub_icon_cIconID, NULL};
static const GDBusSignalInfo _cairo_dock_applet_isub_applet_dbus_signal_info_on_drop_data_sub_icon = {-1, "on_drop_dataSubIcon", (GDBusArgInfo **) (&_cairo_dock_applet_isub_applet_dbus_arg_info_on_drop_data_sub_icon)};
static const GDBusArgInfo _cairo_dock_applet_isub_applet_dbus_arg_info_on_build_menu_sub_icon_cIconID = {-1, "cIconID", "s"};
static const GDBusArgInfo * const _cairo_dock_applet_isub_applet_dbus_arg_info_on_build_menu_sub_icon[] = {&_cairo_dock_applet_isub_applet_dbus_arg_info_on_build_menu_sub_icon_cIconID, NULL};
static const GDBusSignalInfo _cairo_dock_applet_isub_applet_dbus_signal_info_on_build_menu_sub_icon = {-1, "on_build_menuSubIcon", (GDBusArgInfo **) (&_cairo_dock_applet_isub_applet_dbus_arg_info_on_build_menu_sub_icon)};
static const GDBusSignalInfo * const _cairo_dock_applet_isub_applet_dbus_signal_info[] = {&_cairo_dock_applet_isub_applet_dbus_signal_info_on_click_sub_icon, &_cairo_dock_applet_isub_applet_dbus_signal_info_on_middle_click_sub_icon, &_cairo_dock_applet_isub_applet_dbus_signal_info_on_scroll_sub_icon, &_cairo_dock_applet_isub_applet_dbus_signal_info_on_drop_data_sub_icon, &_cairo_dock_applet_isub_applet_dbus_signal_info_on_build_menu_sub_icon, NULL};
static const GDBusPropertyInfo * const _cairo_dock_applet_isub_applet_dbus_property_info[] = {NULL};
static const GDBusInterfaceInfo _cairo_dock_applet_isub_applet_dbus_interface_info = {-1, "org.cairodock.CairoDock.subapplet", (GDBusMethodInfo **) (&_cairo_dock_applet_isub_applet_dbus_method_info), (GDBusSignalInfo **) (&_cairo_dock_applet_isub_applet_dbus_signal_info), (GDBusPropertyInfo **) (&_cairo_dock_applet_isub_applet_dbus_property_info)};
static const GDBusInterfaceVTable _cairo_dock_applet_isub_applet_dbus_interface_vtable = {cairo_dock_applet_isub_applet_dbus_interface_method_call, cairo_dock_applet_isub_applet_dbus_interface_get_property, cairo_dock_applet_isub_applet_dbus_interface_set_property};

static void g_cclosure_user_marshal_VOID__VARIANT (GClosure * closure, GValue * return_value, guint n_param_values, const GValue * param_values, gpointer invocation_hint, gpointer marshal_data);
static void g_cclosure_user_marshal_VOID__INT_VARIANT (GClosure * closure, GValue * return_value, guint n_param_values, const GValue * param_values, gpointer invocation_hint, gpointer marshal_data);
static void g_cclosure_user_marshal_VOID__INT_STRING (GClosure * closure, GValue * return_value, guint n_param_values, const GValue * param_values, gpointer invocation_hint, gpointer marshal_data);
static void g_cclosure_user_marshal_VOID__BOOLEAN_STRING (GClosure * closure, GValue * return_value, guint n_param_values, const GValue * param_values, gpointer invocation_hint, gpointer marshal_data);
static void g_cclosure_user_marshal_VOID__STRING_STRING (GClosure * closure, GValue * return_value, guint n_param_values, const GValue * param_values, gpointer invocation_hint, gpointer marshal_data);

GVariant* cairo_dock_applet_iapplet_Get (CairoDockAppletIApplet* self, const char* cProperty, GError** error) {
	return CAIRO_DOCK_APPLET_IAPPLET_GET_INTERFACE (self)->Get (self, cProperty, error);
}


GHashTable* cairo_dock_applet_iapplet_GetAll (CairoDockAppletIApplet* self, GError** error) {
	return CAIRO_DOCK_APPLET_IAPPLET_GET_INTERFACE (self)->GetAll (self, error);
}


void cairo_dock_applet_iapplet_SetQuickInfo (CairoDockAppletIApplet* self, const char* cQuickInfo, GError** error) {
	CAIRO_DOCK_APPLET_IAPPLET_GET_INTERFACE (self)->SetQuickInfo (self, cQuickInfo, error);
}


void cairo_dock_applet_iapplet_SetLabel (CairoDockAppletIApplet* self, const char* cLabel, GError** error) {
	CAIRO_DOCK_APPLET_IAPPLET_GET_INTERFACE (self)->SetLabel (self, cLabel, error);
}


void cairo_dock_applet_iapplet_SetIcon (CairoDockAppletIApplet* self, const char* cImage, GError** error) {
	CAIRO_DOCK_APPLET_IAPPLET_GET_INTERFACE (self)->SetIcon (self, cImage, error);
}


void cairo_dock_applet_iapplet_SetEmblem (CairoDockAppletIApplet* self, const char* cImage, gint iPosition, GError** error) {
	CAIRO_DOCK_APPLET_IAPPLET_GET_INTERFACE (self)->SetEmblem (self, cImage, iPosition, error);
}


void cairo_dock_applet_iapplet_Animate (CairoDockAppletIApplet* self, const char* cAnimation, gint iRounds, GError** error) {
	CAIRO_DOCK_APPLET_IAPPLET_GET_INTERFACE (self)->Animate (self, cAnimation, iRounds, error);
}


void cairo_dock_applet_iapplet_DemandsAttention (CairoDockAppletIApplet* self, gboolean bStart, const char* cAnimation, GError** error) {
	CAIRO_DOCK_APPLET_IAPPLET_GET_INTERFACE (self)->DemandsAttention (self, bStart, cAnimation, error);
}


void cairo_dock_applet_iapplet_ShowDialog (CairoDockAppletIApplet* self, const char* cMessage, gint iDuration, GError** error) {
	CAIRO_DOCK_APPLET_IAPPLET_GET_INTERFACE (self)->ShowDialog (self, cMessage, iDuration, error);
}


void cairo_dock_applet_iapplet_PopupDialog (CairoDockAppletIApplet* self, GHashTable* hDialogAttributes, GHashTable* hWidgetAttributes, GError** error) {
	CAIRO_DOCK_APPLET_IAPPLET_GET_INTERFACE (self)->PopupDialog (self, hDialogAttributes, hWidgetAttributes, error);
}


void cairo_dock_applet_iapplet_AddDataRenderer (CairoDockAppletIApplet* self, const char* cType, gint iNbValues, const char* cTheme, GError** error) {
	CAIRO_DOCK_APPLET_IAPPLET_GET_INTERFACE (self)->AddDataRenderer (self, cType, iNbValues, cTheme, error);
}


void cairo_dock_applet_iapplet_RenderValues (CairoDockAppletIApplet* self, double* pValues, int pValues_length1, GError** error) {
	CAIRO_DOCK_APPLET_IAPPLET_GET_INTERFACE (self)->RenderValues (self, pValues, pValues_length1, error);
}


void cairo_dock_applet_iapplet_ControlAppli (CairoDockAppletIApplet* self, const char* cApplicationClass, GError** error) {
	CAIRO_DOCK_APPLET_IAPPLET_GET_INTERFACE (self)->ControlAppli (self, cApplicationClass, error);
}


void cairo_dock_applet_iapplet_ShowAppli (CairoDockAppletIApplet* self, gboolean bShow, GError** error) {
	CAIRO_DOCK_APPLET_IAPPLET_GET_INTERFACE (self)->ShowAppli (self, bShow, error);
}


void cairo_dock_applet_iapplet_AddMenuItems (CairoDockAppletIApplet* self, GHashTable** pItems, int pItems_length1, GError** error) {
	CAIRO_DOCK_APPLET_IAPPLET_GET_INTERFACE (self)->AddMenuItems (self, pItems, pItems_length1, error);
}


void cairo_dock_applet_iapplet_BindShortkey (CairoDockAppletIApplet* self, char** cShortkeys, int cShortkeys_length1, GError** error) {
	CAIRO_DOCK_APPLET_IAPPLET_GET_INTERFACE (self)->BindShortkey (self, cShortkeys, cShortkeys_length1, error);
}


static void cairo_dock_applet_iapplet_base_init (CairoDockAppletIAppletIface * iface) {
	static gboolean initialized = FALSE;
	if (!initialized) {
		initialized = TRUE;
		g_signal_new ("on_click", CAIRO_DOCK_APPLET_TYPE_IAPPLET, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__INT, G_TYPE_NONE, 1, G_TYPE_INT);
		g_signal_new ("on_middle_click", CAIRO_DOCK_APPLET_TYPE_IAPPLET, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__VOID, G_TYPE_NONE, 0);
		g_signal_new ("on_build_menu", CAIRO_DOCK_APPLET_TYPE_IAPPLET, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__VOID, G_TYPE_NONE, 0);
		g_signal_new ("on_menu_select", CAIRO_DOCK_APPLET_TYPE_IAPPLET, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__INT, G_TYPE_NONE, 1, G_TYPE_INT);
		g_signal_new ("on_scroll", CAIRO_DOCK_APPLET_TYPE_IAPPLET, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__BOOLEAN, G_TYPE_NONE, 1, G_TYPE_BOOLEAN);
		g_signal_new ("on_drop_data", CAIRO_DOCK_APPLET_TYPE_IAPPLET, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__STRING, G_TYPE_NONE, 1, G_TYPE_STRING);
		g_signal_new ("on_answer", CAIRO_DOCK_APPLET_TYPE_IAPPLET, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_user_marshal_VOID__VARIANT, G_TYPE_NONE, 1, G_TYPE_VARIANT);
		g_signal_new ("on_answer_dialog", CAIRO_DOCK_APPLET_TYPE_IAPPLET, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_user_marshal_VOID__INT_VARIANT, G_TYPE_NONE, 2, G_TYPE_INT, G_TYPE_VARIANT);
		g_signal_new ("on_shortkey", CAIRO_DOCK_APPLET_TYPE_IAPPLET, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__STRING, G_TYPE_NONE, 1, G_TYPE_STRING);
		g_signal_new ("on_change_focus", CAIRO_DOCK_APPLET_TYPE_IAPPLET, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__BOOLEAN, G_TYPE_NONE, 1, G_TYPE_BOOLEAN);
		g_signal_new ("on_stop_module", CAIRO_DOCK_APPLET_TYPE_IAPPLET, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__VOID, G_TYPE_NONE, 0);
		g_signal_new ("on_reload_module", CAIRO_DOCK_APPLET_TYPE_IAPPLET, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__BOOLEAN, G_TYPE_NONE, 1, G_TYPE_BOOLEAN);
	}
}


GType cairo_dock_applet_iapplet_get_type (void) {
	static volatile gsize cairo_dock_applet_iapplet_type_id__volatile = 0;
	if (g_once_init_enter (&cairo_dock_applet_iapplet_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (CairoDockAppletIAppletIface), (GBaseInitFunc) cairo_dock_applet_iapplet_base_init, (GBaseFinalizeFunc) NULL, (GClassInitFunc) NULL, (GClassFinalizeFunc) NULL, NULL, 0, 0, (GInstanceInitFunc) NULL, NULL };
		GType cairo_dock_applet_iapplet_type_id;
		cairo_dock_applet_iapplet_type_id = g_type_register_static (G_TYPE_INTERFACE, "CairoDockAppletIApplet", &g_define_type_info, 0);
		g_type_interface_add_prerequisite (cairo_dock_applet_iapplet_type_id, G_TYPE_OBJECT);
		g_once_init_leave (&cairo_dock_applet_iapplet_type_id__volatile, cairo_dock_applet_iapplet_type_id);
	}
	return cairo_dock_applet_iapplet_type_id__volatile;
}


G_DEFINE_TYPE_EXTENDED (CairoDockAppletIAppletProxy, cairo_dock_applet_iapplet_proxy, G_TYPE_DBUS_PROXY, 0, G_IMPLEMENT_INTERFACE (CAIRO_DOCK_APPLET_TYPE_IAPPLET, cairo_dock_applet_iapplet_proxy_cairo_dock_applet_iapplet_interface_init) );
static void cairo_dock_applet_iapplet_proxy_class_init (CairoDockAppletIAppletProxyClass* klass) {
	G_DBUS_PROXY_CLASS (klass)->g_signal = cairo_dock_applet_iapplet_proxy_g_signal;
}


static void _dbus_handle_cairo_dock_applet_iapplet_on_click (CairoDockAppletIApplet* self, GVariant* parameters) {
	gint iState = 0;
	GVariant* _tmp0_;
	GVariantIter _arguments_iter;
	g_variant_iter_init (&_arguments_iter, parameters);
	_tmp0_ = g_variant_iter_next_value (&_arguments_iter);
	iState = g_variant_get_int32 (_tmp0_);
	g_variant_unref (_tmp0_);
	g_signal_emit_by_name (self, "on-click", iState);
}


static void _dbus_handle_cairo_dock_applet_iapplet_on_middle_click (CairoDockAppletIApplet* self, GVariant* parameters) {
	GVariantIter _arguments_iter;
	g_variant_iter_init (&_arguments_iter, parameters);
	g_signal_emit_by_name (self, "on-middle-click");
}


static void _dbus_handle_cairo_dock_applet_iapplet_on_build_menu (CairoDockAppletIApplet* self, GVariant* parameters) {
	GVariantIter _arguments_iter;
	g_variant_iter_init (&_arguments_iter, parameters);
	g_signal_emit_by_name (self, "on-build-menu");
}


static void _dbus_handle_cairo_dock_applet_iapplet_on_menu_select (CairoDockAppletIApplet* self, GVariant* parameters) {
	gint iNumEntry = 0;
	GVariant* _tmp1_;
	GVariantIter _arguments_iter;
	g_variant_iter_init (&_arguments_iter, parameters);
	_tmp1_ = g_variant_iter_next_value (&_arguments_iter);
	iNumEntry = g_variant_get_int32 (_tmp1_);
	g_variant_unref (_tmp1_);
	g_signal_emit_by_name (self, "on-menu-select", iNumEntry);
}


static void _dbus_handle_cairo_dock_applet_iapplet_on_scroll (CairoDockAppletIApplet* self, GVariant* parameters) {
	gboolean bScrollUp = FALSE;
	GVariant* _tmp2_;
	GVariantIter _arguments_iter;
	g_variant_iter_init (&_arguments_iter, parameters);
	_tmp2_ = g_variant_iter_next_value (&_arguments_iter);
	bScrollUp = g_variant_get_boolean (_tmp2_);
	g_variant_unref (_tmp2_);
	g_signal_emit_by_name (self, "on-scroll", bScrollUp);
}


static void _dbus_handle_cairo_dock_applet_iapplet_on_drop_data (CairoDockAppletIApplet* self, GVariant* parameters) {
	char* cReceivedData = NULL;
	GVariant* _tmp3_;
	GVariantIter _arguments_iter;
	g_variant_iter_init (&_arguments_iter, parameters);
	_tmp3_ = g_variant_iter_next_value (&_arguments_iter);
	cReceivedData = g_variant_dup_string (_tmp3_, NULL);
	g_variant_unref (_tmp3_);
	g_signal_emit_by_name (self, "on-drop-data", cReceivedData);
	_g_free0 (cReceivedData);
}


static void _dbus_handle_cairo_dock_applet_iapplet_on_answer (CairoDockAppletIApplet* self, GVariant* parameters) {
	GVariant* answer = NULL;
	GVariant* _tmp4_;
	GVariantIter _arguments_iter;
	g_variant_iter_init (&_arguments_iter, parameters);
	_tmp4_ = g_variant_iter_next_value (&_arguments_iter);
	answer = g_variant_get_variant (_tmp4_);
	g_variant_unref (_tmp4_);
	g_signal_emit_by_name (self, "on-answer", answer);
	_g_variant_unref0 (answer);
}


static void _dbus_handle_cairo_dock_applet_iapplet_on_answer_dialog (CairoDockAppletIApplet* self, GVariant* parameters) {
	gint iButton = 0;
	GVariant* _tmp5_;
	GVariant* answer = NULL;
	GVariant* _tmp6_;
	GVariantIter _arguments_iter;
	g_variant_iter_init (&_arguments_iter, parameters);
	_tmp5_ = g_variant_iter_next_value (&_arguments_iter);
	iButton = g_variant_get_int32 (_tmp5_);
	g_variant_unref (_tmp5_);
	_tmp6_ = g_variant_iter_next_value (&_arguments_iter);
	answer = g_variant_get_variant (_tmp6_);
	g_variant_unref (_tmp6_);
	g_signal_emit_by_name (self, "on-answer-dialog", iButton, answer);
	_g_variant_unref0 (answer);
}


static void _dbus_handle_cairo_dock_applet_iapplet_on_shortkey (CairoDockAppletIApplet* self, GVariant* parameters) {
	char* cKey = NULL;
	GVariant* _tmp7_;
	GVariantIter _arguments_iter;
	g_variant_iter_init (&_arguments_iter, parameters);
	_tmp7_ = g_variant_iter_next_value (&_arguments_iter);
	cKey = g_variant_dup_string (_tmp7_, NULL);
	g_variant_unref (_tmp7_);
	g_signal_emit_by_name (self, "on-shortkey", cKey);
	_g_free0 (cKey);
}


static void _dbus_handle_cairo_dock_applet_iapplet_on_change_focus (CairoDockAppletIApplet* self, GVariant* parameters) {
	gboolean bIsActive = FALSE;
	GVariant* _tmp8_;
	GVariantIter _arguments_iter;
	g_variant_iter_init (&_arguments_iter, parameters);
	_tmp8_ = g_variant_iter_next_value (&_arguments_iter);
	bIsActive = g_variant_get_boolean (_tmp8_);
	g_variant_unref (_tmp8_);
	g_signal_emit_by_name (self, "on-change-focus", bIsActive);
}


static void _dbus_handle_cairo_dock_applet_iapplet_on_stop_module (CairoDockAppletIApplet* self, GVariant* parameters) {
	GVariantIter _arguments_iter;
	g_variant_iter_init (&_arguments_iter, parameters);
	g_signal_emit_by_name (self, "on-stop-module");
}


static void _dbus_handle_cairo_dock_applet_iapplet_on_reload_module (CairoDockAppletIApplet* self, GVariant* parameters) {
	gboolean bConfigHasChanged = FALSE;
	GVariant* _tmp9_;
	GVariantIter _arguments_iter;
	g_variant_iter_init (&_arguments_iter, parameters);
	_tmp9_ = g_variant_iter_next_value (&_arguments_iter);
	bConfigHasChanged = g_variant_get_boolean (_tmp9_);
	g_variant_unref (_tmp9_);
	g_signal_emit_by_name (self, "on-reload-module", bConfigHasChanged);
}


static void cairo_dock_applet_iapplet_proxy_g_signal (GDBusProxy* proxy, const gchar* sender_name, const gchar* signal_name, GVariant* parameters) {
	if (strcmp (signal_name, "on_click") == 0) {
		_dbus_handle_cairo_dock_applet_iapplet_on_click (proxy, parameters);
	} else if (strcmp (signal_name, "on_middle_click") == 0) {
		_dbus_handle_cairo_dock_applet_iapplet_on_middle_click (proxy, parameters);
	} else if (strcmp (signal_name, "on_build_menu") == 0) {
		_dbus_handle_cairo_dock_applet_iapplet_on_build_menu (proxy, parameters);
	} else if (strcmp (signal_name, "on_menu_select") == 0) {
		_dbus_handle_cairo_dock_applet_iapplet_on_menu_select (proxy, parameters);
	} else if (strcmp (signal_name, "on_scroll") == 0) {
		_dbus_handle_cairo_dock_applet_iapplet_on_scroll (proxy, parameters);
	} else if (strcmp (signal_name, "on_drop_data") == 0) {
		_dbus_handle_cairo_dock_applet_iapplet_on_drop_data (proxy, parameters);
	} else if (strcmp (signal_name, "on_answer") == 0) {
		_dbus_handle_cairo_dock_applet_iapplet_on_answer (proxy, parameters);
	} else if (strcmp (signal_name, "on_answer_dialog") == 0) {
		_dbus_handle_cairo_dock_applet_iapplet_on_answer_dialog (proxy, parameters);
	} else if (strcmp (signal_name, "on_shortkey") == 0) {
		_dbus_handle_cairo_dock_applet_iapplet_on_shortkey (proxy, parameters);
	} else if (strcmp (signal_name, "on_change_focus") == 0) {
		_dbus_handle_cairo_dock_applet_iapplet_on_change_focus (proxy, parameters);
	} else if (strcmp (signal_name, "on_stop_module") == 0) {
		_dbus_handle_cairo_dock_applet_iapplet_on_stop_module (proxy, parameters);
	} else if (strcmp (signal_name, "on_reload_module") == 0) {
		_dbus_handle_cairo_dock_applet_iapplet_on_reload_module (proxy, parameters);
	}
}


static void cairo_dock_applet_iapplet_proxy_init (CairoDockAppletIAppletProxy* self) {
}


static GVariant* cairo_dock_applet_iapplet_proxy_Get (CairoDockAppletIApplet* self, const char* cProperty, GError** error) {
	GVariant *_arguments, *_reply;
	GVariantBuilder _arguments_builder;
	GVariantIter _reply_iter;
	GVariant* _result;
	GVariant* _tmp10_;
	g_variant_builder_init (&_arguments_builder, G_VARIANT_TYPE_TUPLE);
	g_variant_builder_add_value (&_arguments_builder, g_variant_new_string (cProperty));
	_arguments = g_variant_builder_end (&_arguments_builder);
	_reply = g_dbus_proxy_call_sync ((GDBusProxy *) self, "org.cairodock.CairoDock.applet.Get", _arguments, G_DBUS_CALL_FLAGS_NONE, -1, NULL, error);
	if (!_reply) {
		return NULL;
	}
	g_variant_iter_init (&_reply_iter, _reply);
	_tmp10_ = g_variant_iter_next_value (&_reply_iter);
	_result = g_variant_get_variant (_tmp10_);
	g_variant_unref (_tmp10_);
	g_variant_unref (_reply);
	return _result;
}


static GHashTable* cairo_dock_applet_iapplet_proxy_GetAll (CairoDockAppletIApplet* self, GError** error) {
	GVariant *_arguments, *_reply;
	GVariantBuilder _arguments_builder;
	GVariantIter _reply_iter;
	GHashTable* _result;
	GVariant* _tmp11_;
	GHashTable* _tmp12_;
	GVariantIter _tmp13_;
	GVariant* _tmp14_;
	GVariant* _tmp15_;
	g_variant_builder_init (&_arguments_builder, G_VARIANT_TYPE_TUPLE);
	_arguments = g_variant_builder_end (&_arguments_builder);
	_reply = g_dbus_proxy_call_sync ((GDBusProxy *) self, "org.cairodock.CairoDock.applet.GetAll", _arguments, G_DBUS_CALL_FLAGS_NONE, -1, NULL, error);
	if (!_reply) {
		return NULL;
	}
	g_variant_iter_init (&_reply_iter, _reply);
	_tmp11_ = g_variant_iter_next_value (&_reply_iter);
	_tmp12_ = g_hash_table_new_full (g_str_hash, g_str_equal, g_free, NULL);
	g_variant_iter_init (&_tmp13_, _tmp11_);
	while (g_variant_iter_loop (&_tmp13_, "{?*}", &_tmp14_, &_tmp15_)) {
		g_hash_table_insert (_tmp12_, g_variant_dup_string (_tmp14_, NULL), g_variant_get_variant (_tmp15_));
	}
	_result = _tmp12_;
	g_variant_unref (_tmp11_);
	g_variant_unref (_reply);
	return _result;
}


static void cairo_dock_applet_iapplet_proxy_SetQuickInfo (CairoDockAppletIApplet* self, const char* cQuickInfo, GError** error) {
	GVariant *_arguments, *_reply;
	GVariantBuilder _arguments_builder;
	GVariantIter _reply_iter;
	g_variant_builder_init (&_arguments_builder, G_VARIANT_TYPE_TUPLE);
	g_variant_builder_add_value (&_arguments_builder, g_variant_new_string (cQuickInfo));
	_arguments = g_variant_builder_end (&_arguments_builder);
	_reply = g_dbus_proxy_call_sync ((GDBusProxy *) self, "org.cairodock.CairoDock.applet.SetQuickInfo", _arguments, G_DBUS_CALL_FLAGS_NONE, -1, NULL, error);
	if (!_reply) {
		return;
	}
	g_variant_iter_init (&_reply_iter, _reply);
	g_variant_unref (_reply);
}


static void cairo_dock_applet_iapplet_proxy_SetLabel (CairoDockAppletIApplet* self, const char* cLabel, GError** error) {
	GVariant *_arguments, *_reply;
	GVariantBuilder _arguments_builder;
	GVariantIter _reply_iter;
	g_variant_builder_init (&_arguments_builder, G_VARIANT_TYPE_TUPLE);
	g_variant_builder_add_value (&_arguments_builder, g_variant_new_string (cLabel));
	_arguments = g_variant_builder_end (&_arguments_builder);
	_reply = g_dbus_proxy_call_sync ((GDBusProxy *) self, "org.cairodock.CairoDock.applet.SetLabel", _arguments, G_DBUS_CALL_FLAGS_NONE, -1, NULL, error);
	if (!_reply) {
		return;
	}
	g_variant_iter_init (&_reply_iter, _reply);
	g_variant_unref (_reply);
}


static void cairo_dock_applet_iapplet_proxy_SetIcon (CairoDockAppletIApplet* self, const char* cImage, GError** error) {
	GVariant *_arguments, *_reply;
	GVariantBuilder _arguments_builder;
	GVariantIter _reply_iter;
	g_variant_builder_init (&_arguments_builder, G_VARIANT_TYPE_TUPLE);
	g_variant_builder_add_value (&_arguments_builder, g_variant_new_string (cImage));
	_arguments = g_variant_builder_end (&_arguments_builder);
	_reply = g_dbus_proxy_call_sync ((GDBusProxy *) self, "org.cairodock.CairoDock.applet.SetIcon", _arguments, G_DBUS_CALL_FLAGS_NONE, -1, NULL, error);
	if (!_reply) {
		return;
	}
	g_variant_iter_init (&_reply_iter, _reply);
	g_variant_unref (_reply);
}


static void cairo_dock_applet_iapplet_proxy_SetEmblem (CairoDockAppletIApplet* self, const char* cImage, gint iPosition, GError** error) {
	GVariant *_arguments, *_reply;
	GVariantBuilder _arguments_builder;
	GVariantIter _reply_iter;
	g_variant_builder_init (&_arguments_builder, G_VARIANT_TYPE_TUPLE);
	g_variant_builder_add_value (&_arguments_builder, g_variant_new_string (cImage));
	g_variant_builder_add_value (&_arguments_builder, g_variant_new_int32 (iPosition));
	_arguments = g_variant_builder_end (&_arguments_builder);
	_reply = g_dbus_proxy_call_sync ((GDBusProxy *) self, "org.cairodock.CairoDock.applet.SetEmblem", _arguments, G_DBUS_CALL_FLAGS_NONE, -1, NULL, error);
	if (!_reply) {
		return;
	}
	g_variant_iter_init (&_reply_iter, _reply);
	g_variant_unref (_reply);
}


static void cairo_dock_applet_iapplet_proxy_Animate (CairoDockAppletIApplet* self, const char* cAnimation, gint iRounds, GError** error) {
	GVariant *_arguments, *_reply;
	GVariantBuilder _arguments_builder;
	GVariantIter _reply_iter;
	g_variant_builder_init (&_arguments_builder, G_VARIANT_TYPE_TUPLE);
	g_variant_builder_add_value (&_arguments_builder, g_variant_new_string (cAnimation));
	g_variant_builder_add_value (&_arguments_builder, g_variant_new_int32 (iRounds));
	_arguments = g_variant_builder_end (&_arguments_builder);
	_reply = g_dbus_proxy_call_sync ((GDBusProxy *) self, "org.cairodock.CairoDock.applet.Animate", _arguments, G_DBUS_CALL_FLAGS_NONE, -1, NULL, error);
	if (!_reply) {
		return;
	}
	g_variant_iter_init (&_reply_iter, _reply);
	g_variant_unref (_reply);
}


static void cairo_dock_applet_iapplet_proxy_DemandsAttention (CairoDockAppletIApplet* self, gboolean bStart, const char* cAnimation, GError** error) {
	GVariant *_arguments, *_reply;
	GVariantBuilder _arguments_builder;
	GVariantIter _reply_iter;
	g_variant_builder_init (&_arguments_builder, G_VARIANT_TYPE_TUPLE);
	g_variant_builder_add_value (&_arguments_builder, g_variant_new_boolean (bStart));
	g_variant_builder_add_value (&_arguments_builder, g_variant_new_string (cAnimation));
	_arguments = g_variant_builder_end (&_arguments_builder);
	_reply = g_dbus_proxy_call_sync ((GDBusProxy *) self, "org.cairodock.CairoDock.applet.DemandsAttention", _arguments, G_DBUS_CALL_FLAGS_NONE, -1, NULL, error);
	if (!_reply) {
		return;
	}
	g_variant_iter_init (&_reply_iter, _reply);
	g_variant_unref (_reply);
}


static void cairo_dock_applet_iapplet_proxy_ShowDialog (CairoDockAppletIApplet* self, const char* cMessage, gint iDuration, GError** error) {
	GVariant *_arguments, *_reply;
	GVariantBuilder _arguments_builder;
	GVariantIter _reply_iter;
	g_variant_builder_init (&_arguments_builder, G_VARIANT_TYPE_TUPLE);
	g_variant_builder_add_value (&_arguments_builder, g_variant_new_string (cMessage));
	g_variant_builder_add_value (&_arguments_builder, g_variant_new_int32 (iDuration));
	_arguments = g_variant_builder_end (&_arguments_builder);
	_reply = g_dbus_proxy_call_sync ((GDBusProxy *) self, "org.cairodock.CairoDock.applet.ShowDialog", _arguments, G_DBUS_CALL_FLAGS_NONE, -1, NULL, error);
	if (!_reply) {
		return;
	}
	g_variant_iter_init (&_reply_iter, _reply);
	g_variant_unref (_reply);
}


static void cairo_dock_applet_iapplet_proxy_PopupDialog (CairoDockAppletIApplet* self, GHashTable* hDialogAttributes, GHashTable* hWidgetAttributes, GError** error) {
	GVariant *_arguments, *_reply;
	GVariantBuilder _arguments_builder;
	GVariantBuilder _tmp16_;
	GHashTableIter _tmp17_;
	gpointer _tmp18_, _tmp19_;
	GVariantBuilder _tmp20_;
	GHashTableIter _tmp21_;
	gpointer _tmp22_, _tmp23_;
	GVariantIter _reply_iter;
	g_variant_builder_init (&_arguments_builder, G_VARIANT_TYPE_TUPLE);
	g_hash_table_iter_init (&_tmp17_, hDialogAttributes);
	g_variant_builder_init (&_tmp16_, G_VARIANT_TYPE_DICTIONARY);
	while (g_hash_table_iter_next (&_tmp17_, &_tmp18_, &_tmp19_)) {
		char* _key;
		GVariant* _value;
		_key = (char*) _tmp18_;
		_value = (GVariant*) _tmp19_;
		g_variant_builder_add (&_tmp16_, "{?*}", g_variant_new_string (_key), g_variant_new_variant (_value));
	}
	g_variant_builder_add_value (&_arguments_builder, g_variant_builder_end (&_tmp16_));
	g_hash_table_iter_init (&_tmp21_, hWidgetAttributes);
	g_variant_builder_init (&_tmp20_, G_VARIANT_TYPE_DICTIONARY);
	while (g_hash_table_iter_next (&_tmp21_, &_tmp22_, &_tmp23_)) {
		char* _key;
		GVariant* _value;
		_key = (char*) _tmp22_;
		_value = (GVariant*) _tmp23_;
		g_variant_builder_add (&_tmp20_, "{?*}", g_variant_new_string (_key), g_variant_new_variant (_value));
	}
	g_variant_builder_add_value (&_arguments_builder, g_variant_builder_end (&_tmp20_));
	_arguments = g_variant_builder_end (&_arguments_builder);
	_reply = g_dbus_proxy_call_sync ((GDBusProxy *) self, "org.cairodock.CairoDock.applet.PopupDialog", _arguments, G_DBUS_CALL_FLAGS_NONE, -1, NULL, error);
	if (!_reply) {
		return;
	}
	g_variant_iter_init (&_reply_iter, _reply);
	g_variant_unref (_reply);
}


static void cairo_dock_applet_iapplet_proxy_AddDataRenderer (CairoDockAppletIApplet* self, const char* cType, gint iNbValues, const char* cTheme, GError** error) {
	GVariant *_arguments, *_reply;
	GVariantBuilder _arguments_builder;
	GVariantIter _reply_iter;
	g_variant_builder_init (&_arguments_builder, G_VARIANT_TYPE_TUPLE);
	g_variant_builder_add_value (&_arguments_builder, g_variant_new_string (cType));
	g_variant_builder_add_value (&_arguments_builder, g_variant_new_int32 (iNbValues));
	g_variant_builder_add_value (&_arguments_builder, g_variant_new_string (cTheme));
	_arguments = g_variant_builder_end (&_arguments_builder);
	_reply = g_dbus_proxy_call_sync ((GDBusProxy *) self, "org.cairodock.CairoDock.applet.AddDataRenderer", _arguments, G_DBUS_CALL_FLAGS_NONE, -1, NULL, error);
	if (!_reply) {
		return;
	}
	g_variant_iter_init (&_reply_iter, _reply);
	g_variant_unref (_reply);
}


static void cairo_dock_applet_iapplet_proxy_RenderValues (CairoDockAppletIApplet* self, double* pValues, int pValues_length1, GError** error) {
	GVariant *_arguments, *_reply;
	GVariantBuilder _arguments_builder;
	double* _tmp24_;
	GVariantBuilder _tmp25_;
	int _tmp26_;
	GVariantIter _reply_iter;
	g_variant_builder_init (&_arguments_builder, G_VARIANT_TYPE_TUPLE);
	_tmp24_ = pValues;
	g_variant_builder_init (&_tmp25_, G_VARIANT_TYPE_ARRAY);
	for (_tmp26_ = 0; _tmp26_ < pValues_length1; _tmp26_++) {
		g_variant_builder_add_value (&_tmp25_, g_variant_new_double (*_tmp24_));
		_tmp24_++;
	}
	g_variant_builder_add_value (&_arguments_builder, g_variant_builder_end (&_tmp25_));
	_arguments = g_variant_builder_end (&_arguments_builder);
	_reply = g_dbus_proxy_call_sync ((GDBusProxy *) self, "org.cairodock.CairoDock.applet.RenderValues", _arguments, G_DBUS_CALL_FLAGS_NONE, -1, NULL, error);
	if (!_reply) {
		return;
	}
	g_variant_iter_init (&_reply_iter, _reply);
	g_variant_unref (_reply);
}


static void cairo_dock_applet_iapplet_proxy_ControlAppli (CairoDockAppletIApplet* self, const char* cApplicationClass, GError** error) {
	GVariant *_arguments, *_reply;
	GVariantBuilder _arguments_builder;
	GVariantIter _reply_iter;
	g_variant_builder_init (&_arguments_builder, G_VARIANT_TYPE_TUPLE);
	g_variant_builder_add_value (&_arguments_builder, g_variant_new_string (cApplicationClass));
	_arguments = g_variant_builder_end (&_arguments_builder);
	_reply = g_dbus_proxy_call_sync ((GDBusProxy *) self, "org.cairodock.CairoDock.applet.ControlAppli", _arguments, G_DBUS_CALL_FLAGS_NONE, -1, NULL, error);
	if (!_reply) {
		return;
	}
	g_variant_iter_init (&_reply_iter, _reply);
	g_variant_unref (_reply);
}


static void cairo_dock_applet_iapplet_proxy_ShowAppli (CairoDockAppletIApplet* self, gboolean bShow, GError** error) {
	GVariant *_arguments, *_reply;
	GVariantBuilder _arguments_builder;
	GVariantIter _reply_iter;
	g_variant_builder_init (&_arguments_builder, G_VARIANT_TYPE_TUPLE);
	g_variant_builder_add_value (&_arguments_builder, g_variant_new_boolean (bShow));
	_arguments = g_variant_builder_end (&_arguments_builder);
	_reply = g_dbus_proxy_call_sync ((GDBusProxy *) self, "org.cairodock.CairoDock.applet.ShowAppli", _arguments, G_DBUS_CALL_FLAGS_NONE, -1, NULL, error);
	if (!_reply) {
		return;
	}
	g_variant_iter_init (&_reply_iter, _reply);
	g_variant_unref (_reply);
}


static void cairo_dock_applet_iapplet_proxy_AddMenuItems (CairoDockAppletIApplet* self, GHashTable** pItems, int pItems_length1, GError** error) {
	GVariant *_arguments, *_reply;
	GVariantBuilder _arguments_builder;
	GHashTable** _tmp27_;
	GVariantBuilder _tmp28_;
	int _tmp29_;
	GVariantIter _reply_iter;
	g_variant_builder_init (&_arguments_builder, G_VARIANT_TYPE_TUPLE);
	_tmp27_ = pItems;
	g_variant_builder_init (&_tmp28_, G_VARIANT_TYPE_ARRAY);
	for (_tmp29_ = 0; _tmp29_ < pItems_length1; _tmp29_++) {
		GVariantBuilder _tmp30_;
		GHashTableIter _tmp31_;
		gpointer _tmp32_, _tmp33_;
		g_hash_table_iter_init (&_tmp31_, *_tmp27_);
		g_variant_builder_init (&_tmp30_, G_VARIANT_TYPE_DICTIONARY);
		while (g_hash_table_iter_next (&_tmp31_, &_tmp32_, &_tmp33_)) {
			char* _key;
			GVariant* _value;
			_key = (char*) _tmp32_;
			_value = (GVariant*) _tmp33_;
			g_variant_builder_add (&_tmp30_, "{?*}", g_variant_new_string (_key), g_variant_new_variant (_value));
		}
		g_variant_builder_add_value (&_tmp28_, g_variant_builder_end (&_tmp30_));
		_tmp27_++;
	}
	g_variant_builder_add_value (&_arguments_builder, g_variant_builder_end (&_tmp28_));
	_arguments = g_variant_builder_end (&_arguments_builder);
	_reply = g_dbus_proxy_call_sync ((GDBusProxy *) self, "org.cairodock.CairoDock.applet.AddMenuItems", _arguments, G_DBUS_CALL_FLAGS_NONE, -1, NULL, error);
	if (!_reply) {
		return;
	}
	g_variant_iter_init (&_reply_iter, _reply);
	g_variant_unref (_reply);
}


static void cairo_dock_applet_iapplet_proxy_BindShortkey (CairoDockAppletIApplet* self, char** cShortkeys, int cShortkeys_length1, GError** error) {
	GVariant *_arguments, *_reply;
	GVariantBuilder _arguments_builder;
	char** _tmp34_;
	GVariantBuilder _tmp35_;
	int _tmp36_;
	GVariantIter _reply_iter;
	g_variant_builder_init (&_arguments_builder, G_VARIANT_TYPE_TUPLE);
	_tmp34_ = cShortkeys;
	g_variant_builder_init (&_tmp35_, G_VARIANT_TYPE_ARRAY);
	for (_tmp36_ = 0; _tmp36_ < cShortkeys_length1; _tmp36_++) {
		g_variant_builder_add_value (&_tmp35_, g_variant_new_string (*_tmp34_));
		_tmp34_++;
	}
	g_variant_builder_add_value (&_arguments_builder, g_variant_builder_end (&_tmp35_));
	_arguments = g_variant_builder_end (&_arguments_builder);
	_reply = g_dbus_proxy_call_sync ((GDBusProxy *) self, "org.cairodock.CairoDock.applet.BindShortkey", _arguments, G_DBUS_CALL_FLAGS_NONE, -1, NULL, error);
	if (!_reply) {
		return;
	}
	g_variant_iter_init (&_reply_iter, _reply);
	g_variant_unref (_reply);
}


static void cairo_dock_applet_iapplet_proxy_cairo_dock_applet_iapplet_interface_init (CairoDockAppletIAppletIface* iface) {
	iface->Get = cairo_dock_applet_iapplet_proxy_Get;
	iface->GetAll = cairo_dock_applet_iapplet_proxy_GetAll;
	iface->SetQuickInfo = cairo_dock_applet_iapplet_proxy_SetQuickInfo;
	iface->SetLabel = cairo_dock_applet_iapplet_proxy_SetLabel;
	iface->SetIcon = cairo_dock_applet_iapplet_proxy_SetIcon;
	iface->SetEmblem = cairo_dock_applet_iapplet_proxy_SetEmblem;
	iface->Animate = cairo_dock_applet_iapplet_proxy_Animate;
	iface->DemandsAttention = cairo_dock_applet_iapplet_proxy_DemandsAttention;
	iface->ShowDialog = cairo_dock_applet_iapplet_proxy_ShowDialog;
	iface->PopupDialog = cairo_dock_applet_iapplet_proxy_PopupDialog;
	iface->AddDataRenderer = cairo_dock_applet_iapplet_proxy_AddDataRenderer;
	iface->RenderValues = cairo_dock_applet_iapplet_proxy_RenderValues;
	iface->ControlAppli = cairo_dock_applet_iapplet_proxy_ControlAppli;
	iface->ShowAppli = cairo_dock_applet_iapplet_proxy_ShowAppli;
	iface->AddMenuItems = cairo_dock_applet_iapplet_proxy_AddMenuItems;
	iface->BindShortkey = cairo_dock_applet_iapplet_proxy_BindShortkey;
}


static void _dbus_cairo_dock_applet_iapplet_Get (CairoDockAppletIApplet* self, GVariant* parameters, GDBusMethodInvocation* invocation) {
	GError* error;
	char* cProperty = NULL;
	GVariant* _tmp37_;
	GVariant* result;
	GVariantIter _arguments_iter;
	GVariant* _reply;
	GVariantBuilder _reply_builder;
	error = NULL;
	g_variant_iter_init (&_arguments_iter, parameters);
	_tmp37_ = g_variant_iter_next_value (&_arguments_iter);
	cProperty = g_variant_dup_string (_tmp37_, NULL);
	g_variant_unref (_tmp37_);
	result = cairo_dock_applet_iapplet_Get (self, cProperty, &error);
	if (error) {
		g_dbus_method_invocation_return_gerror (invocation, error);
		return;
	}
	g_variant_builder_init (&_reply_builder, G_VARIANT_TYPE_TUPLE);
	_g_free0 (cProperty);
	g_variant_builder_add_value (&_reply_builder, g_variant_new_variant (result));
	_g_variant_unref0 (result);
	_reply = g_variant_builder_end (&_reply_builder);
	g_dbus_method_invocation_return_value (invocation, _reply);
}


static void _dbus_cairo_dock_applet_iapplet_GetAll (CairoDockAppletIApplet* self, GVariant* parameters, GDBusMethodInvocation* invocation) {
	GError* error;
	GHashTable* result;
	GVariantIter _arguments_iter;
	GVariant* _reply;
	GVariantBuilder _reply_builder;
	GVariantBuilder _tmp38_;
	GHashTableIter _tmp39_;
	gpointer _tmp40_, _tmp41_;
	error = NULL;
	g_variant_iter_init (&_arguments_iter, parameters);
	result = cairo_dock_applet_iapplet_GetAll (self, &error);
	if (error) {
		g_dbus_method_invocation_return_gerror (invocation, error);
		return;
	}
	g_variant_builder_init (&_reply_builder, G_VARIANT_TYPE_TUPLE);
	g_hash_table_iter_init (&_tmp39_, result);
	g_variant_builder_init (&_tmp38_, G_VARIANT_TYPE_DICTIONARY);
	while (g_hash_table_iter_next (&_tmp39_, &_tmp40_, &_tmp41_)) {
		char* _key;
		GVariant* _value;
		_key = (char*) _tmp40_;
		_value = (GVariant*) _tmp41_;
		g_variant_builder_add (&_tmp38_, "{?*}", g_variant_new_string (_key), g_variant_new_variant (_value));
	}
	g_variant_builder_add_value (&_reply_builder, g_variant_builder_end (&_tmp38_));
	_g_hash_table_unref0 (result);
	_reply = g_variant_builder_end (&_reply_builder);
	g_dbus_method_invocation_return_value (invocation, _reply);
}


static void _dbus_cairo_dock_applet_iapplet_SetQuickInfo (CairoDockAppletIApplet* self, GVariant* parameters, GDBusMethodInvocation* invocation) {
	GError* error;
	char* cQuickInfo = NULL;
	GVariant* _tmp42_;
	GVariantIter _arguments_iter;
	GVariant* _reply;
	GVariantBuilder _reply_builder;
	error = NULL;
	g_variant_iter_init (&_arguments_iter, parameters);
	_tmp42_ = g_variant_iter_next_value (&_arguments_iter);
	cQuickInfo = g_variant_dup_string (_tmp42_, NULL);
	g_variant_unref (_tmp42_);
	cairo_dock_applet_iapplet_SetQuickInfo (self, cQuickInfo, &error);
	if (error) {
		g_dbus_method_invocation_return_gerror (invocation, error);
		return;
	}
	g_variant_builder_init (&_reply_builder, G_VARIANT_TYPE_TUPLE);
	_g_free0 (cQuickInfo);
	_reply = g_variant_builder_end (&_reply_builder);
	g_dbus_method_invocation_return_value (invocation, _reply);
}


static void _dbus_cairo_dock_applet_iapplet_SetLabel (CairoDockAppletIApplet* self, GVariant* parameters, GDBusMethodInvocation* invocation) {
	GError* error;
	char* cLabel = NULL;
	GVariant* _tmp43_;
	GVariantIter _arguments_iter;
	GVariant* _reply;
	GVariantBuilder _reply_builder;
	error = NULL;
	g_variant_iter_init (&_arguments_iter, parameters);
	_tmp43_ = g_variant_iter_next_value (&_arguments_iter);
	cLabel = g_variant_dup_string (_tmp43_, NULL);
	g_variant_unref (_tmp43_);
	cairo_dock_applet_iapplet_SetLabel (self, cLabel, &error);
	if (error) {
		g_dbus_method_invocation_return_gerror (invocation, error);
		return;
	}
	g_variant_builder_init (&_reply_builder, G_VARIANT_TYPE_TUPLE);
	_g_free0 (cLabel);
	_reply = g_variant_builder_end (&_reply_builder);
	g_dbus_method_invocation_return_value (invocation, _reply);
}


static void _dbus_cairo_dock_applet_iapplet_SetIcon (CairoDockAppletIApplet* self, GVariant* parameters, GDBusMethodInvocation* invocation) {
	GError* error;
	char* cImage = NULL;
	GVariant* _tmp44_;
	GVariantIter _arguments_iter;
	GVariant* _reply;
	GVariantBuilder _reply_builder;
	error = NULL;
	g_variant_iter_init (&_arguments_iter, parameters);
	_tmp44_ = g_variant_iter_next_value (&_arguments_iter);
	cImage = g_variant_dup_string (_tmp44_, NULL);
	g_variant_unref (_tmp44_);
	cairo_dock_applet_iapplet_SetIcon (self, cImage, &error);
	if (error) {
		g_dbus_method_invocation_return_gerror (invocation, error);
		return;
	}
	g_variant_builder_init (&_reply_builder, G_VARIANT_TYPE_TUPLE);
	_g_free0 (cImage);
	_reply = g_variant_builder_end (&_reply_builder);
	g_dbus_method_invocation_return_value (invocation, _reply);
}


static void _dbus_cairo_dock_applet_iapplet_SetEmblem (CairoDockAppletIApplet* self, GVariant* parameters, GDBusMethodInvocation* invocation) {
	GError* error;
	char* cImage = NULL;
	GVariant* _tmp45_;
	gint iPosition = 0;
	GVariant* _tmp46_;
	GVariantIter _arguments_iter;
	GVariant* _reply;
	GVariantBuilder _reply_builder;
	error = NULL;
	g_variant_iter_init (&_arguments_iter, parameters);
	_tmp45_ = g_variant_iter_next_value (&_arguments_iter);
	cImage = g_variant_dup_string (_tmp45_, NULL);
	g_variant_unref (_tmp45_);
	_tmp46_ = g_variant_iter_next_value (&_arguments_iter);
	iPosition = g_variant_get_int32 (_tmp46_);
	g_variant_unref (_tmp46_);
	cairo_dock_applet_iapplet_SetEmblem (self, cImage, iPosition, &error);
	if (error) {
		g_dbus_method_invocation_return_gerror (invocation, error);
		return;
	}
	g_variant_builder_init (&_reply_builder, G_VARIANT_TYPE_TUPLE);
	_g_free0 (cImage);
	_reply = g_variant_builder_end (&_reply_builder);
	g_dbus_method_invocation_return_value (invocation, _reply);
}


static void _dbus_cairo_dock_applet_iapplet_Animate (CairoDockAppletIApplet* self, GVariant* parameters, GDBusMethodInvocation* invocation) {
	GError* error;
	char* cAnimation = NULL;
	GVariant* _tmp47_;
	gint iRounds = 0;
	GVariant* _tmp48_;
	GVariantIter _arguments_iter;
	GVariant* _reply;
	GVariantBuilder _reply_builder;
	error = NULL;
	g_variant_iter_init (&_arguments_iter, parameters);
	_tmp47_ = g_variant_iter_next_value (&_arguments_iter);
	cAnimation = g_variant_dup_string (_tmp47_, NULL);
	g_variant_unref (_tmp47_);
	_tmp48_ = g_variant_iter_next_value (&_arguments_iter);
	iRounds = g_variant_get_int32 (_tmp48_);
	g_variant_unref (_tmp48_);
	cairo_dock_applet_iapplet_Animate (self, cAnimation, iRounds, &error);
	if (error) {
		g_dbus_method_invocation_return_gerror (invocation, error);
		return;
	}
	g_variant_builder_init (&_reply_builder, G_VARIANT_TYPE_TUPLE);
	_g_free0 (cAnimation);
	_reply = g_variant_builder_end (&_reply_builder);
	g_dbus_method_invocation_return_value (invocation, _reply);
}


static void _dbus_cairo_dock_applet_iapplet_DemandsAttention (CairoDockAppletIApplet* self, GVariant* parameters, GDBusMethodInvocation* invocation) {
	GError* error;
	gboolean bStart = FALSE;
	GVariant* _tmp49_;
	char* cAnimation = NULL;
	GVariant* _tmp50_;
	GVariantIter _arguments_iter;
	GVariant* _reply;
	GVariantBuilder _reply_builder;
	error = NULL;
	g_variant_iter_init (&_arguments_iter, parameters);
	_tmp49_ = g_variant_iter_next_value (&_arguments_iter);
	bStart = g_variant_get_boolean (_tmp49_);
	g_variant_unref (_tmp49_);
	_tmp50_ = g_variant_iter_next_value (&_arguments_iter);
	cAnimation = g_variant_dup_string (_tmp50_, NULL);
	g_variant_unref (_tmp50_);
	cairo_dock_applet_iapplet_DemandsAttention (self, bStart, cAnimation, &error);
	if (error) {
		g_dbus_method_invocation_return_gerror (invocation, error);
		return;
	}
	g_variant_builder_init (&_reply_builder, G_VARIANT_TYPE_TUPLE);
	_g_free0 (cAnimation);
	_reply = g_variant_builder_end (&_reply_builder);
	g_dbus_method_invocation_return_value (invocation, _reply);
}


static void _dbus_cairo_dock_applet_iapplet_ShowDialog (CairoDockAppletIApplet* self, GVariant* parameters, GDBusMethodInvocation* invocation) {
	GError* error;
	char* cMessage = NULL;
	GVariant* _tmp51_;
	gint iDuration = 0;
	GVariant* _tmp52_;
	GVariantIter _arguments_iter;
	GVariant* _reply;
	GVariantBuilder _reply_builder;
	error = NULL;
	g_variant_iter_init (&_arguments_iter, parameters);
	_tmp51_ = g_variant_iter_next_value (&_arguments_iter);
	cMessage = g_variant_dup_string (_tmp51_, NULL);
	g_variant_unref (_tmp51_);
	_tmp52_ = g_variant_iter_next_value (&_arguments_iter);
	iDuration = g_variant_get_int32 (_tmp52_);
	g_variant_unref (_tmp52_);
	cairo_dock_applet_iapplet_ShowDialog (self, cMessage, iDuration, &error);
	if (error) {
		g_dbus_method_invocation_return_gerror (invocation, error);
		return;
	}
	g_variant_builder_init (&_reply_builder, G_VARIANT_TYPE_TUPLE);
	_g_free0 (cMessage);
	_reply = g_variant_builder_end (&_reply_builder);
	g_dbus_method_invocation_return_value (invocation, _reply);
}


static void _dbus_cairo_dock_applet_iapplet_PopupDialog (CairoDockAppletIApplet* self, GVariant* parameters, GDBusMethodInvocation* invocation) {
	GError* error;
	GHashTable* hDialogAttributes = NULL;
	GVariant* _tmp53_;
	GHashTable* _tmp54_;
	GVariantIter _tmp55_;
	GVariant* _tmp56_;
	GVariant* _tmp57_;
	GHashTable* hWidgetAttributes = NULL;
	GVariant* _tmp58_;
	GHashTable* _tmp59_;
	GVariantIter _tmp60_;
	GVariant* _tmp61_;
	GVariant* _tmp62_;
	GVariantIter _arguments_iter;
	GVariant* _reply;
	GVariantBuilder _reply_builder;
	error = NULL;
	g_variant_iter_init (&_arguments_iter, parameters);
	_tmp53_ = g_variant_iter_next_value (&_arguments_iter);
	_tmp54_ = g_hash_table_new_full (g_str_hash, g_str_equal, g_free, NULL);
	g_variant_iter_init (&_tmp55_, _tmp53_);
	while (g_variant_iter_loop (&_tmp55_, "{?*}", &_tmp56_, &_tmp57_)) {
		g_hash_table_insert (_tmp54_, g_variant_dup_string (_tmp56_, NULL), g_variant_get_variant (_tmp57_));
	}
	hDialogAttributes = _tmp54_;
	g_variant_unref (_tmp53_);
	_tmp58_ = g_variant_iter_next_value (&_arguments_iter);
	_tmp59_ = g_hash_table_new_full (g_str_hash, g_str_equal, g_free, NULL);
	g_variant_iter_init (&_tmp60_, _tmp58_);
	while (g_variant_iter_loop (&_tmp60_, "{?*}", &_tmp61_, &_tmp62_)) {
		g_hash_table_insert (_tmp59_, g_variant_dup_string (_tmp61_, NULL), g_variant_get_variant (_tmp62_));
	}
	hWidgetAttributes = _tmp59_;
	g_variant_unref (_tmp58_);
	cairo_dock_applet_iapplet_PopupDialog (self, hDialogAttributes, hWidgetAttributes, &error);
	if (error) {
		g_dbus_method_invocation_return_gerror (invocation, error);
		return;
	}
	g_variant_builder_init (&_reply_builder, G_VARIANT_TYPE_TUPLE);
	_g_hash_table_unref0 (hDialogAttributes);
	_g_hash_table_unref0 (hWidgetAttributes);
	_reply = g_variant_builder_end (&_reply_builder);
	g_dbus_method_invocation_return_value (invocation, _reply);
}


static void _dbus_cairo_dock_applet_iapplet_AddDataRenderer (CairoDockAppletIApplet* self, GVariant* parameters, GDBusMethodInvocation* invocation) {
	GError* error;
	char* cType = NULL;
	GVariant* _tmp63_;
	gint iNbValues = 0;
	GVariant* _tmp64_;
	char* cTheme = NULL;
	GVariant* _tmp65_;
	GVariantIter _arguments_iter;
	GVariant* _reply;
	GVariantBuilder _reply_builder;
	error = NULL;
	g_variant_iter_init (&_arguments_iter, parameters);
	_tmp63_ = g_variant_iter_next_value (&_arguments_iter);
	cType = g_variant_dup_string (_tmp63_, NULL);
	g_variant_unref (_tmp63_);
	_tmp64_ = g_variant_iter_next_value (&_arguments_iter);
	iNbValues = g_variant_get_int32 (_tmp64_);
	g_variant_unref (_tmp64_);
	_tmp65_ = g_variant_iter_next_value (&_arguments_iter);
	cTheme = g_variant_dup_string (_tmp65_, NULL);
	g_variant_unref (_tmp65_);
	cairo_dock_applet_iapplet_AddDataRenderer (self, cType, iNbValues, cTheme, &error);
	if (error) {
		g_dbus_method_invocation_return_gerror (invocation, error);
		return;
	}
	g_variant_builder_init (&_reply_builder, G_VARIANT_TYPE_TUPLE);
	_g_free0 (cType);
	_g_free0 (cTheme);
	_reply = g_variant_builder_end (&_reply_builder);
	g_dbus_method_invocation_return_value (invocation, _reply);
}


static void _dbus_cairo_dock_applet_iapplet_RenderValues (CairoDockAppletIApplet* self, GVariant* parameters, GDBusMethodInvocation* invocation) {
	GError* error;
	double* pValues = NULL;
	int pValues_length1;
	GVariant* _tmp66_;
	double* _tmp67_;
	int _tmp67__length;
	int _tmp67__size;
	int _tmp67__length1;
	GVariantIter _tmp68_;
	GVariant* _tmp69_;
	GVariantIter _arguments_iter;
	GVariant* _reply;
	GVariantBuilder _reply_builder;
	error = NULL;
	g_variant_iter_init (&_arguments_iter, parameters);
	pValues_length1 = 0;
	_tmp66_ = g_variant_iter_next_value (&_arguments_iter);
	_tmp67_ = g_new (double, 5);
	_tmp67__length = 0;
	_tmp67__size = 4;
	_tmp67__length1 = 0;
	g_variant_iter_init (&_tmp68_, _tmp66_);
	for (; _tmp69_ = g_variant_iter_next_value (&_tmp68_); _tmp67__length1++) {
		if (_tmp67__size == _tmp67__length) {
			_tmp67__size = 2 * _tmp67__size;
			_tmp67_ = g_renew (double, _tmp67_, _tmp67__size + 1);
		}
		_tmp67_[_tmp67__length++] = g_variant_get_double (_tmp69_);
		g_variant_unref (_tmp69_);
	}
	pValues_length1 = _tmp67__length1;
	pValues = _tmp67_;
	g_variant_unref (_tmp66_);
	cairo_dock_applet_iapplet_RenderValues (self, pValues, pValues_length1, &error);
	if (error) {
		g_dbus_method_invocation_return_gerror (invocation, error);
		return;
	}
	g_variant_builder_init (&_reply_builder, G_VARIANT_TYPE_TUPLE);
	pValues = (g_free (pValues), NULL);
	_reply = g_variant_builder_end (&_reply_builder);
	g_dbus_method_invocation_return_value (invocation, _reply);
}


static void _dbus_cairo_dock_applet_iapplet_ControlAppli (CairoDockAppletIApplet* self, GVariant* parameters, GDBusMethodInvocation* invocation) {
	GError* error;
	char* cApplicationClass = NULL;
	GVariant* _tmp70_;
	GVariantIter _arguments_iter;
	GVariant* _reply;
	GVariantBuilder _reply_builder;
	error = NULL;
	g_variant_iter_init (&_arguments_iter, parameters);
	_tmp70_ = g_variant_iter_next_value (&_arguments_iter);
	cApplicationClass = g_variant_dup_string (_tmp70_, NULL);
	g_variant_unref (_tmp70_);
	cairo_dock_applet_iapplet_ControlAppli (self, cApplicationClass, &error);
	if (error) {
		g_dbus_method_invocation_return_gerror (invocation, error);
		return;
	}
	g_variant_builder_init (&_reply_builder, G_VARIANT_TYPE_TUPLE);
	_g_free0 (cApplicationClass);
	_reply = g_variant_builder_end (&_reply_builder);
	g_dbus_method_invocation_return_value (invocation, _reply);
}


static void _dbus_cairo_dock_applet_iapplet_ShowAppli (CairoDockAppletIApplet* self, GVariant* parameters, GDBusMethodInvocation* invocation) {
	GError* error;
	gboolean bShow = FALSE;
	GVariant* _tmp71_;
	GVariantIter _arguments_iter;
	GVariant* _reply;
	GVariantBuilder _reply_builder;
	error = NULL;
	g_variant_iter_init (&_arguments_iter, parameters);
	_tmp71_ = g_variant_iter_next_value (&_arguments_iter);
	bShow = g_variant_get_boolean (_tmp71_);
	g_variant_unref (_tmp71_);
	cairo_dock_applet_iapplet_ShowAppli (self, bShow, &error);
	if (error) {
		g_dbus_method_invocation_return_gerror (invocation, error);
		return;
	}
	g_variant_builder_init (&_reply_builder, G_VARIANT_TYPE_TUPLE);
	_reply = g_variant_builder_end (&_reply_builder);
	g_dbus_method_invocation_return_value (invocation, _reply);
}


static void _dbus_cairo_dock_applet_iapplet_AddMenuItems (CairoDockAppletIApplet* self, GVariant* parameters, GDBusMethodInvocation* invocation) {
	GError* error;
	GHashTable** pItems = NULL;
	int pItems_length1;
	GVariant* _tmp72_;
	GHashTable** _tmp73_;
	int _tmp73__length;
	int _tmp73__size;
	int _tmp73__length1;
	GVariantIter _tmp74_;
	GVariant* _tmp75_;
	GVariantIter _arguments_iter;
	GVariant* _reply;
	GVariantBuilder _reply_builder;
	error = NULL;
	g_variant_iter_init (&_arguments_iter, parameters);
	pItems_length1 = 0;
	_tmp72_ = g_variant_iter_next_value (&_arguments_iter);
	_tmp73_ = g_new (GHashTable*, 5);
	_tmp73__length = 0;
	_tmp73__size = 4;
	_tmp73__length1 = 0;
	g_variant_iter_init (&_tmp74_, _tmp72_);
	for (; _tmp75_ = g_variant_iter_next_value (&_tmp74_); _tmp73__length1++) {
		GHashTable* _tmp76_;
		GVariantIter _tmp77_;
		GVariant* _tmp78_;
		GVariant* _tmp79_;
		if (_tmp73__size == _tmp73__length) {
			_tmp73__size = 2 * _tmp73__size;
			_tmp73_ = g_renew (GHashTable*, _tmp73_, _tmp73__size + 1);
		}
		_tmp76_ = g_hash_table_new_full (g_str_hash, g_str_equal, g_free, NULL);
		g_variant_iter_init (&_tmp77_, _tmp75_);
		while (g_variant_iter_loop (&_tmp77_, "{?*}", &_tmp78_, &_tmp79_)) {
			g_hash_table_insert (_tmp76_, g_variant_dup_string (_tmp78_, NULL), g_variant_get_variant (_tmp79_));
		}
		_tmp73_[_tmp73__length++] = _tmp76_;
		g_variant_unref (_tmp75_);
	}
	pItems_length1 = _tmp73__length1;
	_tmp73_[_tmp73__length] = NULL;
	pItems = _tmp73_;
	g_variant_unref (_tmp72_);
	cairo_dock_applet_iapplet_AddMenuItems (self, pItems, pItems_length1, &error);
	if (error) {
		g_dbus_method_invocation_return_gerror (invocation, error);
		return;
	}
	g_variant_builder_init (&_reply_builder, G_VARIANT_TYPE_TUPLE);
	pItems = (_vala_array_free (pItems, pItems_length1, (GDestroyNotify) g_hash_table_unref), NULL);
	_reply = g_variant_builder_end (&_reply_builder);
	g_dbus_method_invocation_return_value (invocation, _reply);
}


static void _dbus_cairo_dock_applet_iapplet_BindShortkey (CairoDockAppletIApplet* self, GVariant* parameters, GDBusMethodInvocation* invocation) {
	GError* error;
	char** cShortkeys = NULL;
	int cShortkeys_length1;
	GVariant* _tmp80_;
	char** _tmp81_;
	int _tmp81__length;
	int _tmp81__size;
	int _tmp81__length1;
	GVariantIter _tmp82_;
	GVariant* _tmp83_;
	GVariantIter _arguments_iter;
	GVariant* _reply;
	GVariantBuilder _reply_builder;
	error = NULL;
	g_variant_iter_init (&_arguments_iter, parameters);
	cShortkeys_length1 = 0;
	_tmp80_ = g_variant_iter_next_value (&_arguments_iter);
	_tmp81_ = g_new (char*, 5);
	_tmp81__length = 0;
	_tmp81__size = 4;
	_tmp81__length1 = 0;
	g_variant_iter_init (&_tmp82_, _tmp80_);
	for (; _tmp83_ = g_variant_iter_next_value (&_tmp82_); _tmp81__length1++) {
		if (_tmp81__size == _tmp81__length) {
			_tmp81__size = 2 * _tmp81__size;
			_tmp81_ = g_renew (char*, _tmp81_, _tmp81__size + 1);
		}
		_tmp81_[_tmp81__length++] = g_variant_dup_string (_tmp83_, NULL);
		g_variant_unref (_tmp83_);
	}
	cShortkeys_length1 = _tmp81__length1;
	_tmp81_[_tmp81__length] = NULL;
	cShortkeys = _tmp81_;
	g_variant_unref (_tmp80_);
	cairo_dock_applet_iapplet_BindShortkey (self, cShortkeys, cShortkeys_length1, &error);
	if (error) {
		g_dbus_method_invocation_return_gerror (invocation, error);
		return;
	}
	g_variant_builder_init (&_reply_builder, G_VARIANT_TYPE_TUPLE);
	cShortkeys = (_vala_array_free (cShortkeys, cShortkeys_length1, (GDestroyNotify) g_free), NULL);
	_reply = g_variant_builder_end (&_reply_builder);
	g_dbus_method_invocation_return_value (invocation, _reply);
}


static void cairo_dock_applet_iapplet_dbus_interface_method_call (GDBusConnection* connection, const gchar* sender, const gchar* object_path, const gchar* interface_name, const gchar* method_name, GVariant* parameters, GDBusMethodInvocation* invocation, gpointer user_data) {
	gpointer* data;
	gpointer object;
	data = user_data;
	object = data[0];
	if (strcmp (method_name, "Get") == 0) {
		_dbus_cairo_dock_applet_iapplet_Get (object, parameters, invocation);
	} else if (strcmp (method_name, "GetAll") == 0) {
		_dbus_cairo_dock_applet_iapplet_GetAll (object, parameters, invocation);
	} else if (strcmp (method_name, "SetQuickInfo") == 0) {
		_dbus_cairo_dock_applet_iapplet_SetQuickInfo (object, parameters, invocation);
	} else if (strcmp (method_name, "SetLabel") == 0) {
		_dbus_cairo_dock_applet_iapplet_SetLabel (object, parameters, invocation);
	} else if (strcmp (method_name, "SetIcon") == 0) {
		_dbus_cairo_dock_applet_iapplet_SetIcon (object, parameters, invocation);
	} else if (strcmp (method_name, "SetEmblem") == 0) {
		_dbus_cairo_dock_applet_iapplet_SetEmblem (object, parameters, invocation);
	} else if (strcmp (method_name, "Animate") == 0) {
		_dbus_cairo_dock_applet_iapplet_Animate (object, parameters, invocation);
	} else if (strcmp (method_name, "DemandsAttention") == 0) {
		_dbus_cairo_dock_applet_iapplet_DemandsAttention (object, parameters, invocation);
	} else if (strcmp (method_name, "ShowDialog") == 0) {
		_dbus_cairo_dock_applet_iapplet_ShowDialog (object, parameters, invocation);
	} else if (strcmp (method_name, "PopupDialog") == 0) {
		_dbus_cairo_dock_applet_iapplet_PopupDialog (object, parameters, invocation);
	} else if (strcmp (method_name, "AddDataRenderer") == 0) {
		_dbus_cairo_dock_applet_iapplet_AddDataRenderer (object, parameters, invocation);
	} else if (strcmp (method_name, "RenderValues") == 0) {
		_dbus_cairo_dock_applet_iapplet_RenderValues (object, parameters, invocation);
	} else if (strcmp (method_name, "ControlAppli") == 0) {
		_dbus_cairo_dock_applet_iapplet_ControlAppli (object, parameters, invocation);
	} else if (strcmp (method_name, "ShowAppli") == 0) {
		_dbus_cairo_dock_applet_iapplet_ShowAppli (object, parameters, invocation);
	} else if (strcmp (method_name, "AddMenuItems") == 0) {
		_dbus_cairo_dock_applet_iapplet_AddMenuItems (object, parameters, invocation);
	} else if (strcmp (method_name, "BindShortkey") == 0) {
		_dbus_cairo_dock_applet_iapplet_BindShortkey (object, parameters, invocation);
	}
}


static GVariant* cairo_dock_applet_iapplet_dbus_interface_get_property (GDBusConnection* connection, const gchar* sender, const gchar* object_path, const gchar* interface_name, const gchar* property_name, GError** error, gpointer user_data) {
	gpointer* data;
	gpointer object;
	data = user_data;
	object = data[0];
	return NULL;
}


static gboolean cairo_dock_applet_iapplet_dbus_interface_set_property (GDBusConnection* connection, const gchar* sender, const gchar* object_path, const gchar* interface_name, const gchar* property_name, GVariant* value, GError** error, gpointer user_data) {
	gpointer* data;
	gpointer object;
	data = user_data;
	object = data[0];
	return FALSE;
}


static void _dbus_cairo_dock_applet_iapplet_on_click (GObject* _sender, gint iState, gpointer* _data) {
	GDBusConnection * _connection;
	const gchar * _path;
	GVariant *_arguments;
	GVariantBuilder _arguments_builder;
	_connection = _data[1];
	_path = _data[2];
	g_variant_builder_init (&_arguments_builder, G_VARIANT_TYPE_TUPLE);
	g_variant_builder_add_value (&_arguments_builder, g_variant_new_int32 (iState));
	_arguments = g_variant_builder_end (&_arguments_builder);
	g_dbus_connection_emit_signal (_connection, NULL, _path, "org.cairodock.CairoDock.applet", "on_click", _arguments, NULL);
}


static void _dbus_cairo_dock_applet_iapplet_on_middle_click (GObject* _sender, gpointer* _data) {
	GDBusConnection * _connection;
	const gchar * _path;
	GVariant *_arguments;
	GVariantBuilder _arguments_builder;
	_connection = _data[1];
	_path = _data[2];
	g_variant_builder_init (&_arguments_builder, G_VARIANT_TYPE_TUPLE);
	_arguments = g_variant_builder_end (&_arguments_builder);
	g_dbus_connection_emit_signal (_connection, NULL, _path, "org.cairodock.CairoDock.applet", "on_middle_click", _arguments, NULL);
}


static void _dbus_cairo_dock_applet_iapplet_on_build_menu (GObject* _sender, gpointer* _data) {
	GDBusConnection * _connection;
	const gchar * _path;
	GVariant *_arguments;
	GVariantBuilder _arguments_builder;
	_connection = _data[1];
	_path = _data[2];
	g_variant_builder_init (&_arguments_builder, G_VARIANT_TYPE_TUPLE);
	_arguments = g_variant_builder_end (&_arguments_builder);
	g_dbus_connection_emit_signal (_connection, NULL, _path, "org.cairodock.CairoDock.applet", "on_build_menu", _arguments, NULL);
}


static void _dbus_cairo_dock_applet_iapplet_on_menu_select (GObject* _sender, gint iNumEntry, gpointer* _data) {
	GDBusConnection * _connection;
	const gchar * _path;
	GVariant *_arguments;
	GVariantBuilder _arguments_builder;
	_connection = _data[1];
	_path = _data[2];
	g_variant_builder_init (&_arguments_builder, G_VARIANT_TYPE_TUPLE);
	g_variant_builder_add_value (&_arguments_builder, g_variant_new_int32 (iNumEntry));
	_arguments = g_variant_builder_end (&_arguments_builder);
	g_dbus_connection_emit_signal (_connection, NULL, _path, "org.cairodock.CairoDock.applet", "on_menu_select", _arguments, NULL);
}


static void _dbus_cairo_dock_applet_iapplet_on_scroll (GObject* _sender, gboolean bScrollUp, gpointer* _data) {
	GDBusConnection * _connection;
	const gchar * _path;
	GVariant *_arguments;
	GVariantBuilder _arguments_builder;
	_connection = _data[1];
	_path = _data[2];
	g_variant_builder_init (&_arguments_builder, G_VARIANT_TYPE_TUPLE);
	g_variant_builder_add_value (&_arguments_builder, g_variant_new_boolean (bScrollUp));
	_arguments = g_variant_builder_end (&_arguments_builder);
	g_dbus_connection_emit_signal (_connection, NULL, _path, "org.cairodock.CairoDock.applet", "on_scroll", _arguments, NULL);
}


static void _dbus_cairo_dock_applet_iapplet_on_drop_data (GObject* _sender, const char* cReceivedData, gpointer* _data) {
	GDBusConnection * _connection;
	const gchar * _path;
	GVariant *_arguments;
	GVariantBuilder _arguments_builder;
	_connection = _data[1];
	_path = _data[2];
	g_variant_builder_init (&_arguments_builder, G_VARIANT_TYPE_TUPLE);
	g_variant_builder_add_value (&_arguments_builder, g_variant_new_string (cReceivedData));
	_arguments = g_variant_builder_end (&_arguments_builder);
	g_dbus_connection_emit_signal (_connection, NULL, _path, "org.cairodock.CairoDock.applet", "on_drop_data", _arguments, NULL);
}


static void _dbus_cairo_dock_applet_iapplet_on_answer (GObject* _sender, GVariant* answer, gpointer* _data) {
	GDBusConnection * _connection;
	const gchar * _path;
	GVariant *_arguments;
	GVariantBuilder _arguments_builder;
	_connection = _data[1];
	_path = _data[2];
	g_variant_builder_init (&_arguments_builder, G_VARIANT_TYPE_TUPLE);
	g_variant_builder_add_value (&_arguments_builder, g_variant_new_variant (answer));
	_arguments = g_variant_builder_end (&_arguments_builder);
	g_dbus_connection_emit_signal (_connection, NULL, _path, "org.cairodock.CairoDock.applet", "on_answer", _arguments, NULL);
}


static void _dbus_cairo_dock_applet_iapplet_on_answer_dialog (GObject* _sender, gint iButton, GVariant* answer, gpointer* _data) {
	GDBusConnection * _connection;
	const gchar * _path;
	GVariant *_arguments;
	GVariantBuilder _arguments_builder;
	_connection = _data[1];
	_path = _data[2];
	g_variant_builder_init (&_arguments_builder, G_VARIANT_TYPE_TUPLE);
	g_variant_builder_add_value (&_arguments_builder, g_variant_new_int32 (iButton));
	g_variant_builder_add_value (&_arguments_builder, g_variant_new_variant (answer));
	_arguments = g_variant_builder_end (&_arguments_builder);
	g_dbus_connection_emit_signal (_connection, NULL, _path, "org.cairodock.CairoDock.applet", "on_answer_dialog", _arguments, NULL);
}


static void _dbus_cairo_dock_applet_iapplet_on_shortkey (GObject* _sender, const char* cKey, gpointer* _data) {
	GDBusConnection * _connection;
	const gchar * _path;
	GVariant *_arguments;
	GVariantBuilder _arguments_builder;
	_connection = _data[1];
	_path = _data[2];
	g_variant_builder_init (&_arguments_builder, G_VARIANT_TYPE_TUPLE);
	g_variant_builder_add_value (&_arguments_builder, g_variant_new_string (cKey));
	_arguments = g_variant_builder_end (&_arguments_builder);
	g_dbus_connection_emit_signal (_connection, NULL, _path, "org.cairodock.CairoDock.applet", "on_shortkey", _arguments, NULL);
}


static void _dbus_cairo_dock_applet_iapplet_on_change_focus (GObject* _sender, gboolean bIsActive, gpointer* _data) {
	GDBusConnection * _connection;
	const gchar * _path;
	GVariant *_arguments;
	GVariantBuilder _arguments_builder;
	_connection = _data[1];
	_path = _data[2];
	g_variant_builder_init (&_arguments_builder, G_VARIANT_TYPE_TUPLE);
	g_variant_builder_add_value (&_arguments_builder, g_variant_new_boolean (bIsActive));
	_arguments = g_variant_builder_end (&_arguments_builder);
	g_dbus_connection_emit_signal (_connection, NULL, _path, "org.cairodock.CairoDock.applet", "on_change_focus", _arguments, NULL);
}


static void _dbus_cairo_dock_applet_iapplet_on_stop_module (GObject* _sender, gpointer* _data) {
	GDBusConnection * _connection;
	const gchar * _path;
	GVariant *_arguments;
	GVariantBuilder _arguments_builder;
	_connection = _data[1];
	_path = _data[2];
	g_variant_builder_init (&_arguments_builder, G_VARIANT_TYPE_TUPLE);
	_arguments = g_variant_builder_end (&_arguments_builder);
	g_dbus_connection_emit_signal (_connection, NULL, _path, "org.cairodock.CairoDock.applet", "on_stop_module", _arguments, NULL);
}


static void _dbus_cairo_dock_applet_iapplet_on_reload_module (GObject* _sender, gboolean bConfigHasChanged, gpointer* _data) {
	GDBusConnection * _connection;
	const gchar * _path;
	GVariant *_arguments;
	GVariantBuilder _arguments_builder;
	_connection = _data[1];
	_path = _data[2];
	g_variant_builder_init (&_arguments_builder, G_VARIANT_TYPE_TUPLE);
	g_variant_builder_add_value (&_arguments_builder, g_variant_new_boolean (bConfigHasChanged));
	_arguments = g_variant_builder_end (&_arguments_builder);
	g_dbus_connection_emit_signal (_connection, NULL, _path, "org.cairodock.CairoDock.applet", "on_reload_module", _arguments, NULL);
}


guint cairo_dock_applet_iapplet_register_object (gpointer object, GDBusConnection* connection, const gchar* path, GError** error) {
	guint result;
	gpointer *data;
	data = g_new (gpointer, 3);
	data[0] = g_object_ref (object);
	data[1] = g_object_ref (connection);
	data[2] = g_strdup (path);
	result = g_dbus_connection_register_object (connection, path, &_cairo_dock_applet_iapplet_dbus_interface_info, &_cairo_dock_applet_iapplet_dbus_interface_vtable, data, _cairo_dock_applet_iapplet_unregister_object, error);
	if (!result) {
		return 0;
	}
	g_signal_connect (object, "on-click", (GCallback) _dbus_cairo_dock_applet_iapplet_on_click, data);
	g_signal_connect (object, "on-middle-click", (GCallback) _dbus_cairo_dock_applet_iapplet_on_middle_click, data);
	g_signal_connect (object, "on-build-menu", (GCallback) _dbus_cairo_dock_applet_iapplet_on_build_menu, data);
	g_signal_connect (object, "on-menu-select", (GCallback) _dbus_cairo_dock_applet_iapplet_on_menu_select, data);
	g_signal_connect (object, "on-scroll", (GCallback) _dbus_cairo_dock_applet_iapplet_on_scroll, data);
	g_signal_connect (object, "on-drop-data", (GCallback) _dbus_cairo_dock_applet_iapplet_on_drop_data, data);
	g_signal_connect (object, "on-answer", (GCallback) _dbus_cairo_dock_applet_iapplet_on_answer, data);
	g_signal_connect (object, "on-answer-dialog", (GCallback) _dbus_cairo_dock_applet_iapplet_on_answer_dialog, data);
	g_signal_connect (object, "on-shortkey", (GCallback) _dbus_cairo_dock_applet_iapplet_on_shortkey, data);
	g_signal_connect (object, "on-change-focus", (GCallback) _dbus_cairo_dock_applet_iapplet_on_change_focus, data);
	g_signal_connect (object, "on-stop-module", (GCallback) _dbus_cairo_dock_applet_iapplet_on_stop_module, data);
	g_signal_connect (object, "on-reload-module", (GCallback) _dbus_cairo_dock_applet_iapplet_on_reload_module, data);
	return result;
}


static void _cairo_dock_applet_iapplet_unregister_object (gpointer user_data) {
	gpointer* data;
	data = user_data;
	g_object_unref (data[0]);
	g_object_unref (data[1]);
	g_free (data[2]);
	g_free (data);
}


void cairo_dock_applet_isub_applet_SetQuickInfo (CairoDockAppletISubApplet* self, const char* cQuickInfo, const char* cIconID, GError** error) {
	CAIRO_DOCK_APPLET_ISUB_APPLET_GET_INTERFACE (self)->SetQuickInfo (self, cQuickInfo, cIconID, error);
}


void cairo_dock_applet_isub_applet_SetLabel (CairoDockAppletISubApplet* self, const char* cLabel, const char* cIconID, GError** error) {
	CAIRO_DOCK_APPLET_ISUB_APPLET_GET_INTERFACE (self)->SetLabel (self, cLabel, cIconID, error);
}


void cairo_dock_applet_isub_applet_SetIcon (CairoDockAppletISubApplet* self, const char* cImage, const char* cIconID, GError** error) {
	CAIRO_DOCK_APPLET_ISUB_APPLET_GET_INTERFACE (self)->SetIcon (self, cImage, cIconID, error);
}


void cairo_dock_applet_isub_applet_SetEmblem (CairoDockAppletISubApplet* self, const char* cImage, gint iPosition, const char* cIconID, GError** error) {
	CAIRO_DOCK_APPLET_ISUB_APPLET_GET_INTERFACE (self)->SetEmblem (self, cImage, iPosition, cIconID, error);
}


void cairo_dock_applet_isub_applet_Animate (CairoDockAppletISubApplet* self, const char* cAnimation, gint iNbRounds, const char* cIconID, GError** error) {
	CAIRO_DOCK_APPLET_ISUB_APPLET_GET_INTERFACE (self)->Animate (self, cAnimation, iNbRounds, cIconID, error);
}


void cairo_dock_applet_isub_applet_ShowDialog (CairoDockAppletISubApplet* self, const char* message, gint iDuration, const char* cIconID, GError** error) {
	CAIRO_DOCK_APPLET_ISUB_APPLET_GET_INTERFACE (self)->ShowDialog (self, message, iDuration, cIconID, error);
}


void cairo_dock_applet_isub_applet_AddSubIcons (CairoDockAppletISubApplet* self, char** pIconFields, int pIconFields_length1, GError** error) {
	CAIRO_DOCK_APPLET_ISUB_APPLET_GET_INTERFACE (self)->AddSubIcons (self, pIconFields, pIconFields_length1, error);
}


void cairo_dock_applet_isub_applet_RemoveSubIcon (CairoDockAppletISubApplet* self, const char* cIconID, GError** error) {
	CAIRO_DOCK_APPLET_ISUB_APPLET_GET_INTERFACE (self)->RemoveSubIcon (self, cIconID, error);
}


static void cairo_dock_applet_isub_applet_base_init (CairoDockAppletISubAppletIface * iface) {
	static gboolean initialized = FALSE;
	if (!initialized) {
		initialized = TRUE;
		g_signal_new ("on_click_sub_icon", CAIRO_DOCK_APPLET_TYPE_ISUB_APPLET, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_user_marshal_VOID__INT_STRING, G_TYPE_NONE, 2, G_TYPE_INT, G_TYPE_STRING);
		g_signal_new ("on_middle_click_sub_icon", CAIRO_DOCK_APPLET_TYPE_ISUB_APPLET, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__STRING, G_TYPE_NONE, 1, G_TYPE_STRING);
		g_signal_new ("on_scroll_sub_icon", CAIRO_DOCK_APPLET_TYPE_ISUB_APPLET, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_user_marshal_VOID__BOOLEAN_STRING, G_TYPE_NONE, 2, G_TYPE_BOOLEAN, G_TYPE_STRING);
		g_signal_new ("on_drop_data_sub_icon", CAIRO_DOCK_APPLET_TYPE_ISUB_APPLET, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_user_marshal_VOID__STRING_STRING, G_TYPE_NONE, 2, G_TYPE_STRING, G_TYPE_STRING);
		g_signal_new ("on_build_menu_sub_icon", CAIRO_DOCK_APPLET_TYPE_ISUB_APPLET, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__STRING, G_TYPE_NONE, 1, G_TYPE_STRING);
	}
}


GType cairo_dock_applet_isub_applet_get_type (void) {
	static volatile gsize cairo_dock_applet_isub_applet_type_id__volatile = 0;
	if (g_once_init_enter (&cairo_dock_applet_isub_applet_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (CairoDockAppletISubAppletIface), (GBaseInitFunc) cairo_dock_applet_isub_applet_base_init, (GBaseFinalizeFunc) NULL, (GClassInitFunc) NULL, (GClassFinalizeFunc) NULL, NULL, 0, 0, (GInstanceInitFunc) NULL, NULL };
		GType cairo_dock_applet_isub_applet_type_id;
		cairo_dock_applet_isub_applet_type_id = g_type_register_static (G_TYPE_INTERFACE, "CairoDockAppletISubApplet", &g_define_type_info, 0);
		g_type_interface_add_prerequisite (cairo_dock_applet_isub_applet_type_id, G_TYPE_OBJECT);
		g_once_init_leave (&cairo_dock_applet_isub_applet_type_id__volatile, cairo_dock_applet_isub_applet_type_id);
	}
	return cairo_dock_applet_isub_applet_type_id__volatile;
}


G_DEFINE_TYPE_EXTENDED (CairoDockAppletISubAppletProxy, cairo_dock_applet_isub_applet_proxy, G_TYPE_DBUS_PROXY, 0, G_IMPLEMENT_INTERFACE (CAIRO_DOCK_APPLET_TYPE_ISUB_APPLET, cairo_dock_applet_isub_applet_proxy_cairo_dock_applet_isub_applet_interface_init) );
static void cairo_dock_applet_isub_applet_proxy_class_init (CairoDockAppletISubAppletProxyClass* klass) {
	G_DBUS_PROXY_CLASS (klass)->g_signal = cairo_dock_applet_isub_applet_proxy_g_signal;
}


static void _dbus_handle_cairo_dock_applet_isub_applet_on_click_sub_icon (CairoDockAppletISubApplet* self, GVariant* parameters) {
	gint iState = 0;
	GVariant* _tmp84_;
	char* cIconID = NULL;
	GVariant* _tmp85_;
	GVariantIter _arguments_iter;
	g_variant_iter_init (&_arguments_iter, parameters);
	_tmp84_ = g_variant_iter_next_value (&_arguments_iter);
	iState = g_variant_get_int32 (_tmp84_);
	g_variant_unref (_tmp84_);
	_tmp85_ = g_variant_iter_next_value (&_arguments_iter);
	cIconID = g_variant_dup_string (_tmp85_, NULL);
	g_variant_unref (_tmp85_);
	g_signal_emit_by_name (self, "on-click-sub-icon", iState, cIconID);
	_g_free0 (cIconID);
}


static void _dbus_handle_cairo_dock_applet_isub_applet_on_middle_click_sub_icon (CairoDockAppletISubApplet* self, GVariant* parameters) {
	char* cIconID = NULL;
	GVariant* _tmp86_;
	GVariantIter _arguments_iter;
	g_variant_iter_init (&_arguments_iter, parameters);
	_tmp86_ = g_variant_iter_next_value (&_arguments_iter);
	cIconID = g_variant_dup_string (_tmp86_, NULL);
	g_variant_unref (_tmp86_);
	g_signal_emit_by_name (self, "on-middle-click-sub-icon", cIconID);
	_g_free0 (cIconID);
}


static void _dbus_handle_cairo_dock_applet_isub_applet_on_scroll_sub_icon (CairoDockAppletISubApplet* self, GVariant* parameters) {
	gboolean bScrollUp = FALSE;
	GVariant* _tmp87_;
	char* cIconID = NULL;
	GVariant* _tmp88_;
	GVariantIter _arguments_iter;
	g_variant_iter_init (&_arguments_iter, parameters);
	_tmp87_ = g_variant_iter_next_value (&_arguments_iter);
	bScrollUp = g_variant_get_boolean (_tmp87_);
	g_variant_unref (_tmp87_);
	_tmp88_ = g_variant_iter_next_value (&_arguments_iter);
	cIconID = g_variant_dup_string (_tmp88_, NULL);
	g_variant_unref (_tmp88_);
	g_signal_emit_by_name (self, "on-scroll-sub-icon", bScrollUp, cIconID);
	_g_free0 (cIconID);
}


static void _dbus_handle_cairo_dock_applet_isub_applet_on_drop_data_sub_icon (CairoDockAppletISubApplet* self, GVariant* parameters) {
	char* cReceivedData = NULL;
	GVariant* _tmp89_;
	char* cIconID = NULL;
	GVariant* _tmp90_;
	GVariantIter _arguments_iter;
	g_variant_iter_init (&_arguments_iter, parameters);
	_tmp89_ = g_variant_iter_next_value (&_arguments_iter);
	cReceivedData = g_variant_dup_string (_tmp89_, NULL);
	g_variant_unref (_tmp89_);
	_tmp90_ = g_variant_iter_next_value (&_arguments_iter);
	cIconID = g_variant_dup_string (_tmp90_, NULL);
	g_variant_unref (_tmp90_);
	g_signal_emit_by_name (self, "on-drop-data-sub-icon", cReceivedData, cIconID);
	_g_free0 (cReceivedData);
	_g_free0 (cIconID);
}


static void _dbus_handle_cairo_dock_applet_isub_applet_on_build_menu_sub_icon (CairoDockAppletISubApplet* self, GVariant* parameters) {
	char* cIconID = NULL;
	GVariant* _tmp91_;
	GVariantIter _arguments_iter;
	g_variant_iter_init (&_arguments_iter, parameters);
	_tmp91_ = g_variant_iter_next_value (&_arguments_iter);
	cIconID = g_variant_dup_string (_tmp91_, NULL);
	g_variant_unref (_tmp91_);
	g_signal_emit_by_name (self, "on-build-menu-sub-icon", cIconID);
	_g_free0 (cIconID);
}


static void cairo_dock_applet_isub_applet_proxy_g_signal (GDBusProxy* proxy, const gchar* sender_name, const gchar* signal_name, GVariant* parameters) {
	if (strcmp (signal_name, "on_clickSubIcon") == 0) {
		_dbus_handle_cairo_dock_applet_isub_applet_on_click_sub_icon (proxy, parameters);
	} else if (strcmp (signal_name, "on_middle_clickSubIcon") == 0) {
		_dbus_handle_cairo_dock_applet_isub_applet_on_middle_click_sub_icon (proxy, parameters);
	} else if (strcmp (signal_name, "on_scrollSubIcon") == 0) {
		_dbus_handle_cairo_dock_applet_isub_applet_on_scroll_sub_icon (proxy, parameters);
	} else if (strcmp (signal_name, "on_drop_dataSubIcon") == 0) {
		_dbus_handle_cairo_dock_applet_isub_applet_on_drop_data_sub_icon (proxy, parameters);
	} else if (strcmp (signal_name, "on_build_menuSubIcon") == 0) {
		_dbus_handle_cairo_dock_applet_isub_applet_on_build_menu_sub_icon (proxy, parameters);
	}
}


static void cairo_dock_applet_isub_applet_proxy_init (CairoDockAppletISubAppletProxy* self) {
}


static void cairo_dock_applet_isub_applet_proxy_SetQuickInfo (CairoDockAppletISubApplet* self, const char* cQuickInfo, const char* cIconID, GError** error) {
	GVariant *_arguments, *_reply;
	GVariantBuilder _arguments_builder;
	GVariantIter _reply_iter;
	g_variant_builder_init (&_arguments_builder, G_VARIANT_TYPE_TUPLE);
	g_variant_builder_add_value (&_arguments_builder, g_variant_new_string (cQuickInfo));
	g_variant_builder_add_value (&_arguments_builder, g_variant_new_string (cIconID));
	_arguments = g_variant_builder_end (&_arguments_builder);
	_reply = g_dbus_proxy_call_sync ((GDBusProxy *) self, "org.cairodock.CairoDock.subapplet.SetQuickInfo", _arguments, G_DBUS_CALL_FLAGS_NONE, -1, NULL, error);
	if (!_reply) {
		return;
	}
	g_variant_iter_init (&_reply_iter, _reply);
	g_variant_unref (_reply);
}


static void cairo_dock_applet_isub_applet_proxy_SetLabel (CairoDockAppletISubApplet* self, const char* cLabel, const char* cIconID, GError** error) {
	GVariant *_arguments, *_reply;
	GVariantBuilder _arguments_builder;
	GVariantIter _reply_iter;
	g_variant_builder_init (&_arguments_builder, G_VARIANT_TYPE_TUPLE);
	g_variant_builder_add_value (&_arguments_builder, g_variant_new_string (cLabel));
	g_variant_builder_add_value (&_arguments_builder, g_variant_new_string (cIconID));
	_arguments = g_variant_builder_end (&_arguments_builder);
	_reply = g_dbus_proxy_call_sync ((GDBusProxy *) self, "org.cairodock.CairoDock.subapplet.SetLabel", _arguments, G_DBUS_CALL_FLAGS_NONE, -1, NULL, error);
	if (!_reply) {
		return;
	}
	g_variant_iter_init (&_reply_iter, _reply);
	g_variant_unref (_reply);
}


static void cairo_dock_applet_isub_applet_proxy_SetIcon (CairoDockAppletISubApplet* self, const char* cImage, const char* cIconID, GError** error) {
	GVariant *_arguments, *_reply;
	GVariantBuilder _arguments_builder;
	GVariantIter _reply_iter;
	g_variant_builder_init (&_arguments_builder, G_VARIANT_TYPE_TUPLE);
	g_variant_builder_add_value (&_arguments_builder, g_variant_new_string (cImage));
	g_variant_builder_add_value (&_arguments_builder, g_variant_new_string (cIconID));
	_arguments = g_variant_builder_end (&_arguments_builder);
	_reply = g_dbus_proxy_call_sync ((GDBusProxy *) self, "org.cairodock.CairoDock.subapplet.SetIcon", _arguments, G_DBUS_CALL_FLAGS_NONE, -1, NULL, error);
	if (!_reply) {
		return;
	}
	g_variant_iter_init (&_reply_iter, _reply);
	g_variant_unref (_reply);
}


static void cairo_dock_applet_isub_applet_proxy_SetEmblem (CairoDockAppletISubApplet* self, const char* cImage, gint iPosition, const char* cIconID, GError** error) {
	GVariant *_arguments, *_reply;
	GVariantBuilder _arguments_builder;
	GVariantIter _reply_iter;
	g_variant_builder_init (&_arguments_builder, G_VARIANT_TYPE_TUPLE);
	g_variant_builder_add_value (&_arguments_builder, g_variant_new_string (cImage));
	g_variant_builder_add_value (&_arguments_builder, g_variant_new_int32 (iPosition));
	g_variant_builder_add_value (&_arguments_builder, g_variant_new_string (cIconID));
	_arguments = g_variant_builder_end (&_arguments_builder);
	_reply = g_dbus_proxy_call_sync ((GDBusProxy *) self, "org.cairodock.CairoDock.subapplet.SetEmblem", _arguments, G_DBUS_CALL_FLAGS_NONE, -1, NULL, error);
	if (!_reply) {
		return;
	}
	g_variant_iter_init (&_reply_iter, _reply);
	g_variant_unref (_reply);
}


static void cairo_dock_applet_isub_applet_proxy_Animate (CairoDockAppletISubApplet* self, const char* cAnimation, gint iNbRounds, const char* cIconID, GError** error) {
	GVariant *_arguments, *_reply;
	GVariantBuilder _arguments_builder;
	GVariantIter _reply_iter;
	g_variant_builder_init (&_arguments_builder, G_VARIANT_TYPE_TUPLE);
	g_variant_builder_add_value (&_arguments_builder, g_variant_new_string (cAnimation));
	g_variant_builder_add_value (&_arguments_builder, g_variant_new_int32 (iNbRounds));
	g_variant_builder_add_value (&_arguments_builder, g_variant_new_string (cIconID));
	_arguments = g_variant_builder_end (&_arguments_builder);
	_reply = g_dbus_proxy_call_sync ((GDBusProxy *) self, "org.cairodock.CairoDock.subapplet.Animate", _arguments, G_DBUS_CALL_FLAGS_NONE, -1, NULL, error);
	if (!_reply) {
		return;
	}
	g_variant_iter_init (&_reply_iter, _reply);
	g_variant_unref (_reply);
}


static void cairo_dock_applet_isub_applet_proxy_ShowDialog (CairoDockAppletISubApplet* self, const char* message, gint iDuration, const char* cIconID, GError** error) {
	GVariant *_arguments, *_reply;
	GVariantBuilder _arguments_builder;
	GVariantIter _reply_iter;
	g_variant_builder_init (&_arguments_builder, G_VARIANT_TYPE_TUPLE);
	g_variant_builder_add_value (&_arguments_builder, g_variant_new_string (message));
	g_variant_builder_add_value (&_arguments_builder, g_variant_new_int32 (iDuration));
	g_variant_builder_add_value (&_arguments_builder, g_variant_new_string (cIconID));
	_arguments = g_variant_builder_end (&_arguments_builder);
	_reply = g_dbus_proxy_call_sync ((GDBusProxy *) self, "org.cairodock.CairoDock.subapplet.ShowDialog", _arguments, G_DBUS_CALL_FLAGS_NONE, -1, NULL, error);
	if (!_reply) {
		return;
	}
	g_variant_iter_init (&_reply_iter, _reply);
	g_variant_unref (_reply);
}


static void cairo_dock_applet_isub_applet_proxy_AddSubIcons (CairoDockAppletISubApplet* self, char** pIconFields, int pIconFields_length1, GError** error) {
	GVariant *_arguments, *_reply;
	GVariantBuilder _arguments_builder;
	char** _tmp92_;
	GVariantBuilder _tmp93_;
	int _tmp94_;
	GVariantIter _reply_iter;
	g_variant_builder_init (&_arguments_builder, G_VARIANT_TYPE_TUPLE);
	_tmp92_ = pIconFields;
	g_variant_builder_init (&_tmp93_, G_VARIANT_TYPE_ARRAY);
	for (_tmp94_ = 0; _tmp94_ < pIconFields_length1; _tmp94_++) {
		g_variant_builder_add_value (&_tmp93_, g_variant_new_string (*_tmp92_));
		_tmp92_++;
	}
	g_variant_builder_add_value (&_arguments_builder, g_variant_builder_end (&_tmp93_));
	_arguments = g_variant_builder_end (&_arguments_builder);
	_reply = g_dbus_proxy_call_sync ((GDBusProxy *) self, "org.cairodock.CairoDock.subapplet.AddSubIcons", _arguments, G_DBUS_CALL_FLAGS_NONE, -1, NULL, error);
	if (!_reply) {
		return;
	}
	g_variant_iter_init (&_reply_iter, _reply);
	g_variant_unref (_reply);
}


static void cairo_dock_applet_isub_applet_proxy_RemoveSubIcon (CairoDockAppletISubApplet* self, const char* cIconID, GError** error) {
	GVariant *_arguments, *_reply;
	GVariantBuilder _arguments_builder;
	GVariantIter _reply_iter;
	g_variant_builder_init (&_arguments_builder, G_VARIANT_TYPE_TUPLE);
	g_variant_builder_add_value (&_arguments_builder, g_variant_new_string (cIconID));
	_arguments = g_variant_builder_end (&_arguments_builder);
	_reply = g_dbus_proxy_call_sync ((GDBusProxy *) self, "org.cairodock.CairoDock.subapplet.RemoveSubIcon", _arguments, G_DBUS_CALL_FLAGS_NONE, -1, NULL, error);
	if (!_reply) {
		return;
	}
	g_variant_iter_init (&_reply_iter, _reply);
	g_variant_unref (_reply);
}


static void cairo_dock_applet_isub_applet_proxy_cairo_dock_applet_isub_applet_interface_init (CairoDockAppletISubAppletIface* iface) {
	iface->SetQuickInfo = cairo_dock_applet_isub_applet_proxy_SetQuickInfo;
	iface->SetLabel = cairo_dock_applet_isub_applet_proxy_SetLabel;
	iface->SetIcon = cairo_dock_applet_isub_applet_proxy_SetIcon;
	iface->SetEmblem = cairo_dock_applet_isub_applet_proxy_SetEmblem;
	iface->Animate = cairo_dock_applet_isub_applet_proxy_Animate;
	iface->ShowDialog = cairo_dock_applet_isub_applet_proxy_ShowDialog;
	iface->AddSubIcons = cairo_dock_applet_isub_applet_proxy_AddSubIcons;
	iface->RemoveSubIcon = cairo_dock_applet_isub_applet_proxy_RemoveSubIcon;
}


static void _dbus_cairo_dock_applet_isub_applet_SetQuickInfo (CairoDockAppletISubApplet* self, GVariant* parameters, GDBusMethodInvocation* invocation) {
	GError* error;
	char* cQuickInfo = NULL;
	GVariant* _tmp95_;
	char* cIconID = NULL;
	GVariant* _tmp96_;
	GVariantIter _arguments_iter;
	GVariant* _reply;
	GVariantBuilder _reply_builder;
	error = NULL;
	g_variant_iter_init (&_arguments_iter, parameters);
	_tmp95_ = g_variant_iter_next_value (&_arguments_iter);
	cQuickInfo = g_variant_dup_string (_tmp95_, NULL);
	g_variant_unref (_tmp95_);
	_tmp96_ = g_variant_iter_next_value (&_arguments_iter);
	cIconID = g_variant_dup_string (_tmp96_, NULL);
	g_variant_unref (_tmp96_);
	cairo_dock_applet_isub_applet_SetQuickInfo (self, cQuickInfo, cIconID, &error);
	if (error) {
		g_dbus_method_invocation_return_gerror (invocation, error);
		return;
	}
	g_variant_builder_init (&_reply_builder, G_VARIANT_TYPE_TUPLE);
	_g_free0 (cQuickInfo);
	_g_free0 (cIconID);
	_reply = g_variant_builder_end (&_reply_builder);
	g_dbus_method_invocation_return_value (invocation, _reply);
}


static void _dbus_cairo_dock_applet_isub_applet_SetLabel (CairoDockAppletISubApplet* self, GVariant* parameters, GDBusMethodInvocation* invocation) {
	GError* error;
	char* cLabel = NULL;
	GVariant* _tmp97_;
	char* cIconID = NULL;
	GVariant* _tmp98_;
	GVariantIter _arguments_iter;
	GVariant* _reply;
	GVariantBuilder _reply_builder;
	error = NULL;
	g_variant_iter_init (&_arguments_iter, parameters);
	_tmp97_ = g_variant_iter_next_value (&_arguments_iter);
	cLabel = g_variant_dup_string (_tmp97_, NULL);
	g_variant_unref (_tmp97_);
	_tmp98_ = g_variant_iter_next_value (&_arguments_iter);
	cIconID = g_variant_dup_string (_tmp98_, NULL);
	g_variant_unref (_tmp98_);
	cairo_dock_applet_isub_applet_SetLabel (self, cLabel, cIconID, &error);
	if (error) {
		g_dbus_method_invocation_return_gerror (invocation, error);
		return;
	}
	g_variant_builder_init (&_reply_builder, G_VARIANT_TYPE_TUPLE);
	_g_free0 (cLabel);
	_g_free0 (cIconID);
	_reply = g_variant_builder_end (&_reply_builder);
	g_dbus_method_invocation_return_value (invocation, _reply);
}


static void _dbus_cairo_dock_applet_isub_applet_SetIcon (CairoDockAppletISubApplet* self, GVariant* parameters, GDBusMethodInvocation* invocation) {
	GError* error;
	char* cImage = NULL;
	GVariant* _tmp99_;
	char* cIconID = NULL;
	GVariant* _tmp100_;
	GVariantIter _arguments_iter;
	GVariant* _reply;
	GVariantBuilder _reply_builder;
	error = NULL;
	g_variant_iter_init (&_arguments_iter, parameters);
	_tmp99_ = g_variant_iter_next_value (&_arguments_iter);
	cImage = g_variant_dup_string (_tmp99_, NULL);
	g_variant_unref (_tmp99_);
	_tmp100_ = g_variant_iter_next_value (&_arguments_iter);
	cIconID = g_variant_dup_string (_tmp100_, NULL);
	g_variant_unref (_tmp100_);
	cairo_dock_applet_isub_applet_SetIcon (self, cImage, cIconID, &error);
	if (error) {
		g_dbus_method_invocation_return_gerror (invocation, error);
		return;
	}
	g_variant_builder_init (&_reply_builder, G_VARIANT_TYPE_TUPLE);
	_g_free0 (cImage);
	_g_free0 (cIconID);
	_reply = g_variant_builder_end (&_reply_builder);
	g_dbus_method_invocation_return_value (invocation, _reply);
}


static void _dbus_cairo_dock_applet_isub_applet_SetEmblem (CairoDockAppletISubApplet* self, GVariant* parameters, GDBusMethodInvocation* invocation) {
	GError* error;
	char* cImage = NULL;
	GVariant* _tmp101_;
	gint iPosition = 0;
	GVariant* _tmp102_;
	char* cIconID = NULL;
	GVariant* _tmp103_;
	GVariantIter _arguments_iter;
	GVariant* _reply;
	GVariantBuilder _reply_builder;
	error = NULL;
	g_variant_iter_init (&_arguments_iter, parameters);
	_tmp101_ = g_variant_iter_next_value (&_arguments_iter);
	cImage = g_variant_dup_string (_tmp101_, NULL);
	g_variant_unref (_tmp101_);
	_tmp102_ = g_variant_iter_next_value (&_arguments_iter);
	iPosition = g_variant_get_int32 (_tmp102_);
	g_variant_unref (_tmp102_);
	_tmp103_ = g_variant_iter_next_value (&_arguments_iter);
	cIconID = g_variant_dup_string (_tmp103_, NULL);
	g_variant_unref (_tmp103_);
	cairo_dock_applet_isub_applet_SetEmblem (self, cImage, iPosition, cIconID, &error);
	if (error) {
		g_dbus_method_invocation_return_gerror (invocation, error);
		return;
	}
	g_variant_builder_init (&_reply_builder, G_VARIANT_TYPE_TUPLE);
	_g_free0 (cImage);
	_g_free0 (cIconID);
	_reply = g_variant_builder_end (&_reply_builder);
	g_dbus_method_invocation_return_value (invocation, _reply);
}


static void _dbus_cairo_dock_applet_isub_applet_Animate (CairoDockAppletISubApplet* self, GVariant* parameters, GDBusMethodInvocation* invocation) {
	GError* error;
	char* cAnimation = NULL;
	GVariant* _tmp104_;
	gint iNbRounds = 0;
	GVariant* _tmp105_;
	char* cIconID = NULL;
	GVariant* _tmp106_;
	GVariantIter _arguments_iter;
	GVariant* _reply;
	GVariantBuilder _reply_builder;
	error = NULL;
	g_variant_iter_init (&_arguments_iter, parameters);
	_tmp104_ = g_variant_iter_next_value (&_arguments_iter);
	cAnimation = g_variant_dup_string (_tmp104_, NULL);
	g_variant_unref (_tmp104_);
	_tmp105_ = g_variant_iter_next_value (&_arguments_iter);
	iNbRounds = g_variant_get_int32 (_tmp105_);
	g_variant_unref (_tmp105_);
	_tmp106_ = g_variant_iter_next_value (&_arguments_iter);
	cIconID = g_variant_dup_string (_tmp106_, NULL);
	g_variant_unref (_tmp106_);
	cairo_dock_applet_isub_applet_Animate (self, cAnimation, iNbRounds, cIconID, &error);
	if (error) {
		g_dbus_method_invocation_return_gerror (invocation, error);
		return;
	}
	g_variant_builder_init (&_reply_builder, G_VARIANT_TYPE_TUPLE);
	_g_free0 (cAnimation);
	_g_free0 (cIconID);
	_reply = g_variant_builder_end (&_reply_builder);
	g_dbus_method_invocation_return_value (invocation, _reply);
}


static void _dbus_cairo_dock_applet_isub_applet_ShowDialog (CairoDockAppletISubApplet* self, GVariant* parameters, GDBusMethodInvocation* invocation) {
	GError* error;
	char* message = NULL;
	GVariant* _tmp107_;
	gint iDuration = 0;
	GVariant* _tmp108_;
	char* cIconID = NULL;
	GVariant* _tmp109_;
	GVariantIter _arguments_iter;
	GVariant* _reply;
	GVariantBuilder _reply_builder;
	error = NULL;
	g_variant_iter_init (&_arguments_iter, parameters);
	_tmp107_ = g_variant_iter_next_value (&_arguments_iter);
	message = g_variant_dup_string (_tmp107_, NULL);
	g_variant_unref (_tmp107_);
	_tmp108_ = g_variant_iter_next_value (&_arguments_iter);
	iDuration = g_variant_get_int32 (_tmp108_);
	g_variant_unref (_tmp108_);
	_tmp109_ = g_variant_iter_next_value (&_arguments_iter);
	cIconID = g_variant_dup_string (_tmp109_, NULL);
	g_variant_unref (_tmp109_);
	cairo_dock_applet_isub_applet_ShowDialog (self, message, iDuration, cIconID, &error);
	if (error) {
		g_dbus_method_invocation_return_gerror (invocation, error);
		return;
	}
	g_variant_builder_init (&_reply_builder, G_VARIANT_TYPE_TUPLE);
	_g_free0 (message);
	_g_free0 (cIconID);
	_reply = g_variant_builder_end (&_reply_builder);
	g_dbus_method_invocation_return_value (invocation, _reply);
}


static void _dbus_cairo_dock_applet_isub_applet_AddSubIcons (CairoDockAppletISubApplet* self, GVariant* parameters, GDBusMethodInvocation* invocation) {
	GError* error;
	char** pIconFields = NULL;
	int pIconFields_length1;
	GVariant* _tmp110_;
	char** _tmp111_;
	int _tmp111__length;
	int _tmp111__size;
	int _tmp111__length1;
	GVariantIter _tmp112_;
	GVariant* _tmp113_;
	GVariantIter _arguments_iter;
	GVariant* _reply;
	GVariantBuilder _reply_builder;
	error = NULL;
	g_variant_iter_init (&_arguments_iter, parameters);
	pIconFields_length1 = 0;
	_tmp110_ = g_variant_iter_next_value (&_arguments_iter);
	_tmp111_ = g_new (char*, 5);
	_tmp111__length = 0;
	_tmp111__size = 4;
	_tmp111__length1 = 0;
	g_variant_iter_init (&_tmp112_, _tmp110_);
	for (; _tmp113_ = g_variant_iter_next_value (&_tmp112_); _tmp111__length1++) {
		if (_tmp111__size == _tmp111__length) {
			_tmp111__size = 2 * _tmp111__size;
			_tmp111_ = g_renew (char*, _tmp111_, _tmp111__size + 1);
		}
		_tmp111_[_tmp111__length++] = g_variant_dup_string (_tmp113_, NULL);
		g_variant_unref (_tmp113_);
	}
	pIconFields_length1 = _tmp111__length1;
	_tmp111_[_tmp111__length] = NULL;
	pIconFields = _tmp111_;
	g_variant_unref (_tmp110_);
	cairo_dock_applet_isub_applet_AddSubIcons (self, pIconFields, pIconFields_length1, &error);
	if (error) {
		g_dbus_method_invocation_return_gerror (invocation, error);
		return;
	}
	g_variant_builder_init (&_reply_builder, G_VARIANT_TYPE_TUPLE);
	pIconFields = (_vala_array_free (pIconFields, pIconFields_length1, (GDestroyNotify) g_free), NULL);
	_reply = g_variant_builder_end (&_reply_builder);
	g_dbus_method_invocation_return_value (invocation, _reply);
}


static void _dbus_cairo_dock_applet_isub_applet_RemoveSubIcon (CairoDockAppletISubApplet* self, GVariant* parameters, GDBusMethodInvocation* invocation) {
	GError* error;
	char* cIconID = NULL;
	GVariant* _tmp114_;
	GVariantIter _arguments_iter;
	GVariant* _reply;
	GVariantBuilder _reply_builder;
	error = NULL;
	g_variant_iter_init (&_arguments_iter, parameters);
	_tmp114_ = g_variant_iter_next_value (&_arguments_iter);
	cIconID = g_variant_dup_string (_tmp114_, NULL);
	g_variant_unref (_tmp114_);
	cairo_dock_applet_isub_applet_RemoveSubIcon (self, cIconID, &error);
	if (error) {
		g_dbus_method_invocation_return_gerror (invocation, error);
		return;
	}
	g_variant_builder_init (&_reply_builder, G_VARIANT_TYPE_TUPLE);
	_g_free0 (cIconID);
	_reply = g_variant_builder_end (&_reply_builder);
	g_dbus_method_invocation_return_value (invocation, _reply);
}


static void cairo_dock_applet_isub_applet_dbus_interface_method_call (GDBusConnection* connection, const gchar* sender, const gchar* object_path, const gchar* interface_name, const gchar* method_name, GVariant* parameters, GDBusMethodInvocation* invocation, gpointer user_data) {
	gpointer* data;
	gpointer object;
	data = user_data;
	object = data[0];
	if (strcmp (method_name, "SetQuickInfo") == 0) {
		_dbus_cairo_dock_applet_isub_applet_SetQuickInfo (object, parameters, invocation);
	} else if (strcmp (method_name, "SetLabel") == 0) {
		_dbus_cairo_dock_applet_isub_applet_SetLabel (object, parameters, invocation);
	} else if (strcmp (method_name, "SetIcon") == 0) {
		_dbus_cairo_dock_applet_isub_applet_SetIcon (object, parameters, invocation);
	} else if (strcmp (method_name, "SetEmblem") == 0) {
		_dbus_cairo_dock_applet_isub_applet_SetEmblem (object, parameters, invocation);
	} else if (strcmp (method_name, "Animate") == 0) {
		_dbus_cairo_dock_applet_isub_applet_Animate (object, parameters, invocation);
	} else if (strcmp (method_name, "ShowDialog") == 0) {
		_dbus_cairo_dock_applet_isub_applet_ShowDialog (object, parameters, invocation);
	} else if (strcmp (method_name, "AddSubIcons") == 0) {
		_dbus_cairo_dock_applet_isub_applet_AddSubIcons (object, parameters, invocation);
	} else if (strcmp (method_name, "RemoveSubIcon") == 0) {
		_dbus_cairo_dock_applet_isub_applet_RemoveSubIcon (object, parameters, invocation);
	}
}


static GVariant* cairo_dock_applet_isub_applet_dbus_interface_get_property (GDBusConnection* connection, const gchar* sender, const gchar* object_path, const gchar* interface_name, const gchar* property_name, GError** error, gpointer user_data) {
	gpointer* data;
	gpointer object;
	data = user_data;
	object = data[0];
	return NULL;
}


static gboolean cairo_dock_applet_isub_applet_dbus_interface_set_property (GDBusConnection* connection, const gchar* sender, const gchar* object_path, const gchar* interface_name, const gchar* property_name, GVariant* value, GError** error, gpointer user_data) {
	gpointer* data;
	gpointer object;
	data = user_data;
	object = data[0];
	return FALSE;
}


static void _dbus_cairo_dock_applet_isub_applet_on_click_sub_icon (GObject* _sender, gint iState, const char* cIconID, gpointer* _data) {
	GDBusConnection * _connection;
	const gchar * _path;
	GVariant *_arguments;
	GVariantBuilder _arguments_builder;
	_connection = _data[1];
	_path = _data[2];
	g_variant_builder_init (&_arguments_builder, G_VARIANT_TYPE_TUPLE);
	g_variant_builder_add_value (&_arguments_builder, g_variant_new_int32 (iState));
	g_variant_builder_add_value (&_arguments_builder, g_variant_new_string (cIconID));
	_arguments = g_variant_builder_end (&_arguments_builder);
	g_dbus_connection_emit_signal (_connection, NULL, _path, "org.cairodock.CairoDock.subapplet", "on_clickSubIcon", _arguments, NULL);
}


static void _dbus_cairo_dock_applet_isub_applet_on_middle_click_sub_icon (GObject* _sender, const char* cIconID, gpointer* _data) {
	GDBusConnection * _connection;
	const gchar * _path;
	GVariant *_arguments;
	GVariantBuilder _arguments_builder;
	_connection = _data[1];
	_path = _data[2];
	g_variant_builder_init (&_arguments_builder, G_VARIANT_TYPE_TUPLE);
	g_variant_builder_add_value (&_arguments_builder, g_variant_new_string (cIconID));
	_arguments = g_variant_builder_end (&_arguments_builder);
	g_dbus_connection_emit_signal (_connection, NULL, _path, "org.cairodock.CairoDock.subapplet", "on_middle_clickSubIcon", _arguments, NULL);
}


static void _dbus_cairo_dock_applet_isub_applet_on_scroll_sub_icon (GObject* _sender, gboolean bScrollUp, const char* cIconID, gpointer* _data) {
	GDBusConnection * _connection;
	const gchar * _path;
	GVariant *_arguments;
	GVariantBuilder _arguments_builder;
	_connection = _data[1];
	_path = _data[2];
	g_variant_builder_init (&_arguments_builder, G_VARIANT_TYPE_TUPLE);
	g_variant_builder_add_value (&_arguments_builder, g_variant_new_boolean (bScrollUp));
	g_variant_builder_add_value (&_arguments_builder, g_variant_new_string (cIconID));
	_arguments = g_variant_builder_end (&_arguments_builder);
	g_dbus_connection_emit_signal (_connection, NULL, _path, "org.cairodock.CairoDock.subapplet", "on_scrollSubIcon", _arguments, NULL);
}


static void _dbus_cairo_dock_applet_isub_applet_on_drop_data_sub_icon (GObject* _sender, const char* cReceivedData, const char* cIconID, gpointer* _data) {
	GDBusConnection * _connection;
	const gchar * _path;
	GVariant *_arguments;
	GVariantBuilder _arguments_builder;
	_connection = _data[1];
	_path = _data[2];
	g_variant_builder_init (&_arguments_builder, G_VARIANT_TYPE_TUPLE);
	g_variant_builder_add_value (&_arguments_builder, g_variant_new_string (cReceivedData));
	g_variant_builder_add_value (&_arguments_builder, g_variant_new_string (cIconID));
	_arguments = g_variant_builder_end (&_arguments_builder);
	g_dbus_connection_emit_signal (_connection, NULL, _path, "org.cairodock.CairoDock.subapplet", "on_drop_dataSubIcon", _arguments, NULL);
}


static void _dbus_cairo_dock_applet_isub_applet_on_build_menu_sub_icon (GObject* _sender, const char* cIconID, gpointer* _data) {
	GDBusConnection * _connection;
	const gchar * _path;
	GVariant *_arguments;
	GVariantBuilder _arguments_builder;
	_connection = _data[1];
	_path = _data[2];
	g_variant_builder_init (&_arguments_builder, G_VARIANT_TYPE_TUPLE);
	g_variant_builder_add_value (&_arguments_builder, g_variant_new_string (cIconID));
	_arguments = g_variant_builder_end (&_arguments_builder);
	g_dbus_connection_emit_signal (_connection, NULL, _path, "org.cairodock.CairoDock.subapplet", "on_build_menuSubIcon", _arguments, NULL);
}


guint cairo_dock_applet_isub_applet_register_object (gpointer object, GDBusConnection* connection, const gchar* path, GError** error) {
	guint result;
	gpointer *data;
	data = g_new (gpointer, 3);
	data[0] = g_object_ref (object);
	data[1] = g_object_ref (connection);
	data[2] = g_strdup (path);
	result = g_dbus_connection_register_object (connection, path, &_cairo_dock_applet_isub_applet_dbus_interface_info, &_cairo_dock_applet_isub_applet_dbus_interface_vtable, data, _cairo_dock_applet_isub_applet_unregister_object, error);
	if (!result) {
		return 0;
	}
	g_signal_connect (object, "on-click-sub-icon", (GCallback) _dbus_cairo_dock_applet_isub_applet_on_click_sub_icon, data);
	g_signal_connect (object, "on-middle-click-sub-icon", (GCallback) _dbus_cairo_dock_applet_isub_applet_on_middle_click_sub_icon, data);
	g_signal_connect (object, "on-scroll-sub-icon", (GCallback) _dbus_cairo_dock_applet_isub_applet_on_scroll_sub_icon, data);
	g_signal_connect (object, "on-drop-data-sub-icon", (GCallback) _dbus_cairo_dock_applet_isub_applet_on_drop_data_sub_icon, data);
	g_signal_connect (object, "on-build-menu-sub-icon", (GCallback) _dbus_cairo_dock_applet_isub_applet_on_build_menu_sub_icon, data);
	return result;
}


static void _cairo_dock_applet_isub_applet_unregister_object (gpointer user_data) {
	gpointer* data;
	data = user_data;
	g_object_unref (data[0]);
	g_object_unref (data[1]);
	g_free (data[2]);
	g_free (data);
}


GType cairo_dock_applet_cd_applet_screen_position_get_type (void) {
	static volatile gsize cairo_dock_applet_cd_applet_screen_position_type_id__volatile = 0;
	if (g_once_init_enter (&cairo_dock_applet_cd_applet_screen_position_type_id__volatile)) {
		static const GEnumValue values[] = {{CAIRO_DOCK_APPLET_CD_APPLET_SCREEN_POSITION_BOTTOM, "CAIRO_DOCK_APPLET_CD_APPLET_SCREEN_POSITION_BOTTOM", "bottom"}, {CAIRO_DOCK_APPLET_CD_APPLET_SCREEN_POSITION_TOP, "CAIRO_DOCK_APPLET_CD_APPLET_SCREEN_POSITION_TOP", "top"}, {CAIRO_DOCK_APPLET_CD_APPLET_SCREEN_POSITION_RIGHT, "CAIRO_DOCK_APPLET_CD_APPLET_SCREEN_POSITION_RIGHT", "right"}, {CAIRO_DOCK_APPLET_CD_APPLET_SCREEN_POSITION_LEFT, "CAIRO_DOCK_APPLET_CD_APPLET_SCREEN_POSITION_LEFT", "left"}, {0, NULL, NULL}};
		GType cairo_dock_applet_cd_applet_screen_position_type_id;
		cairo_dock_applet_cd_applet_screen_position_type_id = g_enum_register_static ("CairoDockAppletCDAppletScreenPosition", values);
		g_once_init_leave (&cairo_dock_applet_cd_applet_screen_position_type_id__volatile, cairo_dock_applet_cd_applet_screen_position_type_id);
	}
	return cairo_dock_applet_cd_applet_screen_position_type_id__volatile;
}


GType cairo_dock_applet_cd_applet_container_type_get_type (void) {
	static volatile gsize cairo_dock_applet_cd_applet_container_type_type_id__volatile = 0;
	if (g_once_init_enter (&cairo_dock_applet_cd_applet_container_type_type_id__volatile)) {
		static const GEnumValue values[] = {{CAIRO_DOCK_APPLET_CD_APPLET_CONTAINER_TYPE_DOCK, "CAIRO_DOCK_APPLET_CD_APPLET_CONTAINER_TYPE_DOCK", "dock"}, {CAIRO_DOCK_APPLET_CD_APPLET_CONTAINER_TYPE_DESKLET, "CAIRO_DOCK_APPLET_CD_APPLET_CONTAINER_TYPE_DESKLET", "desklet"}, {0, NULL, NULL}};
		GType cairo_dock_applet_cd_applet_container_type_type_id;
		cairo_dock_applet_cd_applet_container_type_type_id = g_enum_register_static ("CairoDockAppletCDAppletContainerType", values);
		g_once_init_leave (&cairo_dock_applet_cd_applet_container_type_type_id__volatile, cairo_dock_applet_cd_applet_container_type_type_id);
	}
	return cairo_dock_applet_cd_applet_container_type_type_id__volatile;
}


GType cairo_dock_applet_cd_applet_emblem_position_get_type (void) {
	static volatile gsize cairo_dock_applet_cd_applet_emblem_position_type_id__volatile = 0;
	if (g_once_init_enter (&cairo_dock_applet_cd_applet_emblem_position_type_id__volatile)) {
		static const GEnumValue values[] = {{CAIRO_DOCK_APPLET_CD_APPLET_EMBLEM_POSITION_UPPER_LEFT, "CAIRO_DOCK_APPLET_CD_APPLET_EMBLEM_POSITION_UPPER_LEFT", "upper-left"}, {CAIRO_DOCK_APPLET_CD_APPLET_EMBLEM_POSITION_LOWER_RIGHT, "CAIRO_DOCK_APPLET_CD_APPLET_EMBLEM_POSITION_LOWER_RIGHT", "lower-right"}, {CAIRO_DOCK_APPLET_CD_APPLET_EMBLEM_POSITION_LOWER_LEFT, "CAIRO_DOCK_APPLET_CD_APPLET_EMBLEM_POSITION_LOWER_LEFT", "lower-left"}, {CAIRO_DOCK_APPLET_CD_APPLET_EMBLEM_POSITION_UPPER_RIGHT, "CAIRO_DOCK_APPLET_CD_APPLET_EMBLEM_POSITION_UPPER_RIGHT", "upper-right"}, {CAIRO_DOCK_APPLET_CD_APPLET_EMBLEM_POSITION_MIDDLE, "CAIRO_DOCK_APPLET_CD_APPLET_EMBLEM_POSITION_MIDDLE", "middle"}, {0, NULL, NULL}};
		GType cairo_dock_applet_cd_applet_emblem_position_type_id;
		cairo_dock_applet_cd_applet_emblem_position_type_id = g_enum_register_static ("CairoDockAppletCDAppletEmblemPosition", values);
		g_once_init_leave (&cairo_dock_applet_cd_applet_emblem_position_type_id__volatile, cairo_dock_applet_cd_applet_emblem_position_type_id);
	}
	return cairo_dock_applet_cd_applet_emblem_position_type_id__volatile;
}


GType cairo_dock_applet_cd_applet_menu_item_type_get_type (void) {
	static volatile gsize cairo_dock_applet_cd_applet_menu_item_type_type_id__volatile = 0;
	if (g_once_init_enter (&cairo_dock_applet_cd_applet_menu_item_type_type_id__volatile)) {
		static const GEnumValue values[] = {{CAIRO_DOCK_APPLET_CD_APPLET_MENU_ITEM_TYPE_MENU_ENTRY, "CAIRO_DOCK_APPLET_CD_APPLET_MENU_ITEM_TYPE_MENU_ENTRY", "menu-entry"}, {CAIRO_DOCK_APPLET_CD_APPLET_MENU_ITEM_TYPE_MENU_SUB_MENU, "CAIRO_DOCK_APPLET_CD_APPLET_MENU_ITEM_TYPE_MENU_SUB_MENU", "menu-sub-menu"}, {CAIRO_DOCK_APPLET_CD_APPLET_MENU_ITEM_TYPE_MENU_SEPARATOR, "CAIRO_DOCK_APPLET_CD_APPLET_MENU_ITEM_TYPE_MENU_SEPARATOR", "menu-separator"}, {CAIRO_DOCK_APPLET_CD_APPLET_MENU_ITEM_TYPE_MENU_CHECKBOX, "CAIRO_DOCK_APPLET_CD_APPLET_MENU_ITEM_TYPE_MENU_CHECKBOX", "menu-checkbox"}, {CAIRO_DOCK_APPLET_CD_APPLET_MENU_ITEM_TYPE_MENU_RADIO_BUTTON, "CAIRO_DOCK_APPLET_CD_APPLET_MENU_ITEM_TYPE_MENU_RADIO_BUTTON", "menu-radio-button"}, {0, NULL, NULL}};
		GType cairo_dock_applet_cd_applet_menu_item_type_type_id;
		cairo_dock_applet_cd_applet_menu_item_type_type_id = g_enum_register_static ("CairoDockAppletCDAppletMenuItemType", values);
		g_once_init_leave (&cairo_dock_applet_cd_applet_menu_item_type_type_id__volatile, cairo_dock_applet_cd_applet_menu_item_type_type_id);
	}
	return cairo_dock_applet_cd_applet_menu_item_type_type_id__volatile;
}


static glong string_get_length (const char* self) {
	glong result;
	g_return_val_if_fail (self != NULL, 0L);
	result = g_utf8_strlen (self, (gssize) (-1));
	return result;
}


static char* string_substring (const char* self, glong offset, glong len) {
	char* result = NULL;
	glong string_length;
	const char* start;
	g_return_val_if_fail (self != NULL, NULL);
	string_length = string_get_length (self);
	if (offset < 0) {
		offset = string_length + offset;
		g_return_val_if_fail (offset >= 0, NULL);
	} else {
		g_return_val_if_fail (offset <= string_length, NULL);
	}
	if (len < 0) {
		len = string_length - offset;
	}
	g_return_val_if_fail ((offset + len) <= string_length, NULL);
	start = g_utf8_offset_to_pointer (self, offset);
	result = g_strndup (start, ((gchar*) g_utf8_offset_to_pointer (start, len)) - ((gchar*) start));
	return result;
}


CairoDockAppletCDApplet* cairo_dock_applet_cd_applet_construct (GType object_type, char** argv, int argv_length1) {
	CairoDockAppletCDApplet * self;
	char* _tmp0_;
	char* _tmp1_;
	char* _tmp2_;
	char* _tmp3_;
	char* _tmp4_;
	self = (CairoDockAppletCDApplet*) g_object_new (object_type, NULL);
	self->cAppletName = (_tmp0_ = string_substring (argv[0], (glong) 2, (glong) 999), _g_free0 (self->cAppletName), _tmp0_);
	self->cBusPath = (_tmp1_ = g_strdup (argv[2]), _g_free0 (self->cBusPath), _tmp1_);
	self->cConfFile = (_tmp2_ = g_strdup (argv[3]), _g_free0 (self->cConfFile), _tmp2_);
	self->cParentAppName = (_tmp3_ = g_strdup (argv[4]), _g_free0 (self->cParentAppName), _tmp3_);
	_cairo_dock_applet_cd_applet_get_config (self);
	_cairo_dock_applet_cd_applet_connect_to_bus (self);
	self->priv->_cMenuIconId = (_tmp4_ = NULL, _g_free0 (self->priv->_cMenuIconId), _tmp4_);
	return self;
}


CairoDockAppletCDApplet* cairo_dock_applet_cd_applet_new (char** argv, int argv_length1) {
	return cairo_dock_applet_cd_applet_construct (CAIRO_DOCK_APPLET_TYPE_CD_APPLET, argv, argv_length1);
}


void cairo_dock_applet_cd_applet_run (CairoDockAppletCDApplet* self) {
	GMainLoop* _tmp0_;
	g_return_if_fail (self != NULL);
	cairo_dock_applet_cd_applet_begin (self);
	self->priv->loop = (_tmp0_ = g_main_loop_new (NULL, FALSE), _g_main_loop_unref0 (self->priv->loop), _tmp0_);
	g_main_loop_run (self->priv->loop);
}


static void cairo_dock_applet_cd_applet_real_on_click (CairoDockAppletCDApplet* self, gint iState) {
	g_return_if_fail (self != NULL);
	g_print (">>> clic !\n");
}


void cairo_dock_applet_cd_applet_on_click (CairoDockAppletCDApplet* self, gint iState) {
	CAIRO_DOCK_APPLET_CD_APPLET_GET_CLASS (self)->on_click (self, iState);
}


static void cairo_dock_applet_cd_applet_real_on_middle_click (CairoDockAppletCDApplet* self) {
	g_return_if_fail (self != NULL);
	g_print (">>> middle clic !\n");
}


void cairo_dock_applet_cd_applet_on_middle_click (CairoDockAppletCDApplet* self) {
	CAIRO_DOCK_APPLET_CD_APPLET_GET_CLASS (self)->on_middle_click (self);
}


static void _cairo_dock_applet_cd_applet_on_build_menu (CairoDockAppletCDApplet* self) {
	char* _tmp0_;
	g_return_if_fail (self != NULL);
	self->priv->_cMenuIconId = (_tmp0_ = NULL, _g_free0 (self->priv->_cMenuIconId), _tmp0_);
	cairo_dock_applet_cd_applet_on_build_menu (self);
}


static void cairo_dock_applet_cd_applet_real_on_build_menu (CairoDockAppletCDApplet* self) {
	g_return_if_fail (self != NULL);
	g_print (">>> build menu !\n");
}


void cairo_dock_applet_cd_applet_on_build_menu (CairoDockAppletCDApplet* self) {
	CAIRO_DOCK_APPLET_CD_APPLET_GET_CLASS (self)->on_build_menu (self);
}


static void _cairo_dock_applet_cd_applet_on_menu_select (CairoDockAppletCDApplet* self, gint iNumEntry) {
	g_return_if_fail (self != NULL);
	if (self->priv->_cMenuIconId == NULL) {
		cairo_dock_applet_cd_applet_on_menu_select (self, iNumEntry);
	} else {
		cairo_dock_applet_cd_applet_on_menu_select_sub_icon (self, iNumEntry, self->priv->_cMenuIconId);
	}
}


static void cairo_dock_applet_cd_applet_real_on_menu_select (CairoDockAppletCDApplet* self, gint iNumEntry) {
	g_return_if_fail (self != NULL);
	g_print (">>> choice %d has been selected !\n", iNumEntry);
}


void cairo_dock_applet_cd_applet_on_menu_select (CairoDockAppletCDApplet* self, gint iNumEntry) {
	CAIRO_DOCK_APPLET_CD_APPLET_GET_CLASS (self)->on_menu_select (self, iNumEntry);
}


static void cairo_dock_applet_cd_applet_real_on_scroll (CairoDockAppletCDApplet* self, gboolean bScrollUp) {
	g_return_if_fail (self != NULL);
	g_print (">>> scroll (up:%d)\n", (gint) bScrollUp);
}


void cairo_dock_applet_cd_applet_on_scroll (CairoDockAppletCDApplet* self, gboolean bScrollUp) {
	CAIRO_DOCK_APPLET_CD_APPLET_GET_CLASS (self)->on_scroll (self, bScrollUp);
}


static void cairo_dock_applet_cd_applet_real_on_drop_data (CairoDockAppletCDApplet* self, const char* cReceivedData) {
	g_return_if_fail (self != NULL);
	g_return_if_fail (cReceivedData != NULL);
	g_print (">>> received : %s\n", cReceivedData);
}


void cairo_dock_applet_cd_applet_on_drop_data (CairoDockAppletCDApplet* self, const char* cReceivedData) {
	CAIRO_DOCK_APPLET_CD_APPLET_GET_CLASS (self)->on_drop_data (self, cReceivedData);
}


static void cairo_dock_applet_cd_applet_real_on_answer (CairoDockAppletCDApplet* self, GVariant* answer) {
	g_return_if_fail (self != NULL);
	g_return_if_fail (answer != NULL);
	g_print (">>> answer\n");
}


void cairo_dock_applet_cd_applet_on_answer (CairoDockAppletCDApplet* self, GVariant* answer) {
	CAIRO_DOCK_APPLET_CD_APPLET_GET_CLASS (self)->on_answer (self, answer);
}


static void cairo_dock_applet_cd_applet_real_on_answer_dialog (CairoDockAppletCDApplet* self, gint iButton, GVariant* answer) {
	g_return_if_fail (self != NULL);
	g_return_if_fail (answer != NULL);
	g_print (">>> answer dialog\n");
}


void cairo_dock_applet_cd_applet_on_answer_dialog (CairoDockAppletCDApplet* self, gint iButton, GVariant* answer) {
	CAIRO_DOCK_APPLET_CD_APPLET_GET_CLASS (self)->on_answer_dialog (self, iButton, answer);
}


static void cairo_dock_applet_cd_applet_real_on_shortkey (CairoDockAppletCDApplet* self, const char* cKey) {
	g_return_if_fail (self != NULL);
	g_return_if_fail (cKey != NULL);
	g_print (">>> shortkey : %s\n", cKey);
}


void cairo_dock_applet_cd_applet_on_shortkey (CairoDockAppletCDApplet* self, const char* cKey) {
	CAIRO_DOCK_APPLET_CD_APPLET_GET_CLASS (self)->on_shortkey (self, cKey);
}


static void cairo_dock_applet_cd_applet_real_on_change_focus (CairoDockAppletCDApplet* self, gboolean bIsActive) {
	g_return_if_fail (self != NULL);
	g_print (">>> changed focus -> %d\n", (gint) bIsActive);
}


void cairo_dock_applet_cd_applet_on_change_focus (CairoDockAppletCDApplet* self, gboolean bIsActive) {
	CAIRO_DOCK_APPLET_CD_APPLET_GET_CLASS (self)->on_change_focus (self, bIsActive);
}


static void cairo_dock_applet_cd_applet_real_on_click_sub_icon (CairoDockAppletCDApplet* self, gint iState, const char* cIconID) {
	g_return_if_fail (self != NULL);
	g_return_if_fail (cIconID != NULL);
	g_print ("clic on the sub-icon '%s' !\n", cIconID);
}


void cairo_dock_applet_cd_applet_on_click_sub_icon (CairoDockAppletCDApplet* self, gint iState, const char* cIconID) {
	CAIRO_DOCK_APPLET_CD_APPLET_GET_CLASS (self)->on_click_sub_icon (self, iState, cIconID);
}


static void cairo_dock_applet_cd_applet_real_on_middle_click_sub_icon (CairoDockAppletCDApplet* self, const char* cIconID) {
	g_return_if_fail (self != NULL);
	g_return_if_fail (cIconID != NULL);
	g_print ("middle-clic on the sub-icon '%s' !\n", cIconID);
}


void cairo_dock_applet_cd_applet_on_middle_click_sub_icon (CairoDockAppletCDApplet* self, const char* cIconID) {
	CAIRO_DOCK_APPLET_CD_APPLET_GET_CLASS (self)->on_middle_click_sub_icon (self, cIconID);
}


static void cairo_dock_applet_cd_applet_real_on_scroll_sub_icon (CairoDockAppletCDApplet* self, gboolean bScrollUp, const char* cIconID) {
	g_return_if_fail (self != NULL);
	g_return_if_fail (cIconID != NULL);
	g_print ("scroll on the sub-icon '%s' !\n", cIconID);
}


void cairo_dock_applet_cd_applet_on_scroll_sub_icon (CairoDockAppletCDApplet* self, gboolean bScrollUp, const char* cIconID) {
	CAIRO_DOCK_APPLET_CD_APPLET_GET_CLASS (self)->on_scroll_sub_icon (self, bScrollUp, cIconID);
}


static void cairo_dock_applet_cd_applet_real_on_drop_data_sub_icon (CairoDockAppletCDApplet* self, const char* cReceivedData, const char* cIconID) {
	g_return_if_fail (self != NULL);
	g_return_if_fail (cReceivedData != NULL);
	g_return_if_fail (cIconID != NULL);
	g_print ("drop on the sub-icon '%s' !\n", cIconID);
}


void cairo_dock_applet_cd_applet_on_drop_data_sub_icon (CairoDockAppletCDApplet* self, const char* cReceivedData, const char* cIconID) {
	CAIRO_DOCK_APPLET_CD_APPLET_GET_CLASS (self)->on_drop_data_sub_icon (self, cReceivedData, cIconID);
}


static void _cairo_dock_applet_cd_applet_on_build_menu_sub_icon (CairoDockAppletCDApplet* self, const char* cIconID) {
	char* _tmp0_;
	g_return_if_fail (self != NULL);
	g_return_if_fail (cIconID != NULL);
	self->priv->_cMenuIconId = (_tmp0_ = g_strdup (cIconID), _g_free0 (self->priv->_cMenuIconId), _tmp0_);
	cairo_dock_applet_cd_applet_on_build_menu_sub_icon (self, cIconID);
}


static void cairo_dock_applet_cd_applet_real_on_build_menu_sub_icon (CairoDockAppletCDApplet* self, const char* cIconID) {
	g_return_if_fail (self != NULL);
	g_return_if_fail (cIconID != NULL);
	g_print ("build menu on the sub-icon '%s' !\n", cIconID);
}


void cairo_dock_applet_cd_applet_on_build_menu_sub_icon (CairoDockAppletCDApplet* self, const char* cIconID) {
	CAIRO_DOCK_APPLET_CD_APPLET_GET_CLASS (self)->on_build_menu_sub_icon (self, cIconID);
}


static void cairo_dock_applet_cd_applet_real_on_menu_select_sub_icon (CairoDockAppletCDApplet* self, gint iNumEntry, const char* cIconID) {
	g_return_if_fail (self != NULL);
	g_return_if_fail (cIconID != NULL);
	g_print (">>> choice %d has been selected on icon %s !\n", iNumEntry, cIconID);
}


void cairo_dock_applet_cd_applet_on_menu_select_sub_icon (CairoDockAppletCDApplet* self, gint iNumEntry, const char* cIconID) {
	CAIRO_DOCK_APPLET_CD_APPLET_GET_CLASS (self)->on_menu_select_sub_icon (self, iNumEntry, cIconID);
}


static void cairo_dock_applet_cd_applet_real_begin (CairoDockAppletCDApplet* self) {
	g_return_if_fail (self != NULL);
}


void cairo_dock_applet_cd_applet_begin (CairoDockAppletCDApplet* self) {
	CAIRO_DOCK_APPLET_CD_APPLET_GET_CLASS (self)->begin (self);
}


static void cairo_dock_applet_cd_applet_real_end (CairoDockAppletCDApplet* self) {
	g_return_if_fail (self != NULL);
}


void cairo_dock_applet_cd_applet_end (CairoDockAppletCDApplet* self) {
	CAIRO_DOCK_APPLET_CD_APPLET_GET_CLASS (self)->end (self);
}


static void _cairo_dock_applet_cd_applet_on_stop (CairoDockAppletCDApplet* self) {
	g_return_if_fail (self != NULL);
	g_print (">>> applet '%s' is stopped\n", self->cAppletName);
	cairo_dock_applet_cd_applet_end (self);
	g_main_loop_quit (self->priv->loop);
}


static void cairo_dock_applet_cd_applet_real_reload (CairoDockAppletCDApplet* self) {
	g_return_if_fail (self != NULL);
}


void cairo_dock_applet_cd_applet_reload (CairoDockAppletCDApplet* self) {
	CAIRO_DOCK_APPLET_CD_APPLET_GET_CLASS (self)->reload (self);
}


static void _cairo_dock_applet_cd_applet_on_reload (CairoDockAppletCDApplet* self, gboolean bConfigHasChanged) {
	g_return_if_fail (self != NULL);
	g_print (">>> our module is reloaded");
	if (bConfigHasChanged) {
		g_print (">>>  and our config has changed");
		_cairo_dock_applet_cd_applet_get_config (self);
		cairo_dock_applet_cd_applet_reload (self);
	}
}


static void cairo_dock_applet_cd_applet_real_get_config (CairoDockAppletCDApplet* self, GKeyFile* keyfile) {
	g_return_if_fail (self != NULL);
	g_return_if_fail (keyfile != NULL);
}


void cairo_dock_applet_cd_applet_get_config (CairoDockAppletCDApplet* self, GKeyFile* keyfile) {
	CAIRO_DOCK_APPLET_CD_APPLET_GET_CLASS (self)->get_config (self, keyfile);
}


static void _cairo_dock_applet_cd_applet_get_config (CairoDockAppletCDApplet* self) {
	GKeyFile* keyfile;
	GError * _inner_error_ = NULL;
	g_return_if_fail (self != NULL);
	keyfile = g_key_file_new ();
	{
		g_key_file_load_from_file (keyfile, self->cConfFile, G_KEY_FILE_NONE, &_inner_error_);
		if (_inner_error_ != NULL) {
			goto __catch0_g_error;
		}
	}
	goto __finally0;
	__catch0_g_error:
	{
		GError * e;
		e = _inner_error_;
		_inner_error_ = NULL;
		{
			g_warning ("CDApplet.vala:269: %s", e->message);
			_g_error_free0 (e);
		}
	}
	__finally0:
	{
		cairo_dock_applet_cd_applet_get_config (self, keyfile);
	}
	if (_inner_error_ != NULL) {
		_g_key_file_free0 (keyfile);
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
		g_clear_error (&_inner_error_);
		return;
	}
	_g_key_file_free0 (keyfile);
}


static void _cairo_dock_applet_cd_applet_on_click_cairo_dock_applet_iapplet_on_click (CairoDockAppletIApplet* _sender, gint iState, gpointer self) {
	cairo_dock_applet_cd_applet_on_click (self, iState);
}


static void _cairo_dock_applet_cd_applet_on_middle_click_cairo_dock_applet_iapplet_on_middle_click (CairoDockAppletIApplet* _sender, gpointer self) {
	cairo_dock_applet_cd_applet_on_middle_click (self);
}


static void __cairo_dock_applet_cd_applet_on_build_menu_cairo_dock_applet_iapplet_on_build_menu (CairoDockAppletIApplet* _sender, gpointer self) {
	_cairo_dock_applet_cd_applet_on_build_menu (self);
}


static void __cairo_dock_applet_cd_applet_on_menu_select_cairo_dock_applet_iapplet_on_menu_select (CairoDockAppletIApplet* _sender, gint iNumEntry, gpointer self) {
	_cairo_dock_applet_cd_applet_on_menu_select (self, iNumEntry);
}


static void _cairo_dock_applet_cd_applet_on_scroll_cairo_dock_applet_iapplet_on_scroll (CairoDockAppletIApplet* _sender, gboolean bScrollUp, gpointer self) {
	cairo_dock_applet_cd_applet_on_scroll (self, bScrollUp);
}


static void _cairo_dock_applet_cd_applet_on_drop_data_cairo_dock_applet_iapplet_on_drop_data (CairoDockAppletIApplet* _sender, const char* cReceivedData, gpointer self) {
	cairo_dock_applet_cd_applet_on_drop_data (self, cReceivedData);
}


static void _cairo_dock_applet_cd_applet_on_answer_cairo_dock_applet_iapplet_on_answer (CairoDockAppletIApplet* _sender, GVariant* answer, gpointer self) {
	cairo_dock_applet_cd_applet_on_answer (self, answer);
}


static void _cairo_dock_applet_cd_applet_on_answer_dialog_cairo_dock_applet_iapplet_on_answer_dialog (CairoDockAppletIApplet* _sender, gint iButton, GVariant* answer, gpointer self) {
	cairo_dock_applet_cd_applet_on_answer_dialog (self, iButton, answer);
}


static void _cairo_dock_applet_cd_applet_on_shortkey_cairo_dock_applet_iapplet_on_shortkey (CairoDockAppletIApplet* _sender, const char* cKey, gpointer self) {
	cairo_dock_applet_cd_applet_on_shortkey (self, cKey);
}


static void _cairo_dock_applet_cd_applet_on_change_focus_cairo_dock_applet_iapplet_on_change_focus (CairoDockAppletIApplet* _sender, gboolean bIsActive, gpointer self) {
	cairo_dock_applet_cd_applet_on_change_focus (self, bIsActive);
}


static void __cairo_dock_applet_cd_applet_on_stop_cairo_dock_applet_iapplet_on_stop_module (CairoDockAppletIApplet* _sender, gpointer self) {
	_cairo_dock_applet_cd_applet_on_stop (self);
}


static void __cairo_dock_applet_cd_applet_on_reload_cairo_dock_applet_iapplet_on_reload_module (CairoDockAppletIApplet* _sender, gboolean bConfigHasChanged, gpointer self) {
	_cairo_dock_applet_cd_applet_on_reload (self, bConfigHasChanged);
}


static void _cairo_dock_applet_cd_applet_on_click_sub_icon_cairo_dock_applet_isub_applet_on_click_sub_icon (CairoDockAppletISubApplet* _sender, gint iState, const char* cIconID, gpointer self) {
	cairo_dock_applet_cd_applet_on_click_sub_icon (self, iState, cIconID);
}


static void _cairo_dock_applet_cd_applet_on_middle_click_sub_icon_cairo_dock_applet_isub_applet_on_middle_click_sub_icon (CairoDockAppletISubApplet* _sender, const char* cIconID, gpointer self) {
	cairo_dock_applet_cd_applet_on_middle_click_sub_icon (self, cIconID);
}


static void _cairo_dock_applet_cd_applet_on_scroll_sub_icon_cairo_dock_applet_isub_applet_on_scroll_sub_icon (CairoDockAppletISubApplet* _sender, gboolean bScrollUp, const char* cIconID, gpointer self) {
	cairo_dock_applet_cd_applet_on_scroll_sub_icon (self, bScrollUp, cIconID);
}


static void _cairo_dock_applet_cd_applet_on_drop_data_sub_icon_cairo_dock_applet_isub_applet_on_drop_data_sub_icon (CairoDockAppletISubApplet* _sender, const char* cReceivedData, const char* cIconID, gpointer self) {
	cairo_dock_applet_cd_applet_on_drop_data_sub_icon (self, cReceivedData, cIconID);
}


static void __cairo_dock_applet_cd_applet_on_build_menu_sub_icon_cairo_dock_applet_isub_applet_on_build_menu_sub_icon (CairoDockAppletISubApplet* _sender, const char* cIconID, gpointer self) {
	_cairo_dock_applet_cd_applet_on_build_menu_sub_icon (self, cIconID);
}


static void _cairo_dock_applet_cd_applet_connect_to_bus (CairoDockAppletCDApplet* self) {
	GError * _inner_error_ = NULL;
	g_return_if_fail (self != NULL);
	{
		CairoDockAppletIApplet* _tmp0_;
		CairoDockAppletIApplet* _tmp1_;
		_tmp0_ = (CairoDockAppletIApplet*) g_initable_new (CAIRO_DOCK_APPLET_TYPE_IAPPLET_PROXY, NULL, &_inner_error_, "g-flags", G_DBUS_PROXY_FLAGS_DO_NOT_LOAD_PROPERTIES, "g-name", "org.cairodock.CairoDock", "g-bus-type", G_BUS_TYPE_SESSION, "g-object-path", self->cBusPath, "g-interface-name", "org.cairodock.CairoDock.applet", NULL);
		if (_inner_error_ != NULL) {
			if (_inner_error_->domain == G_IO_ERROR) {
				goto __catch1_g_io_error;
			}
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
			g_clear_error (&_inner_error_);
			return;
		}
		self->icon = (_tmp1_ = _tmp0_, _g_object_unref0 (self->icon), _tmp1_);
	}
	goto __finally1;
	__catch1_g_io_error:
	{
		GError * e;
		e = _inner_error_;
		_inner_error_ = NULL;
		{
			g_error ("CDApplet.vala:288: >>> module '%s' can't be found on the bus, exit.\n" \
"Error was: %s", self->cAppletName, e->message);
			_g_error_free0 (e);
		}
	}
	__finally1:
	if (_inner_error_ != NULL) {
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
		g_clear_error (&_inner_error_);
		return;
	}
	{
		char* _tmp2_;
		char* _tmp3_;
		CairoDockAppletISubApplet* _tmp4_;
		CairoDockAppletISubApplet* _tmp5_;
		CairoDockAppletISubApplet* _tmp6_;
		_tmp5_ = (_tmp4_ = (CairoDockAppletISubApplet*) g_initable_new (CAIRO_DOCK_APPLET_TYPE_ISUB_APPLET_PROXY, NULL, &_inner_error_, "g-flags", G_DBUS_PROXY_FLAGS_DO_NOT_LOAD_PROPERTIES, "g-name", "org.cairodock.CairoDock", "g-bus-type", G_BUS_TYPE_SESSION, "g-object-path", _tmp3_ = g_strconcat (self->cBusPath, "/sub_icons", NULL), "g-interface-name", "org.cairodock.CairoDock.subapplet", NULL), _g_free0 (_tmp3_), _g_free0 (_tmp2_), _tmp4_);
		if (_inner_error_ != NULL) {
			if (_inner_error_->domain == G_IO_ERROR) {
				goto __catch2_g_io_error;
			}
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
			g_clear_error (&_inner_error_);
			return;
		}
		self->sub_icons = (_tmp6_ = _tmp5_, _g_object_unref0 (self->sub_icons), _tmp6_);
	}
	goto __finally2;
	__catch2_g_io_error:
	{
		GError * e;
		e = _inner_error_;
		_inner_error_ = NULL;
		{
			g_error ("CDApplet.vala:298: >>> module '%s' can't be found on the bus, exit.\n" \
"Error was: %s", self->cAppletName, e->message);
			_g_error_free0 (e);
		}
	}
	__finally2:
	if (_inner_error_ != NULL) {
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
		g_clear_error (&_inner_error_);
		return;
	}
	g_signal_connect_object (self->icon, "on-click", (GCallback) _cairo_dock_applet_cd_applet_on_click_cairo_dock_applet_iapplet_on_click, self, 0);
	g_signal_connect_object (self->icon, "on-middle-click", (GCallback) _cairo_dock_applet_cd_applet_on_middle_click_cairo_dock_applet_iapplet_on_middle_click, self, 0);
	g_signal_connect_object (self->icon, "on-build-menu", (GCallback) __cairo_dock_applet_cd_applet_on_build_menu_cairo_dock_applet_iapplet_on_build_menu, self, 0);
	g_signal_connect_object (self->icon, "on-menu-select", (GCallback) __cairo_dock_applet_cd_applet_on_menu_select_cairo_dock_applet_iapplet_on_menu_select, self, 0);
	g_signal_connect_object (self->icon, "on-scroll", (GCallback) _cairo_dock_applet_cd_applet_on_scroll_cairo_dock_applet_iapplet_on_scroll, self, 0);
	g_signal_connect_object (self->icon, "on-drop-data", (GCallback) _cairo_dock_applet_cd_applet_on_drop_data_cairo_dock_applet_iapplet_on_drop_data, self, 0);
	g_signal_connect_object (self->icon, "on-answer", (GCallback) _cairo_dock_applet_cd_applet_on_answer_cairo_dock_applet_iapplet_on_answer, self, 0);
	g_signal_connect_object (self->icon, "on-answer-dialog", (GCallback) _cairo_dock_applet_cd_applet_on_answer_dialog_cairo_dock_applet_iapplet_on_answer_dialog, self, 0);
	g_signal_connect_object (self->icon, "on-shortkey", (GCallback) _cairo_dock_applet_cd_applet_on_shortkey_cairo_dock_applet_iapplet_on_shortkey, self, 0);
	g_signal_connect_object (self->icon, "on-change-focus", (GCallback) _cairo_dock_applet_cd_applet_on_change_focus_cairo_dock_applet_iapplet_on_change_focus, self, 0);
	g_signal_connect_object (self->icon, "on-stop-module", (GCallback) __cairo_dock_applet_cd_applet_on_stop_cairo_dock_applet_iapplet_on_stop_module, self, 0);
	g_signal_connect_object (self->icon, "on-reload-module", (GCallback) __cairo_dock_applet_cd_applet_on_reload_cairo_dock_applet_iapplet_on_reload_module, self, 0);
	g_signal_connect_object (self->sub_icons, "on-click-sub-icon", (GCallback) _cairo_dock_applet_cd_applet_on_click_sub_icon_cairo_dock_applet_isub_applet_on_click_sub_icon, self, 0);
	g_signal_connect_object (self->sub_icons, "on-middle-click-sub-icon", (GCallback) _cairo_dock_applet_cd_applet_on_middle_click_sub_icon_cairo_dock_applet_isub_applet_on_middle_click_sub_icon, self, 0);
	g_signal_connect_object (self->sub_icons, "on-scroll-sub-icon", (GCallback) _cairo_dock_applet_cd_applet_on_scroll_sub_icon_cairo_dock_applet_isub_applet_on_scroll_sub_icon, self, 0);
	g_signal_connect_object (self->sub_icons, "on-drop-data-sub-icon", (GCallback) _cairo_dock_applet_cd_applet_on_drop_data_sub_icon_cairo_dock_applet_isub_applet_on_drop_data_sub_icon, self, 0);
	g_signal_connect_object (self->sub_icons, "on-build-menu-sub-icon", (GCallback) __cairo_dock_applet_cd_applet_on_build_menu_sub_icon_cairo_dock_applet_isub_applet_on_build_menu_sub_icon, self, 0);
}


static void cairo_dock_applet_cd_applet_class_init (CairoDockAppletCDAppletClass * klass) {
	cairo_dock_applet_cd_applet_parent_class = g_type_class_peek_parent (klass);
	g_type_class_add_private (klass, sizeof (CairoDockAppletCDAppletPrivate));
	CAIRO_DOCK_APPLET_CD_APPLET_CLASS (klass)->on_click = cairo_dock_applet_cd_applet_real_on_click;
	CAIRO_DOCK_APPLET_CD_APPLET_CLASS (klass)->on_middle_click = cairo_dock_applet_cd_applet_real_on_middle_click;
	CAIRO_DOCK_APPLET_CD_APPLET_CLASS (klass)->on_build_menu = cairo_dock_applet_cd_applet_real_on_build_menu;
	CAIRO_DOCK_APPLET_CD_APPLET_CLASS (klass)->on_menu_select = cairo_dock_applet_cd_applet_real_on_menu_select;
	CAIRO_DOCK_APPLET_CD_APPLET_CLASS (klass)->on_scroll = cairo_dock_applet_cd_applet_real_on_scroll;
	CAIRO_DOCK_APPLET_CD_APPLET_CLASS (klass)->on_drop_data = cairo_dock_applet_cd_applet_real_on_drop_data;
	CAIRO_DOCK_APPLET_CD_APPLET_CLASS (klass)->on_answer = cairo_dock_applet_cd_applet_real_on_answer;
	CAIRO_DOCK_APPLET_CD_APPLET_CLASS (klass)->on_answer_dialog = cairo_dock_applet_cd_applet_real_on_answer_dialog;
	CAIRO_DOCK_APPLET_CD_APPLET_CLASS (klass)->on_shortkey = cairo_dock_applet_cd_applet_real_on_shortkey;
	CAIRO_DOCK_APPLET_CD_APPLET_CLASS (klass)->on_change_focus = cairo_dock_applet_cd_applet_real_on_change_focus;
	CAIRO_DOCK_APPLET_CD_APPLET_CLASS (klass)->on_click_sub_icon = cairo_dock_applet_cd_applet_real_on_click_sub_icon;
	CAIRO_DOCK_APPLET_CD_APPLET_CLASS (klass)->on_middle_click_sub_icon = cairo_dock_applet_cd_applet_real_on_middle_click_sub_icon;
	CAIRO_DOCK_APPLET_CD_APPLET_CLASS (klass)->on_scroll_sub_icon = cairo_dock_applet_cd_applet_real_on_scroll_sub_icon;
	CAIRO_DOCK_APPLET_CD_APPLET_CLASS (klass)->on_drop_data_sub_icon = cairo_dock_applet_cd_applet_real_on_drop_data_sub_icon;
	CAIRO_DOCK_APPLET_CD_APPLET_CLASS (klass)->on_build_menu_sub_icon = cairo_dock_applet_cd_applet_real_on_build_menu_sub_icon;
	CAIRO_DOCK_APPLET_CD_APPLET_CLASS (klass)->on_menu_select_sub_icon = cairo_dock_applet_cd_applet_real_on_menu_select_sub_icon;
	CAIRO_DOCK_APPLET_CD_APPLET_CLASS (klass)->begin = cairo_dock_applet_cd_applet_real_begin;
	CAIRO_DOCK_APPLET_CD_APPLET_CLASS (klass)->end = cairo_dock_applet_cd_applet_real_end;
	CAIRO_DOCK_APPLET_CD_APPLET_CLASS (klass)->reload = cairo_dock_applet_cd_applet_real_reload;
	CAIRO_DOCK_APPLET_CD_APPLET_CLASS (klass)->get_config = cairo_dock_applet_cd_applet_real_get_config;
	G_OBJECT_CLASS (klass)->finalize = cairo_dock_applet_cd_applet_finalize;
}


static void cairo_dock_applet_cd_applet_instance_init (CairoDockAppletCDApplet * self) {
	self->priv = CAIRO_DOCK_APPLET_CD_APPLET_GET_PRIVATE (self);
}


static void cairo_dock_applet_cd_applet_finalize (GObject* obj) {
	CairoDockAppletCDApplet * self;
	self = CAIRO_DOCK_APPLET_CD_APPLET (obj);
	_g_object_unref0 (self->icon);
	_g_object_unref0 (self->sub_icons);
	_g_free0 (self->cAppletName);
	_g_free0 (self->cConfFile);
	_g_free0 (self->cParentAppName);
	_g_free0 (self->cBusPath);
	_g_main_loop_unref0 (self->priv->loop);
	_g_free0 (self->priv->_cMenuIconId);
	G_OBJECT_CLASS (cairo_dock_applet_cd_applet_parent_class)->finalize (obj);
}


GType cairo_dock_applet_cd_applet_get_type (void) {
	static volatile gsize cairo_dock_applet_cd_applet_type_id__volatile = 0;
	if (g_once_init_enter (&cairo_dock_applet_cd_applet_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (CairoDockAppletCDAppletClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) cairo_dock_applet_cd_applet_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (CairoDockAppletCDApplet), 0, (GInstanceInitFunc) cairo_dock_applet_cd_applet_instance_init, NULL };
		GType cairo_dock_applet_cd_applet_type_id;
		cairo_dock_applet_cd_applet_type_id = g_type_register_static (G_TYPE_OBJECT, "CairoDockAppletCDApplet", &g_define_type_info, 0);
		g_once_init_leave (&cairo_dock_applet_cd_applet_type_id__volatile, cairo_dock_applet_cd_applet_type_id);
	}
	return cairo_dock_applet_cd_applet_type_id__volatile;
}


static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func) {
	if ((array != NULL) && (destroy_func != NULL)) {
		int i;
		for (i = 0; i < array_length; i = i + 1) {
			if (((gpointer*) array)[i] != NULL) {
				destroy_func (((gpointer*) array)[i]);
			}
		}
	}
}


static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func) {
	_vala_array_destroy (array, array_length, destroy_func);
	g_free (array);
}



static void g_cclosure_user_marshal_VOID__VARIANT (GClosure * closure, GValue * return_value, guint n_param_values, const GValue * param_values, gpointer invocation_hint, gpointer marshal_data) {
	typedef void (*GMarshalFunc_VOID__VARIANT) (gpointer data1, gpointer arg_1, gpointer data2);
	register GMarshalFunc_VOID__VARIANT callback;
	register GCClosure * cc;
	register gpointer data1, data2;
	cc = (GCClosure *) closure;
	g_return_if_fail (n_param_values == 2);
	if (G_CCLOSURE_SWAP_DATA (closure)) {
		data1 = closure->data;
		data2 = param_values->data[0].v_pointer;
	} else {
		data1 = param_values->data[0].v_pointer;
		data2 = closure->data;
	}
	callback = (GMarshalFunc_VOID__VARIANT) (marshal_data ? marshal_data : cc->callback);
	callback (data1, g_value_get_variant (param_values + 1), data2);
}


static void g_cclosure_user_marshal_VOID__INT_VARIANT (GClosure * closure, GValue * return_value, guint n_param_values, const GValue * param_values, gpointer invocation_hint, gpointer marshal_data) {
	typedef void (*GMarshalFunc_VOID__INT_VARIANT) (gpointer data1, gint arg_1, gpointer arg_2, gpointer data2);
	register GMarshalFunc_VOID__INT_VARIANT callback;
	register GCClosure * cc;
	register gpointer data1, data2;
	cc = (GCClosure *) closure;
	g_return_if_fail (n_param_values == 3);
	if (G_CCLOSURE_SWAP_DATA (closure)) {
		data1 = closure->data;
		data2 = param_values->data[0].v_pointer;
	} else {
		data1 = param_values->data[0].v_pointer;
		data2 = closure->data;
	}
	callback = (GMarshalFunc_VOID__INT_VARIANT) (marshal_data ? marshal_data : cc->callback);
	callback (data1, g_value_get_int (param_values + 1), g_value_get_variant (param_values + 2), data2);
}


static void g_cclosure_user_marshal_VOID__INT_STRING (GClosure * closure, GValue * return_value, guint n_param_values, const GValue * param_values, gpointer invocation_hint, gpointer marshal_data) {
	typedef void (*GMarshalFunc_VOID__INT_STRING) (gpointer data1, gint arg_1, const char* arg_2, gpointer data2);
	register GMarshalFunc_VOID__INT_STRING callback;
	register GCClosure * cc;
	register gpointer data1, data2;
	cc = (GCClosure *) closure;
	g_return_if_fail (n_param_values == 3);
	if (G_CCLOSURE_SWAP_DATA (closure)) {
		data1 = closure->data;
		data2 = param_values->data[0].v_pointer;
	} else {
		data1 = param_values->data[0].v_pointer;
		data2 = closure->data;
	}
	callback = (GMarshalFunc_VOID__INT_STRING) (marshal_data ? marshal_data : cc->callback);
	callback (data1, g_value_get_int (param_values + 1), g_value_get_string (param_values + 2), data2);
}


static void g_cclosure_user_marshal_VOID__BOOLEAN_STRING (GClosure * closure, GValue * return_value, guint n_param_values, const GValue * param_values, gpointer invocation_hint, gpointer marshal_data) {
	typedef void (*GMarshalFunc_VOID__BOOLEAN_STRING) (gpointer data1, gboolean arg_1, const char* arg_2, gpointer data2);
	register GMarshalFunc_VOID__BOOLEAN_STRING callback;
	register GCClosure * cc;
	register gpointer data1, data2;
	cc = (GCClosure *) closure;
	g_return_if_fail (n_param_values == 3);
	if (G_CCLOSURE_SWAP_DATA (closure)) {
		data1 = closure->data;
		data2 = param_values->data[0].v_pointer;
	} else {
		data1 = param_values->data[0].v_pointer;
		data2 = closure->data;
	}
	callback = (GMarshalFunc_VOID__BOOLEAN_STRING) (marshal_data ? marshal_data : cc->callback);
	callback (data1, g_value_get_boolean (param_values + 1), g_value_get_string (param_values + 2), data2);
}


static void g_cclosure_user_marshal_VOID__STRING_STRING (GClosure * closure, GValue * return_value, guint n_param_values, const GValue * param_values, gpointer invocation_hint, gpointer marshal_data) {
	typedef void (*GMarshalFunc_VOID__STRING_STRING) (gpointer data1, const char* arg_1, const char* arg_2, gpointer data2);
	register GMarshalFunc_VOID__STRING_STRING callback;
	register GCClosure * cc;
	register gpointer data1, data2;
	cc = (GCClosure *) closure;
	g_return_if_fail (n_param_values == 3);
	if (G_CCLOSURE_SWAP_DATA (closure)) {
		data1 = closure->data;
		data2 = param_values->data[0].v_pointer;
	} else {
		data1 = param_values->data[0].v_pointer;
		data2 = closure->data;
	}
	callback = (GMarshalFunc_VOID__STRING_STRING) (marshal_data ? marshal_data : cc->callback);
	callback (data1, g_value_get_string (param_values + 1), g_value_get_string (param_values + 2), data2);
}



